(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 12.2' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    293919,       7984]
NotebookOptionsPosition[    288413,       7891]
NotebookOutlinePosition[    288832,       7908]
CellTagsIndexPosition[    288789,       7905]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["\<\
Supplementary Material -- Picard-Fuchs Operators for Banana Integrals\
\>", "Title",
 CellChangeTimes->{{3.8372282742285757`*^9, 3.837228277817273*^9}, {
  3.8376784709745903`*^9, 
  3.837678488884706*^9}},ExpressionUUID->"5e146ba6-3056-485d-95ac-\
35994a430abf"],

Cell[CellGroupData[{

Cell["Operators in the generic-mass case", "Chapter",
 CellChangeTimes->{{3.83722828959616*^9, 
  3.83722829752756*^9}},ExpressionUUID->"b50de7df-2fe0-4670-a278-\
aec814a58f66"],

Cell["Evaluate all functions in \[OpenCurlyDoubleQuote]Necessary Functions\
\[CloseCurlyDoubleQuote]!", "Text",
 CellChangeTimes->{{3.837237009937067*^9, 3.837237020715063*^9}, {
  3.837237051315207*^9, 
  3.83723705432823*^9}},ExpressionUUID->"aa8d77a8-2c29-4c07-84b8-\
4ec88bdb64b9"],

Cell["\<\
The Function \"OperatorsNonEqualMass[l]\" computes the necessary Picard-Fuchs \
operators to describe the homogeneous differential ideal of the l-loop \
generic mass banana integral in D = 2 - 2 \[Epsilon] .\
\>", "Text",
 CellChangeTimes->{{3.8376783627432528`*^9, 3.8376784171097527`*^9}, 
   3.8376790505779457`*^9},ExpressionUUID->"60d4d29a-c901-493f-a1fd-\
25cb9562a518"],

Cell[TextData[{
 "With ",
 Cell[BoxData[
  FormBox["\"\<OperatorsGenericMass[l,\!\(
\*SubscriptBox[\(deg\), \(z\)]\),\!\(
\*SubscriptBox[\(ord\), \(\[Theta]\)]\)\>", TraditionalForm]],
  FormatType->TraditionalForm,ExpressionUUID->
  "ff748a98-c363-4c4d-ba9f-8ad0f4e2a5da"],
 "]\[CloseCurlyDoubleQuote] one can compute all operators as described in \
Section 5.2 in our paper. Here l stands for the loop order, ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["ord", "\[Theta]"], TraditionalForm]],
  FormatType->TraditionalForm,ExpressionUUID->
  "0133d103-d8a2-45e4-9b3a-765ea7ab893e"],
 " is the upper bound of the multi-order of the operators in the variables ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["z", "i"], TraditionalForm]],
  FormatType->TraditionalForm,ExpressionUUID->
  "78dfe524-8d65-4531-918b-cb9ab5057e86"],
 " and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["deg", "z"], TraditionalForm]],
  FormatType->TraditionalForm,ExpressionUUID->
  "72e6f4c1-9988-4307-87cb-120285302fdf"],
 " is the upper bound of the multi-degree of the polynomials in front of the \
derivatives. In \[OpenCurlyDoubleQuote]OperatorsNonEqualMass[l]\
\[CloseCurlyDoubleQuote] these values are given by ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["ord", "\[Theta]"], TraditionalForm]],ExpressionUUID->
  "05864ea6-2eb3-4a64-b899-d65a301b7384"],
 "=l and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["deg", "z"], TraditionalForm]],ExpressionUUID->
  "75bee1e2-b630-4ac2-bba8-9359e46a23f5"],
 "=1."
}], "Text",
 CellChangeTimes->{{3.8376785077170877`*^9, 3.837678642268983*^9}, {
  3.837678691127445*^9, 3.837678820075452*^9}, {3.8376788505514402`*^9, 
  3.837678922248219*^9}, {3.8376789576182117`*^9, 3.8376789703082523`*^9}, {
  3.837679036728858*^9, 
  3.837679080232932*^9}},ExpressionUUID->"ffa1b902-9928-4d53-afe1-\
d81dcdca952d"],

Cell[CellGroupData[{

Cell["Necessary Functions", "Section",
 CellChangeTimes->{{3.837228303658607*^9, 
  3.837228306516485*^9}},ExpressionUUID->"2f5a02a2-bba2-4ee1-8299-\
a45de99e01a5"],

Cell[BoxData[
 RowBox[{"Clear", "[", 
  RowBox[{
  "\[CapitalTheta]D1", ",", "\[CapitalTheta]D1m", ",", "Diffoptheta", ",", 
   "ThetaDiffop", ",", "FallingFactorial", ",", "OperatorsGenericMass", ",", 
   "OperatorsNonEqualMass"}], "]"}]], "Input",
 CellChangeTimes->{{3.824805395048574*^9, 3.824805398787952*^9}, 
   3.824805527816263*^9, {3.824805588816475*^9, 3.824805601277424*^9}, {
   3.837228442049926*^9, 3.837228473998996*^9}, {3.8372285134068747`*^9, 
   3.8372285404446287`*^9}, {3.837228580391715*^9, 3.837228580539954*^9}, {
   3.837677711712716*^9, 3.8376777146897287`*^9}, {3.837677823511407*^9, 
   3.837677823681654*^9}},
 CellLabel->"In[63]:=",ExpressionUUID->"3391a588-1ee2-404b-a439-0450a6259916"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"\[CapitalTheta]D1", "[", "t_", "]"}], ":=", 
   RowBox[{
    RowBox[{"t", " ", 
     RowBox[{"D", "[", 
      RowBox[{"#", ",", "t"}], "]"}]}], "&"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[CapitalTheta]D1m", "[", 
    RowBox[{"t_", ",", "m_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", "hi", "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"hi", "=", "#"}], ";", "\[IndentingNewLine]", 
       RowBox[{"Do", "[", 
        RowBox[{
         RowBox[{"hi", "=", 
          RowBox[{
           RowBox[{"\[CapitalTheta]D1", "[", "t", "]"}], "[", "hi", "]"}]}], 
         ",", 
         RowBox[{"{", 
          RowBox[{"k", ",", "0", ",", 
           RowBox[{"m", "-", "1"}]}], "}"}]}], "]"}], ";", 
       "\[IndentingNewLine]", "hi"}]}], "]"}], "&"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Diffoptheta", "[", "LList__", "]"}], ":=", 
   RowBox[{
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"hi", ",", "hii"}], "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"hii", "=", "LList"}], ";", "\[IndentingNewLine]", 
       RowBox[{"hi", "=", 
        RowBox[{
         RowBox[{"ReplaceAll", "[", 
          RowBox[{"#2", ",", 
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
              "hii", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], 
              "\[Rule]", 
              SubscriptBox["XX", "i"]}], ",", 
             RowBox[{"{", 
              RowBox[{"i", ",", 
               RowBox[{"Length", "[", "hii", "]"}]}], "}"}]}], "]"}]}], "]"}],
          "*", "#1"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"Do", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"hi", "=", 
           RowBox[{"CoefficientList", "[", 
            RowBox[{"hi", ",", 
             SubscriptBox["\[Theta]", "l"]}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"hi", "=", 
           RowBox[{"Expand", "[", 
            RowBox[{"Sum", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"\[CapitalTheta]D1m", "[", 
                RowBox[{
                 RowBox[{
                 "hii", "\[LeftDoubleBracket]", "l", 
                  "\[RightDoubleBracket]"}], ",", 
                 RowBox[{"k", "-", "1"}]}], "]"}], "[", 
               RowBox[{"hi", "[", 
                RowBox[{"[", "k", "]"}], "]"}], "]"}], ",", 
              RowBox[{"{", 
               RowBox[{"k", ",", "1", ",", 
                RowBox[{"Length", "[", "hi", "]"}]}], "}"}]}], "]"}], 
            "]"}]}]}], ",", 
         RowBox[{"{", 
          RowBox[{"l", ",", "1", ",", 
           RowBox[{"Length", "[", "hii", "]"}]}], "}"}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"ReplaceAll", "[", 
        RowBox[{"hi", ",", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{
            SubscriptBox["XX", "i"], "->", 
            RowBox[{
            "hii", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]}], 
           ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", 
             RowBox[{"Length", "[", "hii", "]"}]}], "}"}]}], "]"}]}], 
        "]"}]}]}], "]"}], "&"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ThetaDiffop", "[", 
    RowBox[{"f_", ",", "LList__"}], "]"}], ":=", 
   RowBox[{
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "hi", ",", "hii", ",", "maxdiff", ",", "khilf", ",", "listehilf"}], 
       "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"hi", "=", "#"}], ";", "\[IndentingNewLine]", 
       RowBox[{"hii", "=", 
        RowBox[{"LList", "//", "Length"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"maxdiff", "=", 
        RowBox[{"Max", "[", 
         RowBox[{"Cases", "[", 
          RowBox[{
           RowBox[{"hi", "*", "khilf"}], ",", 
           RowBox[{
            RowBox[{
             RowBox[{
              SuperscriptBox["f", 
               TagBox[
                RowBox[{"(", "order__", ")"}],
                Derivative],
               MultilineFunction->None], "@@", "LList"}], "\[RuleDelayed]", 
             "order"}], "/.", 
            RowBox[{"khilf", "\[Rule]", "1"}]}], ",", "Infinity"}], "]"}], 
         "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"maxdiff", "=", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"maxdiff", "\[Equal]", 
           RowBox[{"-", "\[Infinity]"}]}], ",", "0", ",", "maxdiff"}], 
         "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"listehilf", "=", 
        RowBox[{"Flatten", "[", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"D", "[", 
             RowBox[{
              RowBox[{"f", "@@", "LList"}], ",", 
              RowBox[{"Sequence", "@@", 
               RowBox[{"Table", "[", 
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{
                   "LList", "\[LeftDoubleBracket]", "j", 
                    "\[RightDoubleBracket]"}], ",", 
                   SubscriptBox["n", "j"]}], "}"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"j", ",", "1", ",", "hii"}], "}"}]}], "]"}]}]}], 
             "]"}], "\[Rule]", 
            RowBox[{"Product", "[", 
             RowBox[{
              RowBox[{
               FractionBox["1", 
                SuperscriptBox[
                 RowBox[{
                 "LList", "\[LeftDoubleBracket]", "i", 
                  "\[RightDoubleBracket]"}], 
                 SubscriptBox["n", "i"]]], 
               RowBox[{"Product", "[", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   SubscriptBox["\[Theta]", "i"], "-", "r"}], ")"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"r", ",", "0", ",", 
                   RowBox[{
                    SubscriptBox["n", "i"], "-", "1"}]}], "}"}]}], "]"}]}], 
              ",", 
              RowBox[{"{", 
               RowBox[{"i", ",", "1", ",", "hii"}], "}"}]}], "]"}]}], ",", 
           RowBox[{"Evaluate", "[", 
            RowBox[{"Sequence", "@@", 
             RowBox[{"Table", "[", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{
                 SubscriptBox["n", "k"], ",", "0", ",", "maxdiff"}], "}"}], 
               ",", 
               RowBox[{"{", 
                RowBox[{"k", ",", "1", ",", "hii"}], "}"}]}], "]"}]}], 
            "]"}]}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"ReplaceAll", "[", 
         RowBox[{"hi", ",", "listehilf"}], "]"}], "//", "Expand"}]}]}], "]"}],
     "&"}]}], ";"}]}], "Input",
 CellChangeTimes->{
  3.822711122962096*^9, {3.822711153360466*^9, 3.822711159818063*^9}, {
   3.822711648309795*^9, 3.8227117278163033`*^9}, 3.822711919016674*^9, {
   3.8227119530040283`*^9, 3.822711979262253*^9}, {3.822712040129524*^9, 
   3.822712055179718*^9}, {3.822712094938733*^9, 3.8227120986288023`*^9}, {
   3.822712136924954*^9, 3.822712186640397*^9}, {3.822712234072877*^9, 
   3.8227122699720488`*^9}, {3.8227123352502127`*^9, 3.822712338531443*^9}, {
   3.822712698427964*^9, 3.822712702245545*^9}, {3.822712839296855*^9, 
   3.822712927962576*^9}, {3.822712966371402*^9, 3.822712998277327*^9}, {
   3.8235764811024227`*^9, 3.823576492207881*^9}, {3.823576670711665*^9, 
   3.823576673976061*^9}, 3.837228465587461*^9},
 CellLabel->"In[64]:=",ExpressionUUID->"86e6ce61-0bb3-4721-90cb-29727bfc3106"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"FallingFactorial", "[", 
    RowBox[{"n_", ",", "m_"}], "]"}], "=", 
   RowBox[{"Product", "[", 
    RowBox[{
     RowBox[{"n", "-", "k"}], ",", 
     RowBox[{"{", 
      RowBox[{"k", ",", "0", ",", 
       RowBox[{"m", "-", "1"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"OperatorsGenericMass", "[", 
    RowBox[{"loop_", ",", "degreez_", ",", "degree\[Theta]_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{"OperatorsGenericMass", "[", 
     RowBox[{"loop", ",", "degreez", ",", "degree\[Theta]"}], "]"}], "=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "hi", ",", "hii", ",", "list\[Theta]", ",", "list\[Theta]z", ",", 
        "listz", ",", "lista0", ",", "listall", ",", "$l", ",", "$j", ",", 
        "$s", ",", "nn"}], "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"$l", "=", 
        RowBox[{"loop", "+", "1"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"$j", "=", "degree\[Theta]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"$s", "=", "degreez"}], ";", "\[IndentingNewLine]", 
       RowBox[{"nn", "=", 
        RowBox[{"Sum", "[", 
         RowBox[{
          SubscriptBox["n", "i"], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "$l"}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"listeall", "=", 
        RowBox[{
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{"Product", "[", 
               RowBox[{
                SuperscriptBox[
                 SubscriptBox["\[Theta]", "i"], 
                 SubscriptBox["j", "i"]], ",", 
                RowBox[{"{", 
                 RowBox[{"i", ",", "$l"}], "}"}]}], "]"}], 
              RowBox[{"Product", "[", 
               RowBox[{
                SuperscriptBox[
                 SubscriptBox["z", "r"], 
                 SubscriptBox["s", "r"]], ",", 
                RowBox[{"{", 
                 RowBox[{"r", ",", "$l"}], "}"}]}], "]"}]}], ",", 
             RowBox[{
              RowBox[{"Product", "[", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    SubscriptBox["n", "i"], "-", 
                    SubscriptBox["s", "i"], "+", "\[Epsilon]"}], ")"}], 
                  SubscriptBox["j", "i"]], 
                 RowBox[{"FallingFactorial", "[", 
                  RowBox[{
                   SubscriptBox["n", "i"], ",", 
                   SubscriptBox["s", "i"]}], "]"}], 
                 RowBox[{"FallingFactorial", "[", 
                  RowBox[{
                   RowBox[{
                    SubscriptBox["n", "i"], "+", "\[Epsilon]"}], ",", 
                   SubscriptBox["s", "i"]}], "]"}]}], ",", 
                RowBox[{"{", 
                 RowBox[{"i", ",", "$l"}], "}"}]}], "]"}], 
              FractionBox[
               RowBox[{
                RowBox[{"FallingFactorial", "[", 
                 RowBox[{
                  RowBox[{"nn", "+", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"$l", "-", "1"}], ")"}], " ", "\[Epsilon]"}]}], 
                  ",", "$s"}], "]"}], 
                RowBox[{"FallingFactorial", "[", 
                 RowBox[{
                  RowBox[{"nn", "+", 
                   RowBox[{"$l", " ", "\[Epsilon]"}]}], ",", "$s"}], "]"}]}], 
               
               RowBox[{
                RowBox[{"FallingFactorial", "[", 
                 RowBox[{
                  RowBox[{"nn", "+", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"$l", "-", "1"}], ")"}], " ", "\[Epsilon]"}]}], 
                  ",", 
                  RowBox[{"Sum", "[", 
                   RowBox[{
                    SubscriptBox["s", "i"], ",", 
                    RowBox[{"{", 
                    RowBox[{"i", ",", "$l"}], "}"}]}], "]"}]}], "]"}], 
                RowBox[{"FallingFactorial", "[", 
                 RowBox[{
                  RowBox[{"nn", "+", 
                   RowBox[{"$l", " ", "\[Epsilon]"}]}], ",", 
                  RowBox[{"Sum", "[", 
                   RowBox[{
                    SubscriptBox["s", "i"], ",", 
                    RowBox[{"{", 
                    RowBox[{"i", ",", "$l"}], "}"}]}], "]"}]}], "]"}]}]]}]}], 
            "}"}], ",", 
           RowBox[{"Evaluate", "[", 
            RowBox[{"Sequence", "@@", 
             RowBox[{"Table", "[", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{
                 SubscriptBox["j", "i"], ",", "0", ",", 
                 RowBox[{"$j", "-", 
                  RowBox[{"Sum", "[", 
                   RowBox[{
                    SubscriptBox["j", "r"], ",", 
                    RowBox[{"{", 
                    RowBox[{"r", ",", 
                    RowBox[{"i", "-", "1"}]}], "}"}]}], "]"}]}]}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"i", ",", "$l"}], "}"}]}], "]"}]}], "]"}], ",", 
           RowBox[{"Evaluate", "[", 
            RowBox[{"Sequence", "@@", 
             RowBox[{"Table", "[", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{
                 SubscriptBox["s", "r"], ",", "0", ",", 
                 RowBox[{"$s", "-", 
                  RowBox[{"Sum", "[", 
                   RowBox[{
                    SubscriptBox["s", "i"], ",", 
                    RowBox[{"{", 
                    RowBox[{"i", ",", 
                    RowBox[{"r", "-", "1"}]}], "}"}]}], "]"}]}]}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"r", ",", "$l"}], "}"}]}], "]"}]}], "]"}]}], "]"}], "//",
          "Flatten"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"listeall", "=", 
        RowBox[{
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"listeall", "\[LeftDoubleBracket]", 
              RowBox[{
               RowBox[{"2", "k"}], "-", "1"}], "\[RightDoubleBracket]"}], ",", 
             RowBox[{"listeall", "\[LeftDoubleBracket]", 
              RowBox[{"2", "k"}], "\[RightDoubleBracket]"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"k", ",", "1", ",", 
             RowBox[{
              RowBox[{"Length", "[", "listeall", "]"}], "/", "2"}]}], "}"}]}],
           "]"}], "//", 
         RowBox[{
          RowBox[{"DeleteDuplicatesBy", "[", 
           RowBox[{"#", ",", "First"}], "]"}], "&"}]}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"hi", "=", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"Sum", "[", 
            RowBox[{
             RowBox[{
              SubscriptBox["a", "r"], 
              RowBox[{"listeall", "\[LeftDoubleBracket]", 
               RowBox[{"r", ",", "2"}], "\[RightDoubleBracket]"}]}], ",", 
             RowBox[{"{", 
              RowBox[{"r", ",", 
               RowBox[{"Length", "[", "listeall", "]"}]}], "}"}]}], "]"}], "//", 
           RowBox[{
            RowBox[{"CoefficientList", "[", 
             RowBox[{"#", ",", 
              RowBox[{"Table", "[", 
               RowBox[{
                SubscriptBox["n", "r"], ",", 
                RowBox[{"{", 
                 RowBox[{"r", ",", "$l"}], "}"}]}], "]"}]}], "]"}], "&"}]}], "//",
           "Flatten"}], "//", 
         RowBox[{
          RowBox[{"DeleteCases", "[", 
           RowBox[{"#", ",", "0"}], "]"}], "&"}]}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"hi", "=", 
        RowBox[{
         RowBox[{"Solve", "[", 
          RowBox[{
           RowBox[{"hi", "\[Equal]", "0"}], ",", 
           RowBox[{"Table", "[", 
            RowBox[{
             SubscriptBox["a", "r"], ",", 
             RowBox[{"{", 
              RowBox[{"r", ",", 
               RowBox[{"Length", "[", "listeall", "]"}]}], "}"}]}], "]"}]}], 
          "]"}], "//", "Expand"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"hi", "=", 
        RowBox[{
         RowBox[{
          RowBox[{"Sum", "[", 
           RowBox[{
            RowBox[{
             SubscriptBox["a", "r"], 
             RowBox[{"listeall", "\[LeftDoubleBracket]", 
              RowBox[{"r", ",", "1"}], "\[RightDoubleBracket]"}]}], ",", 
            RowBox[{"{", 
             RowBox[{"r", ",", 
              RowBox[{"Length", "[", "listeall", "]"}]}], "}"}]}], "]"}], "/.", 
          RowBox[{"Flatten", "[", "hi", "]"}]}], "//", "Expand"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"hii", "=", 
        RowBox[{
         RowBox[{
          RowBox[{"hi", "//", 
           RowBox[{
            RowBox[{"Table", "[", 
             RowBox[{
              RowBox[{"Coefficient", "[", 
               RowBox[{"#", ",", 
                SubscriptBox["a", "k"]}], "]"}], ",", 
              RowBox[{"{", 
               RowBox[{"k", ",", 
                RowBox[{"Length", "[", "listeall", "]"}]}], "}"}]}], "]"}], 
            "&"}]}], "//", "Flatten"}], "//", 
         RowBox[{
          RowBox[{"DeleteCases", "[", 
           RowBox[{"#", ",", "0"}], "]"}], "&"}]}]}], ";", 
       "\[IndentingNewLine]", "hii"}]}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"OperatorsNonEqualMass", "[", "l_", "]"}], ":=", 
   RowBox[{"OperatorsGenericMass", "[", 
    RowBox[{"l", ",", "1", ",", "l"}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.8245276541167192`*^9, 3.824527710704406*^9}, {
   3.8245277555021563`*^9, 3.824527775686351*^9}, {3.824527844470414*^9, 
   3.824528075240706*^9}, {3.824528115868308*^9, 3.82452843098037*^9}, {
   3.824528485914857*^9, 3.824528511417272*^9}, {3.824528582542335*^9, 
   3.8245285903723516`*^9}, {3.82452869711519*^9, 3.824528702931274*^9}, {
   3.824528762092718*^9, 3.824528765092739*^9}, {3.824528829791144*^9, 
   3.8245288726203136`*^9}, {3.824528924259413*^9, 3.824529080683627*^9}, {
   3.824529458954918*^9, 3.8245294869559107`*^9}, {3.824531018737068*^9, 
   3.8245311365257072`*^9}, {3.824531181987896*^9, 3.8245311846866617`*^9}, {
   3.824532606084846*^9, 3.8245326115509663`*^9}, {3.824532701781253*^9, 
   3.824532772531515*^9}, {3.824532826364099*^9, 3.824532887599258*^9}, {
   3.8245329190167923`*^9, 3.824532919628553*^9}, {3.824532991101776*^9, 
   3.8245330387119913`*^9}, {3.824533098103292*^9, 3.824533188826282*^9}, {
   3.824533242860318*^9, 3.824533247226947*^9}, {3.8245333199696217`*^9, 
   3.8245334132455063`*^9}, {3.824533450809816*^9, 3.8245334973746347`*^9}, {
   3.824533564650758*^9, 3.8245336139386063`*^9}, {3.824533701183714*^9, 
   3.824533767110351*^9}, {3.824533873325347*^9, 3.824533892944743*^9}, {
   3.824534797205471*^9, 3.8245347983690023`*^9}, 3.824535580205475*^9, {
   3.824545526512022*^9, 3.824545548190961*^9}, 3.8245455934308367`*^9, {
   3.8245456661640244`*^9, 3.824545692353443*^9}, {3.824545737266576*^9, 
   3.824545789522902*^9}, {3.824545827348641*^9, 3.824545830947548*^9}, {
   3.824545903569607*^9, 3.8245459042772503`*^9}, {3.824545950161209*^9, 
   3.824546037291527*^9}, {3.824546071133944*^9, 3.824546110149781*^9}, {
   3.8245464940920143`*^9, 3.82454649654426*^9}, {3.824546569874984*^9, 
   3.8245465982711897`*^9}, {3.824546635196267*^9, 3.8245466416857367`*^9}, {
   3.824546714972139*^9, 3.824546718109679*^9}, {3.824546799642479*^9, 
   3.824546843643662*^9}, {3.824546982047303*^9, 3.8245470258208323`*^9}, {
   3.824547057560499*^9, 3.8245470956411333`*^9}, 3.8245471366597633`*^9, {
   3.8245472064374533`*^9, 3.8245473142027197`*^9}, 3.824547471202012*^9, {
   3.824547523594899*^9, 3.824547537624216*^9}, {3.824547607870802*^9, 
   3.824547643465822*^9}, {3.824547989415092*^9, 3.8245480038617783`*^9}, {
   3.824548037567465*^9, 3.824548040975525*^9}, {3.824548183279437*^9, 
   3.824548186317361*^9}, {3.82455119095654*^9, 3.8245512287787743`*^9}, {
   3.8245512735927963`*^9, 3.824551275905478*^9}, 3.824551486779292*^9, 
   3.824551565231152*^9, {3.824551642880825*^9, 3.8245516835598383`*^9}, {
   3.8245517338273983`*^9, 3.824551775472795*^9}, {3.824551832606514*^9, 
   3.824551840588773*^9}, {3.824551879057797*^9, 3.824551905312046*^9}, {
   3.824551965039357*^9, 3.824552002377157*^9}, {3.824552326653242*^9, 
   3.824552328283122*^9}, {3.824552378075193*^9, 3.824552378288761*^9}, {
   3.824552410522317*^9, 3.824552414136819*^9}, {3.824552489059648*^9, 
   3.824552493896661*^9}, {3.8245525471113586`*^9, 3.824552573585258*^9}, {
   3.824552606905983*^9, 3.8245526250180693`*^9}, {3.824552767670245*^9, 
   3.8245527677596693`*^9}, {3.824552799193521*^9, 3.824552839512814*^9}, {
   3.824552894257271*^9, 3.824552950890483*^9}, {3.824553018110327*^9, 
   3.8245530356482487`*^9}, {3.82455307684731*^9, 3.824553106367756*^9}, {
   3.824556113046752*^9, 3.8245561269543457`*^9}, {3.824556465989777*^9, 
   3.824556500335795*^9}, 3.8245565538310003`*^9, {3.824786263950593*^9, 
   3.824786334251483*^9}, {3.82478669475345*^9, 3.8247867067785482`*^9}, {
   3.824786740762912*^9, 3.824786841756201*^9}, {3.824786914363021*^9, 
   3.824786929520053*^9}, 3.837228537244541*^9, {3.837677684956523*^9, 
   3.8376776924240294`*^9}, {3.8376777232646923`*^9, 3.8376777994750443`*^9}},
 
 CellLabel->"In[68]:=",ExpressionUUID->"608cfe77-7767-416e-bf69-4b7cb0e8b46f"]
}, Closed]],

Cell[CellGroupData[{

Cell["Some Examples", "Section",
 CellChangeTimes->{{3.837228623693796*^9, 
  3.8372286254487553`*^9}},ExpressionUUID->"1a6dc5ff-9852-478b-82e4-\
252de3737e41"],

Cell[CellGroupData[{

Cell["l=2", "Subsubsection",
 CellChangeTimes->{{3.837228632311771*^9, 
  3.837228632975037*^9}},ExpressionUUID->"2ab9371e-4028-48d9-8025-\
6988568ca47c"],

Cell["Computes all necessary operators for l=2:", "Text",
 CellChangeTimes->{{3.83767784268156*^9, 3.837677930184064*^9}, {
  3.8376782876998053`*^9, 3.8376782882967367`*^9}, {3.837678458938019*^9, 
  3.837678461209503*^9}},ExpressionUUID->"6b1ec49f-26a8-4c1a-985b-\
85a920751e4b"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"OperatorsNonEqualMass", "[", "2", "]"}], "//", "Simplify"}], "//",
   "TableForm"}], "\[IndentingNewLine]", 
 RowBox[{"%", "//", "Length"}]}], "Input",
 CellChangeTimes->{{3.8376779444630003`*^9, 3.837678043158977*^9}, {
  3.8376781986125937`*^9, 3.837678200120821*^9}},
 CellLabel->"In[82]:=",ExpressionUUID->"dbcb596b-ff90-44b1-9af7-eb7ec45b4ad4"],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {
      RowBox[{
       RowBox[{
        SubscriptBox["\[Theta]", "3"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "\[Epsilon]"}], "+", 
          SubscriptBox["\[Theta]", "3"]}], ")"}]}], "+", 
       RowBox[{
        SubscriptBox["z", "3"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "\[Epsilon]", "-", 
          SubscriptBox["\[Theta]", "1"], "-", 
          SubscriptBox["\[Theta]", "2"], "-", 
          SubscriptBox["\[Theta]", "3"]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          SubscriptBox["\[Theta]", "1"], "+", 
          SubscriptBox["\[Theta]", "2"], "+", 
          SubscriptBox["\[Theta]", "3"]}], ")"}]}]}]},
     {
      RowBox[{
       RowBox[{
        SubscriptBox["z", "3"], " ", 
        RowBox[{"(", 
         RowBox[{"\[Epsilon]", "-", 
          SubscriptBox["\[Theta]", "2"]}], ")"}], " ", 
        SubscriptBox["\[Theta]", "2"]}], "+", 
       RowBox[{
        SubscriptBox["z", "2"], " ", 
        SubscriptBox["\[Theta]", "3"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "\[Epsilon]"}], "+", 
          SubscriptBox["\[Theta]", "3"]}], ")"}]}]}]},
     {
      RowBox[{
       RowBox[{
        SubscriptBox["z", "3"], " ", 
        RowBox[{"(", 
         RowBox[{"\[Epsilon]", "-", 
          SubscriptBox["\[Theta]", "1"]}], ")"}], " ", 
        SubscriptBox["\[Theta]", "1"]}], "+", 
       RowBox[{
        SubscriptBox["z", "1"], " ", 
        SubscriptBox["\[Theta]", "3"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "\[Epsilon]"}], "+", 
          SubscriptBox["\[Theta]", "3"]}], ")"}]}]}]},
     {
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         SubscriptBox["z", "1"]}], " ", 
        RowBox[{"(", 
         RowBox[{"\[Epsilon]", "-", 
          SubscriptBox["\[Theta]", "2"]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"\[Epsilon]", "-", 
          SubscriptBox["\[Theta]", "3"]}], ")"}]}], "-", 
       RowBox[{
        SubscriptBox["z", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "\[Epsilon]", "-", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Theta]", "1"]}], "-", 
          SubscriptBox["\[Theta]", "2"]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"\[Epsilon]", "-", 
          SubscriptBox["\[Theta]", "3"]}], ")"}]}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"\[Epsilon]", "-", 
          SubscriptBox["\[Theta]", "2"]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "\[Epsilon]"}], "+", 
          RowBox[{
           SubscriptBox["z", "3"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "\[Epsilon]", "-", 
             RowBox[{"2", " ", 
              SubscriptBox["\[Theta]", "1"]}], "-", 
             RowBox[{"2", " ", 
              SubscriptBox["\[Theta]", "2"]}], "-", 
             SubscriptBox["\[Theta]", "3"]}], ")"}]}], "+", 
          SubscriptBox["\[Theta]", "3"]}], ")"}]}]}]},
     {
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          SubscriptBox["z", "3"]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"\[Epsilon]", "-", 
          SubscriptBox["\[Theta]", "2"]}], ")"}], " ", 
        SubscriptBox["\[Theta]", "2"]}], "-", 
       RowBox[{
        SubscriptBox["z", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          SubscriptBox["\[Theta]", "1"], "+", 
          SubscriptBox["\[Theta]", "2"]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"1", "-", "\[Epsilon]", "+", 
          SubscriptBox["\[Theta]", "1"], "+", 
          SubscriptBox["\[Theta]", "2"], "+", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Theta]", "3"]}]}], ")"}]}]}]},
     {
      RowBox[{
       RowBox[{
        SubscriptBox["z", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"\[Epsilon]", "-", 
          SubscriptBox["\[Theta]", "1"]}], ")"}], " ", 
        SubscriptBox["\[Theta]", "1"]}], "+", 
       RowBox[{
        SubscriptBox["z", "1"], " ", 
        SubscriptBox["\[Theta]", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "\[Epsilon]"}], "+", 
          SubscriptBox["\[Theta]", "2"]}], ")"}]}]}]},
     {
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         SubscriptBox["z", "1"]}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "\[Epsilon]", "-", 
          SubscriptBox["\[Theta]", "1"], "-", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Theta]", "2"]}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"\[Epsilon]", "-", 
          SubscriptBox["\[Theta]", "3"]}], ")"}]}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"\[Epsilon]", "-", 
          SubscriptBox["\[Theta]", "1"]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "\[Epsilon]"}], "+", 
          RowBox[{
           SubscriptBox["z", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"\[Epsilon]", "-", 
             SubscriptBox["\[Theta]", "3"]}], ")"}]}], "+", 
          RowBox[{
           SubscriptBox["z", "3"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "\[Epsilon]", "-", 
             RowBox[{"2", " ", 
              SubscriptBox["\[Theta]", "1"]}], "-", 
             RowBox[{"2", " ", 
              SubscriptBox["\[Theta]", "2"]}], "-", 
             SubscriptBox["\[Theta]", "3"]}], ")"}]}], "+", 
          SubscriptBox["\[Theta]", "3"]}], ")"}]}]}]},
     {
      RowBox[{
       RowBox[{"-", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"\[Epsilon]", "-", 
            SubscriptBox["\[Theta]", "1"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", 
               SubscriptBox["z", "3"]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{"\[Epsilon]", "-", 
               SubscriptBox["\[Theta]", "2"]}], ")"}]}], "+", 
            RowBox[{
             SubscriptBox["z", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "\[Epsilon]", "-", 
               RowBox[{"2", " ", 
                SubscriptBox["\[Theta]", "1"]}], "-", 
               SubscriptBox["\[Theta]", "2"], "-", 
               RowBox[{"2", " ", 
                SubscriptBox["\[Theta]", "3"]}]}], ")"}]}]}], ")"}]}], 
         ")"}]}], "-", 
       RowBox[{
        SubscriptBox["z", "1"], " ", 
        RowBox[{"(", 
         RowBox[{"\[Epsilon]", "-", 
          SubscriptBox["\[Theta]", "2"]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "\[Epsilon]", "-", 
          SubscriptBox["\[Theta]", "1"], "-", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Theta]", "3"]}]}], ")"}]}]}]},
     {
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          SubscriptBox["z", "2"], "+", 
          SubscriptBox["z", "3"]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"\[Epsilon]", "-", 
          SubscriptBox["\[Theta]", "1"]}], ")"}], " ", 
        SubscriptBox["\[Theta]", "1"]}], "+", 
       RowBox[{
        SubscriptBox["z", "1"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "\[Epsilon]", "-", 
          SubsuperscriptBox["\[Theta]", "1", "2"], "+", 
          RowBox[{
           SubscriptBox["\[Theta]", "1"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "2"}], "+", "\[Epsilon]", "-", 
             RowBox[{"2", " ", 
              SubscriptBox["\[Theta]", "2"]}], "-", 
             RowBox[{"2", " ", 
              SubscriptBox["\[Theta]", "3"]}]}], ")"}]}], "-", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Theta]", "3"]}], "-", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Theta]", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             SubscriptBox["\[Theta]", "3"]}], ")"}]}]}], ")"}]}]}]}
    },
    GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.5599999999999999]}, 
        Offset[0.27999999999999997`]}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}}],
   Column],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{{3.837677951745667*^9, 3.837678043666243*^9}, 
   3.837678200534234*^9},
 CellLabel->
  "Out[82]//TableForm=",ExpressionUUID->"f9a7caf9-ebf7-4ef9-9902-\
879a81663e32"],

Cell[BoxData["9"], "Output",
 CellChangeTimes->{{3.837677951745667*^9, 3.837678043666243*^9}, 
   3.837678200542472*^9},
 CellLabel->"Out[83]=",ExpressionUUID->"4ca20bf7-c180-4545-bb00-2e3f13b889b6"]
}, Open  ]],

Cell[BoxData["\[IndentingNewLine]"], "Input",
 CellChangeTimes->{
  3.8376778420228643`*^9},ExpressionUUID->"8ed53c50-b50c-482f-aaf1-\
d0b10d9b9c15"],

Cell[TextData[{
 "We can also choose other bounds on the order of the operators and the \
degree of the polynomial in front of the derivatives. For example, we can \
take still l=2 but now ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["deg", "z"], TraditionalForm]],
  FormatType->TraditionalForm,ExpressionUUID->
  "79232006-075a-4372-97d7-cbe01cb0cf7d"],
 "\[LessEqual]2 and ",
 Cell[BoxData[
  FormBox[
   RowBox[{" ", 
    RowBox[{
     SubscriptBox["ord", "\[Theta]"], "<=", "2"}]}], TraditionalForm]],
  FormatType->TraditionalForm,ExpressionUUID->
  "6b015a2d-236d-48f9-a6b8-1e1b838a0ec7"],
 ". Then we find:"
}], "Text",
 CellChangeTimes->{{3.837228677132165*^9, 3.837228718083098*^9}, {
  3.837228754218828*^9, 3.8372287545225058`*^9}, {3.8376780640935698`*^9, 
  3.837678187540554*^9}, {3.837678222731221*^9, 
  3.83767825181223*^9}},ExpressionUUID->"d2a7136d-7328-4b28-87e7-\
1b2d6527955c"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"OperatorsGenericMass", "[", 
   RowBox[{"2", ",", "2", ",", "2"}], "]"}], "//", 
  "Simplify"}], "\[IndentingNewLine]", 
 RowBox[{"%", "//", "Length"}]}], "Input",
 CellChangeTimes->{{3.837228669651752*^9, 3.837228670753717*^9}, {
  3.837228723934767*^9, 3.83722874984416*^9}, {3.837229130945356*^9, 
  3.837229134387401*^9}, {3.8372292342447557`*^9, 3.837229234876568*^9}, {
  3.837678191176303*^9, 3.837678192929996*^9}},
 CellLabel->"In[86]:=",ExpressionUUID->"2c1cb143-a79a-4ae8-97eb-e20ac00a207b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["\[Theta]", "3"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "\[Epsilon]"}], "+", 
       SubscriptBox["\[Theta]", "3"]}], ")"}]}], "-", 
    RowBox[{
     SubsuperscriptBox["z", "3", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"2", " ", "\[Epsilon]"}], "-", 
          SubscriptBox["\[Theta]", "3"]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"3", " ", "\[Epsilon]"}], "-", 
          RowBox[{"4", " ", 
           SubscriptBox["\[Theta]", "2"]}], "-", 
          SubscriptBox["\[Theta]", "3"]}], ")"}]}], "+", 
       RowBox[{"4", " ", 
        SubscriptBox["\[Theta]", "1"], " ", 
        RowBox[{"(", 
         RowBox[{"1", "-", 
          RowBox[{"2", " ", "\[Epsilon]"}], "+", 
          RowBox[{"3", " ", 
           SubscriptBox["\[Theta]", "2"]}], "+", 
          SubscriptBox["\[Theta]", "3"]}], ")"}]}]}], ")"}]}], "-", 
    RowBox[{
     SubscriptBox["z", "3"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{"2", " ", "\[Epsilon]"}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            RowBox[{"3", " ", "\[Epsilon]"}], "-", 
            RowBox[{"2", " ", 
             SubscriptBox["\[Theta]", "1"]}], "-", 
            RowBox[{"2", " ", 
             SubscriptBox["\[Theta]", "2"]}], "-", 
            RowBox[{"2", " ", 
             SubscriptBox["\[Theta]", "3"]}]}], ")"}]}], ")"}]}], "+", 
       RowBox[{
        SubscriptBox["z", "1"], " ", 
        RowBox[{"(", 
         RowBox[{"1", "-", 
          RowBox[{"5", " ", "\[Epsilon]"}], "+", 
          RowBox[{"6", " ", 
           SuperscriptBox["\[Epsilon]", "2"]}], "+", 
          SubsuperscriptBox["\[Theta]", "1", "2"], "+", 
          RowBox[{"4", " ", 
           SubscriptBox["\[Theta]", "3"]}], "-", 
          RowBox[{"14", " ", "\[Epsilon]", " ", 
           SubscriptBox["\[Theta]", "3"]}], "+", 
          RowBox[{"6", " ", 
           SubsuperscriptBox["\[Theta]", "3", "2"]}], "+", 
          RowBox[{
           SubscriptBox["\[Theta]", "1"], " ", 
           RowBox[{"(", 
            RowBox[{"2", "-", 
             RowBox[{"5", " ", "\[Epsilon]"}], "+", 
             RowBox[{"4", " ", 
              SubscriptBox["\[Theta]", "2"]}], "+", 
             RowBox[{"4", " ", 
              SubscriptBox["\[Theta]", "3"]}]}], ")"}]}], "+", 
          RowBox[{
           SubscriptBox["\[Theta]", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"4", "-", 
             RowBox[{"8", " ", "\[Epsilon]"}], "+", 
             RowBox[{"12", " ", 
              SubscriptBox["\[Theta]", "3"]}]}], ")"}]}]}], ")"}]}], "+", 
       RowBox[{
        SubscriptBox["z", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"1", "-", 
          RowBox[{"5", " ", "\[Epsilon]"}], "+", 
          RowBox[{"6", " ", 
           SuperscriptBox["\[Epsilon]", "2"]}], "+", 
          RowBox[{"6", " ", 
           SubsuperscriptBox["\[Theta]", "1", "2"]}], "+", 
          SubsuperscriptBox["\[Theta]", "2", "2"], "+", 
          RowBox[{"4", " ", 
           SubscriptBox["\[Theta]", "3"]}], "-", 
          RowBox[{"14", " ", "\[Epsilon]", " ", 
           SubscriptBox["\[Theta]", "3"]}], "+", 
          RowBox[{"6", " ", 
           SubsuperscriptBox["\[Theta]", "3", "2"]}], "+", 
          RowBox[{
           SubscriptBox["\[Theta]", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"2", "-", 
             RowBox[{"5", " ", "\[Epsilon]"}], "+", 
             RowBox[{"4", " ", 
              SubscriptBox["\[Theta]", "3"]}]}], ")"}]}], "+", 
          RowBox[{
           SubscriptBox["\[Theta]", "1"], " ", 
           RowBox[{"(", 
            RowBox[{"4", "-", 
             RowBox[{"14", " ", "\[Epsilon]"}], "+", 
             RowBox[{"4", " ", 
              SubscriptBox["\[Theta]", "2"]}], "+", 
             RowBox[{"12", " ", 
              SubscriptBox["\[Theta]", "3"]}]}], ")"}]}]}], ")"}]}]}], 
      ")"}]}]}], ",", 
   RowBox[{
    SubscriptBox["z", "3"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         SubscriptBox["z", "1"], "+", 
         SubscriptBox["z", "2"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"\[Epsilon]", "-", 
         SubscriptBox["\[Theta]", "3"]}], ")"}], " ", 
       SubscriptBox["\[Theta]", "3"]}], "+", 
      RowBox[{
       SubscriptBox["z", "3"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "\[Epsilon]", "-", 
            RowBox[{"2", " ", 
             SubscriptBox["\[Theta]", "2"]}], "-", 
            SubscriptBox["\[Theta]", "3"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            SubscriptBox["\[Theta]", "3"]}], ")"}]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["\[Theta]", "1"], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            SubscriptBox["\[Theta]", "2"], "+", 
            SubscriptBox["\[Theta]", "3"]}], ")"}]}]}], ")"}]}]}], ")"}]}], 
   ",", 
   RowBox[{
    SubscriptBox["z", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[Theta]", "3"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "\[Epsilon]"}], "+", 
         SubscriptBox["\[Theta]", "3"]}], ")"}]}], "+", 
      RowBox[{
       SubscriptBox["z", "3"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "\[Epsilon]", "-", 
         SubscriptBox["\[Theta]", "1"], "-", 
         SubscriptBox["\[Theta]", "2"], "-", 
         SubscriptBox["\[Theta]", "3"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         SubscriptBox["\[Theta]", "1"], "+", 
         SubscriptBox["\[Theta]", "2"], "+", 
         SubscriptBox["\[Theta]", "3"]}], ")"}]}]}], ")"}]}], ",", 
   RowBox[{
    SubscriptBox["z", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SubscriptBox["z", "3"], " ", 
       RowBox[{"(", 
        RowBox[{"\[Epsilon]", "-", 
         SubscriptBox["\[Theta]", "2"]}], ")"}], " ", 
       SubscriptBox["\[Theta]", "2"]}], "+", 
      RowBox[{
       SubscriptBox["z", "2"], " ", 
       SubscriptBox["\[Theta]", "3"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "\[Epsilon]"}], "+", 
         SubscriptBox["\[Theta]", "3"]}], ")"}]}]}], ")"}]}], ",", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "2"], " ", 
     SubscriptBox["z", "3"], " ", 
     RowBox[{"(", 
      RowBox[{"\[Epsilon]", "-", 
       SubscriptBox["\[Theta]", "1"]}], ")"}], " ", 
     SubscriptBox["\[Theta]", "1"]}], "+", 
    RowBox[{
     SubscriptBox["z", "1"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SubscriptBox["\[Theta]", "3"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "\[Epsilon]"}], "+", 
          SubscriptBox["\[Theta]", "3"]}], ")"}]}], "+", 
       RowBox[{
        SubscriptBox["z", "3"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "\[Epsilon]", "-", 
          SubscriptBox["\[Theta]", "1"], "-", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Theta]", "2"]}], "-", 
          SubscriptBox["\[Theta]", "3"]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          SubscriptBox["\[Theta]", "1"], "+", 
          SubscriptBox["\[Theta]", "3"]}], ")"}]}]}], ")"}]}]}], ",", 
   RowBox[{
    SubscriptBox["z", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SubscriptBox["z", "3"], " ", 
       RowBox[{"(", 
        RowBox[{"\[Epsilon]", "-", 
         SubscriptBox["\[Theta]", "1"]}], ")"}], " ", 
       SubscriptBox["\[Theta]", "1"]}], "+", 
      RowBox[{
       SubscriptBox["z", "1"], " ", 
       SubscriptBox["\[Theta]", "3"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "\[Epsilon]"}], "+", 
         SubscriptBox["\[Theta]", "3"]}], ")"}]}]}], ")"}]}], ",", 
   RowBox[{
    SubscriptBox["z", "1"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SubscriptBox["z", "3"], " ", 
       RowBox[{"(", 
        RowBox[{"\[Epsilon]", "-", 
         SubscriptBox["\[Theta]", "1"]}], ")"}], " ", 
       SubscriptBox["\[Theta]", "1"]}], "+", 
      RowBox[{
       SubscriptBox["z", "1"], " ", 
       SubscriptBox["\[Theta]", "3"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "\[Epsilon]"}], "+", 
         SubscriptBox["\[Theta]", "3"]}], ")"}]}]}], ")"}]}], ",", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "1"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         SubscriptBox["z", "3"]}], " ", 
        RowBox[{"(", 
         RowBox[{"\[Epsilon]", "-", 
          SubscriptBox["\[Theta]", "2"]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "3"}], "+", 
          RowBox[{"4", " ", "\[Epsilon]"}], "-", 
          RowBox[{"4", " ", 
           SubscriptBox["\[Theta]", "1"]}], "-", 
          RowBox[{"6", " ", 
           SubscriptBox["\[Theta]", "3"]}]}], ")"}]}], "-", 
       RowBox[{
        SubscriptBox["z", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "3"}], "+", 
          RowBox[{"4", " ", "\[Epsilon]"}], "-", 
          RowBox[{"4", " ", 
           SubscriptBox["\[Theta]", "1"]}], "-", 
          RowBox[{"6", " ", 
           SubscriptBox["\[Theta]", "2"]}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"\[Epsilon]", "-", 
          SubscriptBox["\[Theta]", "3"]}], ")"}]}]}], ")"}]}], "-", 
    RowBox[{
     SubsuperscriptBox["z", "1", "2"], " ", 
     RowBox[{"(", 
      RowBox[{"\[Epsilon]", "-", 
       SubscriptBox["\[Theta]", "2"]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"\[Epsilon]", "-", 
       SubscriptBox["\[Theta]", "3"]}], ")"}]}], "-", 
    RowBox[{
     SubsuperscriptBox["z", "2", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{"3", " ", "\[Epsilon]"}], "-", 
       RowBox[{"4", " ", 
        SubscriptBox["\[Theta]", "1"]}], "-", 
       SubscriptBox["\[Theta]", "2"]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"\[Epsilon]", "-", 
       SubscriptBox["\[Theta]", "3"]}], ")"}]}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"\[Epsilon]", "-", 
       SubscriptBox["\[Theta]", "2"]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "\[Epsilon]"}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"2", " ", "\[Epsilon]"}]}], ")"}], " ", 
        SubscriptBox["z", "3"]}], "+", 
       RowBox[{
        SubsuperscriptBox["z", "3", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"3", " ", "\[Epsilon]"}], "-", 
          RowBox[{"4", " ", 
           SubscriptBox["\[Theta]", "1"]}], "-", 
          SubscriptBox["\[Theta]", "3"]}], ")"}]}], "+", 
       SubscriptBox["\[Theta]", "3"]}], ")"}]}], "-", 
    RowBox[{
     SubscriptBox["z", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{"2", " ", "\[Epsilon]"}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"\[Epsilon]", "-", 
            SubscriptBox["\[Theta]", "3"]}], ")"}]}], ")"}]}], "+", 
       RowBox[{
        SubscriptBox["z", "3"], " ", 
        RowBox[{"(", 
         RowBox[{"2", "-", 
          RowBox[{"8", " ", "\[Epsilon]"}], "+", 
          RowBox[{"6", " ", 
           SuperscriptBox["\[Epsilon]", "2"]}], "+", 
          RowBox[{"12", " ", 
           SubsuperscriptBox["\[Theta]", "1", "2"]}], "+", 
          RowBox[{"4", " ", 
           SubsuperscriptBox["\[Theta]", "2", "2"]}], "+", 
          RowBox[{"5", " ", 
           SubscriptBox["\[Theta]", "3"]}], "-", 
          RowBox[{"12", " ", "\[Epsilon]", " ", 
           SubscriptBox["\[Theta]", "3"]}], "+", 
          RowBox[{"4", " ", 
           SubsuperscriptBox["\[Theta]", "3", "2"]}], "+", 
          RowBox[{"4", " ", 
           SubscriptBox["\[Theta]", "1"], " ", 
           RowBox[{"(", 
            RowBox[{"2", "-", 
             RowBox[{"5", " ", "\[Epsilon]"}], "+", 
             RowBox[{"3", " ", 
              SubscriptBox["\[Theta]", "2"]}], "+", 
             RowBox[{"3", " ", 
              SubscriptBox["\[Theta]", "3"]}]}], ")"}]}], "+", 
          RowBox[{
           SubscriptBox["\[Theta]", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"5", "-", 
             RowBox[{"12", " ", "\[Epsilon]"}], "+", 
             RowBox[{"6", " ", 
              SubscriptBox["\[Theta]", "3"]}]}], ")"}]}]}], ")"}]}]}], 
      ")"}]}]}], ",", 
   RowBox[{
    SubscriptBox["z", "3"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["z", "1"]}], " ", 
       RowBox[{"(", 
        RowBox[{"\[Epsilon]", "-", 
         SubscriptBox["\[Theta]", "2"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"\[Epsilon]", "-", 
         SubscriptBox["\[Theta]", "3"]}], ")"}]}], "-", 
      RowBox[{
       SubscriptBox["z", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "\[Epsilon]", "-", 
         RowBox[{"2", " ", 
          SubscriptBox["\[Theta]", "1"]}], "-", 
         SubscriptBox["\[Theta]", "2"], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["\[Theta]", "3"]}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"\[Epsilon]", "-", 
         SubscriptBox["\[Theta]", "3"]}], ")"}]}], "-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"\[Epsilon]", "-", 
         SubscriptBox["\[Theta]", "2"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "\[Epsilon]"}], "+", 
         RowBox[{
          SubscriptBox["z", "3"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "\[Epsilon]", "-", 
            RowBox[{"2", " ", 
             SubscriptBox["\[Theta]", "1"]}], "-", 
            SubscriptBox["\[Theta]", "3"]}], ")"}]}], "+", 
         SubscriptBox["\[Theta]", "3"]}], ")"}]}]}], ")"}]}], ",", 
   RowBox[{
    SubscriptBox["z", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["z", "1"]}], " ", 
       RowBox[{"(", 
        RowBox[{"\[Epsilon]", "-", 
         SubscriptBox["\[Theta]", "2"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"\[Epsilon]", "-", 
         SubscriptBox["\[Theta]", "3"]}], ")"}]}], "-", 
      RowBox[{
       SubscriptBox["z", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "\[Epsilon]", "-", 
         RowBox[{"2", " ", 
          SubscriptBox["\[Theta]", "1"]}], "-", 
         SubscriptBox["\[Theta]", "2"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"\[Epsilon]", "-", 
         SubscriptBox["\[Theta]", "3"]}], ")"}]}], "-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"\[Epsilon]", "-", 
         SubscriptBox["\[Theta]", "2"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "\[Epsilon]"}], "+", 
         RowBox[{
          SubscriptBox["z", "3"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "\[Epsilon]", "-", 
            RowBox[{"2", " ", 
             SubscriptBox["\[Theta]", "1"]}], "-", 
            RowBox[{"2", " ", 
             SubscriptBox["\[Theta]", "2"]}], "-", 
            SubscriptBox["\[Theta]", "3"]}], ")"}]}], "+", 
         SubscriptBox["\[Theta]", "3"]}], ")"}]}]}], ")"}]}], ",", 
   RowBox[{
    RowBox[{"2", " ", 
     SubscriptBox["z", "2"], " ", 
     SubscriptBox["z", "3"], " ", 
     RowBox[{"(", 
      RowBox[{"\[Epsilon]", "-", 
       SubscriptBox["\[Theta]", "1"]}], ")"}], " ", 
     SubscriptBox["\[Theta]", "1"]}], "-", 
    RowBox[{
     SubsuperscriptBox["z", "1", "2"], " ", 
     RowBox[{"(", 
      RowBox[{"\[Epsilon]", "-", 
       SubscriptBox["\[Theta]", "2"]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"\[Epsilon]", "-", 
       SubscriptBox["\[Theta]", "3"]}], ")"}]}], "+", 
    RowBox[{
     SubscriptBox["z", "1"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         SubscriptBox["z", "2"]}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "\[Epsilon]", "-", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Theta]", "1"]}], "-", 
          SubscriptBox["\[Theta]", "2"]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"\[Epsilon]", "-", 
          SubscriptBox["\[Theta]", "3"]}], ")"}]}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"\[Epsilon]", "-", 
          SubscriptBox["\[Theta]", "2"]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "\[Epsilon]"}], "+", 
          RowBox[{
           SubscriptBox["z", "3"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "\[Epsilon]", "-", 
             RowBox[{"2", " ", 
              SubscriptBox["\[Theta]", "1"]}], "-", 
             SubscriptBox["\[Theta]", "3"]}], ")"}]}], "+", 
          SubscriptBox["\[Theta]", "3"]}], ")"}]}]}], ")"}]}]}], ",", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[Theta]", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "\[Epsilon]"}], "+", 
       SubscriptBox["\[Theta]", "2"]}], ")"}]}], "-", 
    RowBox[{
     SubsuperscriptBox["z", "2", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"2", " ", "\[Epsilon]"}], "-", 
          SubscriptBox["\[Theta]", "2"]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"3", " ", "\[Epsilon]"}], "-", 
          SubscriptBox["\[Theta]", "2"], "-", 
          RowBox[{"4", " ", 
           SubscriptBox["\[Theta]", "3"]}]}], ")"}]}], "+", 
       RowBox[{"4", " ", 
        SubscriptBox["\[Theta]", "1"], " ", 
        RowBox[{"(", 
         RowBox[{"1", "-", 
          RowBox[{"2", " ", "\[Epsilon]"}], "+", 
          SubscriptBox["\[Theta]", "2"], "+", 
          RowBox[{"3", " ", 
           SubscriptBox["\[Theta]", "3"]}]}], ")"}]}]}], ")"}]}], "-", 
    RowBox[{
     SubscriptBox["z", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{"2", " ", "\[Epsilon]"}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            RowBox[{"3", " ", "\[Epsilon]"}], "-", 
            RowBox[{"2", " ", 
             SubscriptBox["\[Theta]", "1"]}], "-", 
            RowBox[{"2", " ", 
             SubscriptBox["\[Theta]", "2"]}], "-", 
            RowBox[{"2", " ", 
             SubscriptBox["\[Theta]", "3"]}]}], ")"}]}], ")"}]}], "+", 
       RowBox[{
        SubscriptBox["z", "3"], " ", 
        RowBox[{"(", 
         RowBox[{"1", "-", 
          RowBox[{"5", " ", "\[Epsilon]"}], "+", 
          RowBox[{"6", " ", 
           SuperscriptBox["\[Epsilon]", "2"]}], "+", 
          RowBox[{"6", " ", 
           SubsuperscriptBox["\[Theta]", "1", "2"]}], "+", 
          RowBox[{"6", " ", 
           SubsuperscriptBox["\[Theta]", "2", "2"]}], "+", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Theta]", "3"]}], "-", 
          RowBox[{"5", " ", "\[Epsilon]", " ", 
           SubscriptBox["\[Theta]", "3"]}], "+", 
          SubsuperscriptBox["\[Theta]", "3", "2"], "+", 
          RowBox[{
           SubscriptBox["\[Theta]", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"4", "-", 
             RowBox[{"14", " ", "\[Epsilon]"}], "+", 
             RowBox[{"4", " ", 
              SubscriptBox["\[Theta]", "3"]}]}], ")"}]}], "+", 
          RowBox[{
           SubscriptBox["\[Theta]", "1"], " ", 
           RowBox[{"(", 
            RowBox[{"4", "-", 
             RowBox[{"14", " ", "\[Epsilon]"}], "+", 
             RowBox[{"12", " ", 
              SubscriptBox["\[Theta]", "2"]}], "+", 
             RowBox[{"4", " ", 
              SubscriptBox["\[Theta]", "3"]}]}], ")"}]}]}], ")"}]}], "+", 
       RowBox[{
        SubscriptBox["z", "1"], " ", 
        RowBox[{"(", 
         RowBox[{
          SubsuperscriptBox["\[Theta]", "1", "2"], "+", 
          RowBox[{"6", " ", 
           SubsuperscriptBox["\[Theta]", "2", "2"]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             RowBox[{"2", " ", "\[Epsilon]"}]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             RowBox[{"3", " ", "\[Epsilon]"}], "-", 
             RowBox[{"4", " ", 
              SubscriptBox["\[Theta]", "3"]}]}], ")"}]}], "+", 
          RowBox[{
           SubscriptBox["\[Theta]", "1"], " ", 
           RowBox[{"(", 
            RowBox[{"2", "-", 
             RowBox[{"5", " ", "\[Epsilon]"}], "+", 
             RowBox[{"4", " ", 
              SubscriptBox["\[Theta]", "2"]}], "+", 
             RowBox[{"4", " ", 
              SubscriptBox["\[Theta]", "3"]}]}], ")"}]}], "+", 
          RowBox[{
           SubscriptBox["\[Theta]", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"4", "-", 
             RowBox[{"14", " ", "\[Epsilon]"}], "+", 
             RowBox[{"12", " ", 
              SubscriptBox["\[Theta]", "3"]}]}], ")"}]}]}], ")"}]}]}], 
      ")"}]}]}], ",", 
   RowBox[{
    SubscriptBox["z", "3"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[Theta]", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "\[Epsilon]"}], "+", 
         SubscriptBox["\[Theta]", "2"]}], ")"}]}], "+", 
      RowBox[{
       SubscriptBox["z", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "\[Epsilon]", "-", 
         SubscriptBox["\[Theta]", "1"], "-", 
         SubscriptBox["\[Theta]", "2"], "-", 
         SubscriptBox["\[Theta]", "3"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         SubscriptBox["\[Theta]", "1"], "+", 
         SubscriptBox["\[Theta]", "2"], "+", 
         SubscriptBox["\[Theta]", "3"]}], ")"}]}]}], ")"}]}], ",", 
   RowBox[{
    SubscriptBox["z", "3"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SubscriptBox["z", "3"], " ", 
       SubscriptBox["\[Theta]", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "\[Epsilon]"}], "+", 
         SubscriptBox["\[Theta]", "2"]}], ")"}]}], "+", 
      RowBox[{
       SubscriptBox["z", "2"], " ", 
       RowBox[{"(", 
        RowBox[{"\[Epsilon]", "-", 
         SubscriptBox["\[Theta]", "3"]}], ")"}], " ", 
       SubscriptBox["\[Theta]", "3"]}]}], ")"}]}], ",", 
   RowBox[{
    SubscriptBox["z", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         SubscriptBox["z", "1"], "+", 
         SubscriptBox["z", "3"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"\[Epsilon]", "-", 
         SubscriptBox["\[Theta]", "2"]}], ")"}], " ", 
       SubscriptBox["\[Theta]", "2"]}], "+", 
      RowBox[{
       SubscriptBox["z", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], " ", 
          SubscriptBox["\[Theta]", "1"], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            SubscriptBox["\[Theta]", "2"], "+", 
            SubscriptBox["\[Theta]", "3"]}], ")"}]}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "+", 
            SubscriptBox["\[Theta]", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"1", "-", "\[Epsilon]", "+", 
            SubscriptBox["\[Theta]", "2"], "+", 
            RowBox[{"2", " ", 
             SubscriptBox["\[Theta]", "3"]}]}], ")"}]}]}], ")"}]}]}], ")"}]}],
    ",", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "2"], " ", 
     SubscriptBox["z", "3"], " ", 
     RowBox[{"(", 
      RowBox[{"\[Epsilon]", "-", 
       SubscriptBox["\[Theta]", "1"]}], ")"}], " ", 
     SubscriptBox["\[Theta]", "1"]}], "+", 
    RowBox[{
     SubscriptBox["z", "1"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SubscriptBox["\[Theta]", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "\[Epsilon]"}], "+", 
          SubscriptBox["\[Theta]", "2"]}], ")"}]}], "-", 
       RowBox[{
        SubscriptBox["z", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          SubscriptBox["\[Theta]", "1"], "+", 
          SubscriptBox["\[Theta]", "2"]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"1", "-", "\[Epsilon]", "+", 
          SubscriptBox["\[Theta]", "1"], "+", 
          SubscriptBox["\[Theta]", "2"], "+", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Theta]", "3"]}]}], ")"}]}]}], ")"}]}]}], ",", 
   RowBox[{
    SubscriptBox["z", "3"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SubscriptBox["z", "2"], " ", 
       RowBox[{"(", 
        RowBox[{"\[Epsilon]", "-", 
         SubscriptBox["\[Theta]", "1"]}], ")"}], " ", 
       SubscriptBox["\[Theta]", "1"]}], "+", 
      RowBox[{
       SubscriptBox["z", "1"], " ", 
       SubscriptBox["\[Theta]", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "\[Epsilon]"}], "+", 
         SubscriptBox["\[Theta]", "2"]}], ")"}]}]}], ")"}]}], ",", 
   RowBox[{
    SubscriptBox["z", "1"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SubscriptBox["z", "2"], " ", 
       RowBox[{"(", 
        RowBox[{"\[Epsilon]", "-", 
         SubscriptBox["\[Theta]", "1"]}], ")"}], " ", 
       SubscriptBox["\[Theta]", "1"]}], "+", 
      RowBox[{
       SubscriptBox["z", "1"], " ", 
       SubscriptBox["\[Theta]", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "\[Epsilon]"}], "+", 
         SubscriptBox["\[Theta]", "2"]}], ")"}]}]}], ")"}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      SubsuperscriptBox["z", "1", "2"]}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{"3", " ", "\[Epsilon]"}], "-", 
       SubscriptBox["\[Theta]", "1"], "-", 
       RowBox[{"4", " ", 
        SubscriptBox["\[Theta]", "2"]}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"\[Epsilon]", "-", 
       SubscriptBox["\[Theta]", "3"]}], ")"}]}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"\[Epsilon]", "-", 
       SubscriptBox["\[Theta]", "1"]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "\[Epsilon]"}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"2", " ", "\[Epsilon]"}]}], ")"}], " ", 
        SubscriptBox["z", "3"]}], "+", 
       RowBox[{
        SubscriptBox["z", "2"], " ", 
        SubscriptBox["z", "3"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "3"}], "+", 
          RowBox[{"4", " ", "\[Epsilon]"}], "-", 
          RowBox[{"12", " ", 
           SubscriptBox["\[Theta]", "1"]}], "-", 
          RowBox[{"4", " ", 
           SubscriptBox["\[Theta]", "2"]}], "-", 
          RowBox[{"6", " ", 
           SubscriptBox["\[Theta]", "3"]}]}], ")"}]}], "+", 
       RowBox[{
        SubsuperscriptBox["z", "2", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"\[Epsilon]", "-", 
          SubscriptBox["\[Theta]", "3"]}], ")"}]}], "+", 
       RowBox[{
        SubsuperscriptBox["z", "3", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"3", " ", "\[Epsilon]"}], "-", 
          RowBox[{"4", " ", 
           SubscriptBox["\[Theta]", "2"]}], "-", 
          SubscriptBox["\[Theta]", "3"]}], ")"}]}], "+", 
       SubscriptBox["\[Theta]", "3"]}], ")"}]}], "-", 
    RowBox[{
     SubscriptBox["z", "1"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{"2", " ", "\[Epsilon]"}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"\[Epsilon]", "-", 
            SubscriptBox["\[Theta]", "3"]}], ")"}]}], ")"}]}], "+", 
       RowBox[{
        SubscriptBox["z", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "3"}], "+", 
          RowBox[{"4", " ", "\[Epsilon]"}], "-", 
          RowBox[{"6", " ", 
           SubscriptBox["\[Theta]", "1"]}], "-", 
          RowBox[{"4", " ", 
           SubscriptBox["\[Theta]", "2"]}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"\[Epsilon]", "-", 
          SubscriptBox["\[Theta]", "3"]}], ")"}]}], "+", 
       RowBox[{
        SubscriptBox["z", "3"], " ", 
        RowBox[{"(", 
         RowBox[{"2", "-", 
          RowBox[{"8", " ", "\[Epsilon]"}], "+", 
          RowBox[{"6", " ", 
           SuperscriptBox["\[Epsilon]", "2"]}], "+", 
          RowBox[{"4", " ", 
           SubsuperscriptBox["\[Theta]", "1", "2"]}], "+", 
          RowBox[{"5", " ", 
           SubscriptBox["\[Theta]", "3"]}], "-", 
          RowBox[{"12", " ", "\[Epsilon]", " ", 
           SubscriptBox["\[Theta]", "3"]}], "+", 
          RowBox[{"4", " ", 
           SubsuperscriptBox["\[Theta]", "3", "2"]}], "+", 
          RowBox[{
           SubscriptBox["\[Theta]", "1"], " ", 
           RowBox[{"(", 
            RowBox[{"5", "-", 
             RowBox[{"12", " ", "\[Epsilon]"}], "+", 
             RowBox[{"12", " ", 
              SubscriptBox["\[Theta]", "2"]}], "+", 
             RowBox[{"6", " ", 
              SubscriptBox["\[Theta]", "3"]}]}], ")"}]}], "+", 
          RowBox[{
           SubscriptBox["\[Theta]", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"8", "-", 
             RowBox[{"8", " ", "\[Epsilon]"}], "+", 
             RowBox[{"12", " ", 
              SubscriptBox["\[Theta]", "3"]}]}], ")"}]}]}], ")"}]}]}], 
      ")"}]}]}], ",", 
   RowBox[{
    SubscriptBox["z", "3"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["z", "1"]}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "\[Epsilon]", "-", 
         SubscriptBox["\[Theta]", "1"], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["\[Theta]", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["\[Theta]", "3"]}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"\[Epsilon]", "-", 
         SubscriptBox["\[Theta]", "3"]}], ")"}]}], "-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"\[Epsilon]", "-", 
         SubscriptBox["\[Theta]", "1"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "\[Epsilon]"}], "+", 
         RowBox[{
          SubscriptBox["z", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"\[Epsilon]", "-", 
            SubscriptBox["\[Theta]", "3"]}], ")"}]}], "+", 
         RowBox[{
          SubscriptBox["z", "3"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "\[Epsilon]", "-", 
            RowBox[{"2", " ", 
             SubscriptBox["\[Theta]", "2"]}], "-", 
            SubscriptBox["\[Theta]", "3"]}], ")"}]}], "+", 
         SubscriptBox["\[Theta]", "3"]}], ")"}]}]}], ")"}]}], ",", 
   RowBox[{
    SubscriptBox["z", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["z", "1"]}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "\[Epsilon]", "-", 
         SubscriptBox["\[Theta]", "1"], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["\[Theta]", "2"]}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"\[Epsilon]", "-", 
         SubscriptBox["\[Theta]", "3"]}], ")"}]}], "-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"\[Epsilon]", "-", 
         SubscriptBox["\[Theta]", "1"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "\[Epsilon]"}], "+", 
         RowBox[{
          SubscriptBox["z", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"\[Epsilon]", "-", 
            SubscriptBox["\[Theta]", "3"]}], ")"}]}], "+", 
         RowBox[{
          SubscriptBox["z", "3"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "\[Epsilon]", "-", 
            RowBox[{"2", " ", 
             SubscriptBox["\[Theta]", "1"]}], "-", 
            RowBox[{"2", " ", 
             SubscriptBox["\[Theta]", "2"]}], "-", 
            SubscriptBox["\[Theta]", "3"]}], ")"}]}], "+", 
         SubscriptBox["\[Theta]", "3"]}], ")"}]}]}], ")"}]}], ",", 
   RowBox[{
    SubscriptBox["z", "1"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["z", "1"]}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "\[Epsilon]", "-", 
         SubscriptBox["\[Theta]", "1"], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["\[Theta]", "2"]}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"\[Epsilon]", "-", 
         SubscriptBox["\[Theta]", "3"]}], ")"}]}], "-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"\[Epsilon]", "-", 
         SubscriptBox["\[Theta]", "1"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "\[Epsilon]"}], "+", 
         RowBox[{
          SubscriptBox["z", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"\[Epsilon]", "-", 
            SubscriptBox["\[Theta]", "3"]}], ")"}]}], "+", 
         RowBox[{
          SubscriptBox["z", "3"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "\[Epsilon]", "-", 
            RowBox[{"2", " ", 
             SubscriptBox["\[Theta]", "1"]}], "-", 
            RowBox[{"2", " ", 
             SubscriptBox["\[Theta]", "2"]}], "-", 
            SubscriptBox["\[Theta]", "3"]}], ")"}]}], "+", 
         SubscriptBox["\[Theta]", "3"]}], ")"}]}]}], ")"}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"\[Epsilon]", "-", 
         SubscriptBox["\[Theta]", "1"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            SubsuperscriptBox["z", "3", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"\[Epsilon]", "-", 
            SubscriptBox["\[Theta]", "2"]}], ")"}]}], "+", 
         RowBox[{
          SubscriptBox["z", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "-", 
            RowBox[{"2", " ", "\[Epsilon]"}], "+", 
            RowBox[{
             SubscriptBox["z", "3"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "3"}], "+", 
               RowBox[{"4", " ", "\[Epsilon]"}], "-", 
               RowBox[{"12", " ", 
                SubscriptBox["\[Theta]", "1"]}], "-", 
               RowBox[{"6", " ", 
                SubscriptBox["\[Theta]", "2"]}], "-", 
               RowBox[{"4", " ", 
                SubscriptBox["\[Theta]", "3"]}]}], ")"}]}]}], ")"}]}], "+", 
         RowBox[{
          SubsuperscriptBox["z", "2", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            RowBox[{"3", " ", "\[Epsilon]"}], "-", 
            SubscriptBox["\[Theta]", "2"], "-", 
            RowBox[{"4", " ", 
             SubscriptBox["\[Theta]", "3"]}]}], ")"}]}]}], ")"}]}], ")"}]}], 
    "-", 
    RowBox[{
     SubsuperscriptBox["z", "1", "2"], " ", 
     RowBox[{"(", 
      RowBox[{"\[Epsilon]", "-", 
       SubscriptBox["\[Theta]", "2"]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{"3", " ", "\[Epsilon]"}], "-", 
       SubscriptBox["\[Theta]", "1"], "-", 
       RowBox[{"4", " ", 
        SubscriptBox["\[Theta]", "3"]}]}], ")"}]}], "-", 
    RowBox[{
     SubscriptBox["z", "1"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"\[Epsilon]", "-", 
          SubscriptBox["\[Theta]", "2"]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "-", 
          RowBox[{"2", " ", "\[Epsilon]"}], "+", 
          RowBox[{
           SubscriptBox["z", "3"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "3"}], "+", 
             RowBox[{"4", " ", "\[Epsilon]"}], "-", 
             RowBox[{"6", " ", 
              SubscriptBox["\[Theta]", "1"]}], "-", 
             RowBox[{"4", " ", 
              SubscriptBox["\[Theta]", "3"]}]}], ")"}]}]}], ")"}]}], "+", 
       RowBox[{
        SubscriptBox["z", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"4", " ", 
           SubsuperscriptBox["\[Theta]", "1", "2"]}], "+", 
          RowBox[{"4", " ", 
           SubsuperscriptBox["\[Theta]", "2", "2"]}], "+", 
          RowBox[{"2", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "\[Epsilon]"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             RowBox[{"3", " ", "\[Epsilon]"}], "-", 
             RowBox[{"4", " ", 
              SubscriptBox["\[Theta]", "3"]}]}], ")"}]}], "+", 
          RowBox[{
           SubscriptBox["\[Theta]", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"5", "-", 
             RowBox[{"12", " ", "\[Epsilon]"}], "+", 
             RowBox[{"12", " ", 
              SubscriptBox["\[Theta]", "3"]}]}], ")"}]}], "+", 
          RowBox[{
           SubscriptBox["\[Theta]", "1"], " ", 
           RowBox[{"(", 
            RowBox[{"5", "-", 
             RowBox[{"12", " ", "\[Epsilon]"}], "+", 
             RowBox[{"6", " ", 
              SubscriptBox["\[Theta]", "2"]}], "+", 
             RowBox[{"12", " ", 
              SubscriptBox["\[Theta]", "3"]}]}], ")"}]}]}], ")"}]}]}], 
      ")"}]}]}], ",", 
   RowBox[{
    SubscriptBox["z", "3"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"\[Epsilon]", "-", 
           SubscriptBox["\[Theta]", "1"]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              SubscriptBox["z", "3"]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{"\[Epsilon]", "-", 
              SubscriptBox["\[Theta]", "2"]}], ")"}]}], "+", 
           RowBox[{
            SubscriptBox["z", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "\[Epsilon]", "-", 
              RowBox[{"2", " ", 
               SubscriptBox["\[Theta]", "1"]}], "-", 
              SubscriptBox["\[Theta]", "2"], "-", 
              RowBox[{"2", " ", 
               SubscriptBox["\[Theta]", "3"]}]}], ")"}]}]}], ")"}]}], ")"}]}],
       "-", 
      RowBox[{
       SubscriptBox["z", "1"], " ", 
       RowBox[{"(", 
        RowBox[{"\[Epsilon]", "-", 
         SubscriptBox["\[Theta]", "2"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "\[Epsilon]", "-", 
         SubscriptBox["\[Theta]", "1"], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["\[Theta]", "3"]}]}], ")"}]}]}], ")"}]}], ",", 
   RowBox[{
    SubscriptBox["z", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"\[Epsilon]", "-", 
           SubscriptBox["\[Theta]", "1"]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              SubscriptBox["z", "3"]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{"\[Epsilon]", "-", 
              SubscriptBox["\[Theta]", "2"]}], ")"}]}], "+", 
           RowBox[{
            SubscriptBox["z", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "\[Epsilon]", "-", 
              SubscriptBox["\[Theta]", "2"], "-", 
              RowBox[{"2", " ", 
               SubscriptBox["\[Theta]", "3"]}]}], ")"}]}]}], ")"}]}], ")"}]}],
       "-", 
      RowBox[{
       SubscriptBox["z", "1"], " ", 
       RowBox[{"(", 
        RowBox[{"\[Epsilon]", "-", 
         SubscriptBox["\[Theta]", "2"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "\[Epsilon]", "-", 
         SubscriptBox["\[Theta]", "1"], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["\[Theta]", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["\[Theta]", "3"]}]}], ")"}]}]}], ")"}]}], ",", 
   RowBox[{
    SubscriptBox["z", "1"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"\[Epsilon]", "-", 
           SubscriptBox["\[Theta]", "1"]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              SubscriptBox["z", "3"]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{"\[Epsilon]", "-", 
              SubscriptBox["\[Theta]", "2"]}], ")"}]}], "+", 
           RowBox[{
            SubscriptBox["z", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "\[Epsilon]", "-", 
              RowBox[{"2", " ", 
               SubscriptBox["\[Theta]", "1"]}], "-", 
              SubscriptBox["\[Theta]", "2"], "-", 
              RowBox[{"2", " ", 
               SubscriptBox["\[Theta]", "3"]}]}], ")"}]}]}], ")"}]}], ")"}]}],
       "-", 
      RowBox[{
       SubscriptBox["z", "1"], " ", 
       RowBox[{"(", 
        RowBox[{"\[Epsilon]", "-", 
         SubscriptBox["\[Theta]", "2"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "\[Epsilon]", "-", 
         SubscriptBox["\[Theta]", "1"], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["\[Theta]", "3"]}]}], ")"}]}]}], ")"}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{"6", " ", 
        SubscriptBox["z", "2"], " ", 
        SubscriptBox["z", "3"]}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"\[Epsilon]", "-", 
       SubscriptBox["\[Theta]", "1"]}], ")"}], " ", 
     SubscriptBox["\[Theta]", "1"]}], "-", 
    RowBox[{
     SubsuperscriptBox["z", "1", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       SubsuperscriptBox["\[Theta]", "1", "2"], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"2", " ", "\[Epsilon]"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"3", " ", "\[Epsilon]"}], "-", 
          RowBox[{"4", " ", 
           SubscriptBox["\[Theta]", "3"]}]}], ")"}]}], "+", 
       RowBox[{
        SubscriptBox["\[Theta]", "1"], " ", 
        RowBox[{"(", 
         RowBox[{"2", "-", 
          RowBox[{"5", " ", "\[Epsilon]"}], "+", 
          RowBox[{"4", " ", 
           SubscriptBox["\[Theta]", "2"]}], "+", 
          RowBox[{"4", " ", 
           SubscriptBox["\[Theta]", "3"]}]}], ")"}]}], "+", 
       RowBox[{
        SubscriptBox["\[Theta]", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"4", "-", 
          RowBox[{"8", " ", "\[Epsilon]"}], "+", 
          RowBox[{"12", " ", 
           SubscriptBox["\[Theta]", "3"]}]}], ")"}]}]}], ")"}]}], "-", 
    RowBox[{
     SubscriptBox["z", "1"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{"2", " ", "\[Epsilon]"}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            RowBox[{"3", " ", "\[Epsilon]"}], "-", 
            RowBox[{"2", " ", 
             SubscriptBox["\[Theta]", "1"]}], "-", 
            RowBox[{"2", " ", 
             SubscriptBox["\[Theta]", "2"]}], "-", 
            RowBox[{"2", " ", 
             SubscriptBox["\[Theta]", "3"]}]}], ")"}]}], ")"}]}], "+", 
       RowBox[{
        SubscriptBox["z", "3"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"6", " ", 
           SubsuperscriptBox["\[Theta]", "1", "2"]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             RowBox[{"2", " ", "\[Epsilon]"}], "-", 
             SubscriptBox["\[Theta]", "3"]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             RowBox[{"3", " ", "\[Epsilon]"}], "-", 
             RowBox[{"4", " ", 
              SubscriptBox["\[Theta]", "2"]}], "-", 
             SubscriptBox["\[Theta]", "3"]}], ")"}]}], "+", 
          RowBox[{
           SubscriptBox["\[Theta]", "1"], " ", 
           RowBox[{"(", 
            RowBox[{"4", "-", 
             RowBox[{"14", " ", "\[Epsilon]"}], "+", 
             RowBox[{"12", " ", 
              SubscriptBox["\[Theta]", "2"]}], "+", 
             RowBox[{"4", " ", 
              SubscriptBox["\[Theta]", "3"]}]}], ")"}]}]}], ")"}]}], "+", 
       RowBox[{
        SubscriptBox["z", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"6", " ", 
           SubsuperscriptBox["\[Theta]", "1", "2"]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             RowBox[{"2", " ", "\[Epsilon]"}], "-", 
             SubscriptBox["\[Theta]", "2"]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             RowBox[{"3", " ", "\[Epsilon]"}], "-", 
             SubscriptBox["\[Theta]", "2"], "-", 
             RowBox[{"4", " ", 
              SubscriptBox["\[Theta]", "3"]}]}], ")"}]}], "+", 
          RowBox[{
           SubscriptBox["\[Theta]", "1"], " ", 
           RowBox[{"(", 
            RowBox[{"4", "-", 
             RowBox[{"14", " ", "\[Epsilon]"}], "+", 
             RowBox[{"4", " ", 
              SubscriptBox["\[Theta]", "2"]}], "+", 
             RowBox[{"12", " ", 
              SubscriptBox["\[Theta]", "3"]}]}], ")"}]}]}], ")"}]}]}], 
      ")"}]}]}], ",", 
   RowBox[{
    SubscriptBox["z", "3"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         SubscriptBox["z", "2"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"\[Epsilon]", "-", 
         SubscriptBox["\[Theta]", "1"]}], ")"}], " ", 
       SubscriptBox["\[Theta]", "1"]}], "+", 
      RowBox[{
       SubscriptBox["z", "1"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "\[Epsilon]", "-", 
         SubscriptBox["\[Theta]", "1"], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["\[Theta]", "2"]}], "-", 
         SubscriptBox["\[Theta]", "3"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         SubscriptBox["\[Theta]", "1"], "+", 
         SubscriptBox["\[Theta]", "3"]}], ")"}]}]}], ")"}]}], ",", 
   RowBox[{
    SubscriptBox["z", "3"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SubscriptBox["z", "3"], " ", 
       SubscriptBox["\[Theta]", "1"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "\[Epsilon]"}], "+", 
         SubscriptBox["\[Theta]", "1"]}], ")"}]}], "+", 
      RowBox[{
       SubscriptBox["z", "1"], " ", 
       RowBox[{"(", 
        RowBox[{"\[Epsilon]", "-", 
         SubscriptBox["\[Theta]", "3"]}], ")"}], " ", 
       SubscriptBox["\[Theta]", "3"]}]}], ")"}]}], ",", 
   RowBox[{
    SubscriptBox["z", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         SubscriptBox["z", "3"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"\[Epsilon]", "-", 
         SubscriptBox["\[Theta]", "1"]}], ")"}], " ", 
       SubscriptBox["\[Theta]", "1"]}], "-", 
      RowBox[{
       SubscriptBox["z", "1"], " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         SubscriptBox["\[Theta]", "1"], "+", 
         SubscriptBox["\[Theta]", "2"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", "\[Epsilon]", "+", 
         SubscriptBox["\[Theta]", "1"], "+", 
         SubscriptBox["\[Theta]", "2"], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["\[Theta]", "3"]}]}], ")"}]}]}], ")"}]}], ",", 
   RowBox[{
    SubscriptBox["z", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SubscriptBox["z", "2"], " ", 
       SubscriptBox["\[Theta]", "1"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "\[Epsilon]"}], "+", 
         SubscriptBox["\[Theta]", "1"]}], ")"}]}], "+", 
      RowBox[{
       SubscriptBox["z", "1"], " ", 
       RowBox[{"(", 
        RowBox[{"\[Epsilon]", "-", 
         SubscriptBox["\[Theta]", "2"]}], ")"}], " ", 
       SubscriptBox["\[Theta]", "2"]}]}], ")"}]}], ",", 
   RowBox[{
    SubscriptBox["z", "1"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         SubscriptBox["z", "2"], "+", 
         SubscriptBox["z", "3"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"\[Epsilon]", "-", 
         SubscriptBox["\[Theta]", "1"]}], ")"}], " ", 
       SubscriptBox["\[Theta]", "1"]}], "+", 
      RowBox[{
       SubscriptBox["z", "1"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "\[Epsilon]", "-", 
         SubsuperscriptBox["\[Theta]", "1", "2"], "+", 
         RowBox[{
          SubscriptBox["\[Theta]", "1"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "2"}], "+", "\[Epsilon]", "-", 
            RowBox[{"2", " ", 
             SubscriptBox["\[Theta]", "2"]}], "-", 
            RowBox[{"2", " ", 
             SubscriptBox["\[Theta]", "3"]}]}], ")"}]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["\[Theta]", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["\[Theta]", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            SubscriptBox["\[Theta]", "3"]}], ")"}]}]}], ")"}]}]}], ")"}]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.837228671500844*^9, {3.837228725040854*^9, 3.837228750021544*^9}, 
   3.837229135165716*^9, 3.837229235391947*^9, {3.837678205195949*^9, 
   3.837678210583755*^9}},
 CellLabel->"Out[86]=",ExpressionUUID->"40177e4d-6591-4448-ada7-c1b574cef260"],

Cell[BoxData["32"], "Output",
 CellChangeTimes->{
  3.837228671500844*^9, {3.837228725040854*^9, 3.837228750021544*^9}, 
   3.837229135165716*^9, 3.837229235391947*^9, {3.837678205195949*^9, 
   3.8376782106006308`*^9}},
 CellLabel->"Out[87]=",ExpressionUUID->"579b517a-a2b9-4c8a-b1aa-7ca3fd91dffd"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["l=3", "Subsubsection",
 CellChangeTimes->{{3.837228632311771*^9, 3.837228632975037*^9}, {
  3.837678454752136*^9, 
  3.837678455640568*^9}},ExpressionUUID->"29e0faca-07f6-4875-abd9-\
0843925dc0a8"],

Cell["Computes all necessary operators for l=3:", "Text",
 CellChangeTimes->{{3.83767784268156*^9, 3.837677930184064*^9}, {
  3.837678279116335*^9, 3.8376782798476353`*^9}, {3.837678422543075*^9, 
  3.8376784423769484`*^9}},ExpressionUUID->"be2185a5-9a9c-495d-b708-\
3db798fe6ba6"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"OperatorsNonEqualMass", "[", "3", "]"}], "//", "Simplify"}], "//",
   "TableForm"}], "\[IndentingNewLine]", 
 RowBox[{"%", "//", "Length"}]}], "Input",
 CellChangeTimes->{{3.8376779444630003`*^9, 3.837678043158977*^9}, {
   3.8376781986125937`*^9, 3.837678200120821*^9}, 3.8376782731888447`*^9},
 CellLabel->"In[88]:=",ExpressionUUID->"6c6fc30a-9020-428b-b22a-0b310e1f8057"],

Cell[BoxData[
 TemplateBox[{
  "Solve", "svars", 
   "\"Equations may not give solutions for all \\\"solve\\\" variables.\"", 2,
    88, 3, 30129496903220097915, "MyKernel4"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.837678283264957*^9},
 CellLabel->
  "During evaluation of \
In[88]:=",ExpressionUUID->"d3bf8100-6618-4709-b7bf-45a47a28ebea"],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {
      RowBox[{
       RowBox[{
        SubscriptBox["\[Theta]", "4"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "\[Epsilon]"}], "+", 
          SubscriptBox["\[Theta]", "4"]}], ")"}]}], "+", 
       RowBox[{
        SubscriptBox["z", "4"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "\[Epsilon]", "-", 
          SubscriptBox["\[Theta]", "1"], "-", 
          SubscriptBox["\[Theta]", "2"], "-", 
          SubscriptBox["\[Theta]", "3"], "-", 
          SubscriptBox["\[Theta]", "4"]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          SubscriptBox["\[Theta]", "1"], "+", 
          SubscriptBox["\[Theta]", "2"], "+", 
          SubscriptBox["\[Theta]", "3"], "+", 
          SubscriptBox["\[Theta]", "4"]}], ")"}]}]}]},
     {
      RowBox[{
       RowBox[{
        SubscriptBox["z", "4"], " ", 
        RowBox[{"(", 
         RowBox[{"\[Epsilon]", "-", 
          SubscriptBox["\[Theta]", "3"]}], ")"}], " ", 
        SubscriptBox["\[Theta]", "3"]}], "+", 
       RowBox[{
        SubscriptBox["z", "3"], " ", 
        SubscriptBox["\[Theta]", "4"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "\[Epsilon]"}], "+", 
          SubscriptBox["\[Theta]", "4"]}], ")"}]}]}]},
     {
      RowBox[{
       RowBox[{
        SubscriptBox["z", "4"], " ", 
        RowBox[{"(", 
         RowBox[{"\[Epsilon]", "-", 
          SubscriptBox["\[Theta]", "2"]}], ")"}], " ", 
        SubscriptBox["\[Theta]", "2"]}], "+", 
       RowBox[{
        SubscriptBox["z", "2"], " ", 
        SubscriptBox["\[Theta]", "4"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "\[Epsilon]"}], "+", 
          SubscriptBox["\[Theta]", "4"]}], ")"}]}]}]},
     {
      RowBox[{
       RowBox[{
        SubscriptBox["z", "4"], " ", 
        RowBox[{"(", 
         RowBox[{"\[Epsilon]", "-", 
          SubscriptBox["\[Theta]", "1"]}], ")"}], " ", 
        SubscriptBox["\[Theta]", "1"]}], "+", 
       RowBox[{
        SubscriptBox["z", "1"], " ", 
        SubscriptBox["\[Theta]", "4"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "\[Epsilon]"}], "+", 
          SubscriptBox["\[Theta]", "4"]}], ")"}]}]}]},
     {
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          SubscriptBox["z", "1"], "+", 
          SubscriptBox["z", "2"], "+", 
          SubscriptBox["z", "3"]}], ")"}], " ", 
        SubscriptBox["\[Theta]", "4"], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["\[Epsilon]", "2"], "-", 
          SubsuperscriptBox["\[Theta]", "4", "2"]}], ")"}]}], "+", 
       RowBox[{
        SubscriptBox["z", "4"], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", "\[Epsilon]", "+", 
          SubscriptBox["\[Theta]", "4"]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "\[Epsilon]", "-", 
             RowBox[{"2", " ", 
              SubscriptBox["\[Theta]", "3"]}], "-", 
             SubscriptBox["\[Theta]", "4"]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             SubscriptBox["\[Theta]", "4"]}], ")"}]}], "-", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Theta]", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             SubscriptBox["\[Theta]", "3"], "+", 
             SubscriptBox["\[Theta]", "4"]}], ")"}]}], "-", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Theta]", "1"], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             SubscriptBox["\[Theta]", "2"], "+", 
             SubscriptBox["\[Theta]", "3"], "+", 
             SubscriptBox["\[Theta]", "4"]}], ")"}]}]}], ")"}]}]}]},
     {
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"\[Epsilon]", "-", 
          SubscriptBox["\[Theta]", "4"]}], ")"}], " ", 
        SubscriptBox["\[Theta]", "4"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           SubscriptBox["\[Theta]", "3"]}], "+", 
          RowBox[{"2", " ", 
           SubscriptBox["z", "3"], " ", 
           RowBox[{"(", 
            RowBox[{"\[Epsilon]", "+", 
             SubscriptBox["\[Theta]", "4"]}], ")"}]}]}], ")"}]}], "-", 
       RowBox[{
        SubscriptBox["z", "4"], " ", 
        SubscriptBox["\[Theta]", "3"], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", "\[Epsilon]", "+", 
          RowBox[{"2", " ", 
           SuperscriptBox["\[Epsilon]", "2"]}], "+", 
          SubsuperscriptBox["\[Theta]", "1", "2"], "+", 
          SubsuperscriptBox["\[Theta]", "2", "2"], "-", 
          RowBox[{"3", " ", "\[Epsilon]", " ", 
           SubscriptBox["\[Theta]", "3"]}], "+", 
          SubsuperscriptBox["\[Theta]", "3", "2"], "+", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Theta]", "4"]}], "+", 
          RowBox[{"\[Epsilon]", " ", 
           SubscriptBox["\[Theta]", "4"]}], "+", 
          SubsuperscriptBox["\[Theta]", "4", "2"], "+", 
          RowBox[{
           SubscriptBox["\[Theta]", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"2", "-", "\[Epsilon]", "+", 
             RowBox[{"2", " ", 
              SubscriptBox["\[Theta]", "3"]}], "+", 
             RowBox[{"2", " ", 
              SubscriptBox["\[Theta]", "4"]}]}], ")"}]}], "+", 
          RowBox[{
           SubscriptBox["\[Theta]", "1"], " ", 
           RowBox[{"(", 
            RowBox[{"2", "-", "\[Epsilon]", "+", 
             RowBox[{"2", " ", 
              SubscriptBox["\[Theta]", "2"]}], "+", 
             RowBox[{"2", " ", 
              SubscriptBox["\[Theta]", "3"]}], "+", 
             RowBox[{"2", " ", 
              SubscriptBox["\[Theta]", "4"]}]}], ")"}]}]}], ")"}]}]}]},
     {
      RowBox[{
       SubscriptBox["\[Theta]", "3"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SubscriptBox["z", "4"], " ", 
          RowBox[{"(", 
           RowBox[{"\[Epsilon]", "-", 
            SubscriptBox["\[Theta]", "3"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            SubscriptBox["\[Theta]", "3"]}], ")"}]}], "+", 
         RowBox[{
          SubscriptBox["z", "3"], " ", 
          SubscriptBox["\[Theta]", "4"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "\[Epsilon]"}], "+", 
            SubscriptBox["\[Theta]", "4"]}], ")"}]}]}], ")"}]}]},
     {
      RowBox[{
       SubscriptBox["\[Theta]", "3"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SubscriptBox["z", "4"], " ", 
          RowBox[{"(", 
           RowBox[{"\[Epsilon]", "-", 
            SubscriptBox["\[Theta]", "2"]}], ")"}], " ", 
          SubscriptBox["\[Theta]", "2"]}], "+", 
         RowBox[{
          SubscriptBox["z", "2"], " ", 
          SubscriptBox["\[Theta]", "4"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "\[Epsilon]"}], "+", 
            SubscriptBox["\[Theta]", "4"]}], ")"}]}]}], ")"}]}]},
     {
      RowBox[{
       SubscriptBox["\[Theta]", "3"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SubscriptBox["z", "4"], " ", 
          RowBox[{"(", 
           RowBox[{"\[Epsilon]", "-", 
            SubscriptBox["\[Theta]", "1"]}], ")"}], " ", 
          SubscriptBox["\[Theta]", "1"]}], "+", 
         RowBox[{
          SubscriptBox["z", "1"], " ", 
          SubscriptBox["\[Theta]", "4"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "\[Epsilon]"}], "+", 
            SubscriptBox["\[Theta]", "4"]}], ")"}]}]}], ")"}]}]},
     {
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          SubscriptBox["z", "4"]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"\[Epsilon]", "-", 
          SubscriptBox["\[Theta]", "3"]}], ")"}], " ", 
        SubscriptBox["\[Theta]", "3"]}], "-", 
       RowBox[{
        SubscriptBox["z", "3"], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          SubscriptBox["\[Theta]", "1"], "+", 
          SubscriptBox["\[Theta]", "2"], "+", 
          SubscriptBox["\[Theta]", "3"]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"1", "-", "\[Epsilon]", "+", 
          SubscriptBox["\[Theta]", "1"], "+", 
          SubscriptBox["\[Theta]", "2"], "+", 
          SubscriptBox["\[Theta]", "3"], "+", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Theta]", "4"]}]}], ")"}]}]}]},
     {
      RowBox[{
       RowBox[{
        SubscriptBox["z", "3"], " ", 
        RowBox[{"(", 
         RowBox[{"\[Epsilon]", "-", 
          SubscriptBox["\[Theta]", "2"]}], ")"}], " ", 
        SubscriptBox["\[Theta]", "2"]}], "+", 
       RowBox[{
        SubscriptBox["z", "2"], " ", 
        SubscriptBox["\[Theta]", "3"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "\[Epsilon]"}], "+", 
          SubscriptBox["\[Theta]", "3"]}], ")"}]}]}]},
     {
      RowBox[{
       RowBox[{
        SubscriptBox["z", "3"], " ", 
        RowBox[{"(", 
         RowBox[{"\[Epsilon]", "-", 
          SubscriptBox["\[Theta]", "1"]}], ")"}], " ", 
        SubscriptBox["\[Theta]", "1"]}], "+", 
       RowBox[{
        SubscriptBox["z", "1"], " ", 
        SubscriptBox["\[Theta]", "3"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "\[Epsilon]"}], "+", 
          SubscriptBox["\[Theta]", "3"]}], ")"}]}]}]},
     {
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         SubscriptBox["z", "4"]}], " ", 
        RowBox[{"(", 
         RowBox[{"\[Epsilon]", "-", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Theta]", "1"]}], "-", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Theta]", "2"]}], "-", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Theta]", "3"]}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"\[Epsilon]", "-", 
          SubscriptBox["\[Theta]", "3"]}], ")"}], " ", 
        SubscriptBox["\[Theta]", "3"]}], "-", 
       RowBox[{
        SubscriptBox["\[Theta]", "4"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"\[Epsilon]", "-", 
             SubscriptBox["\[Theta]", "3"]}], ")"}], " ", 
           SubscriptBox["\[Theta]", "3"]}], "+", 
          RowBox[{
           SubscriptBox["z", "3"], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", "\[Epsilon]", "-", 
             SuperscriptBox["\[Epsilon]", "2"], "+", 
             SubsuperscriptBox["\[Theta]", "1", "2"], "+", 
             SubsuperscriptBox["\[Theta]", "2", "2"], "+", 
             RowBox[{"2", " ", 
              SubscriptBox["\[Theta]", "3"]}], "+", 
             RowBox[{"\[Epsilon]", " ", 
              SubscriptBox["\[Theta]", "3"]}], "+", 
             SubsuperscriptBox["\[Theta]", "3", "2"], "+", 
             RowBox[{
              SubscriptBox["\[Theta]", "2"], " ", 
              RowBox[{"(", 
               RowBox[{"2", "+", "\[Epsilon]", "+", 
                RowBox[{"2", " ", 
                 SubscriptBox["\[Theta]", "3"]}]}], ")"}]}], "+", 
             RowBox[{
              SubscriptBox["\[Theta]", "1"], " ", 
              RowBox[{"(", 
               RowBox[{"2", "+", "\[Epsilon]", "+", 
                RowBox[{"2", " ", 
                 SubscriptBox["\[Theta]", "2"]}], "+", 
                RowBox[{"2", " ", 
                 SubscriptBox["\[Theta]", "3"]}]}], ")"}]}], "+", 
             SubsuperscriptBox["\[Theta]", "4", "2"]}], ")"}]}]}], 
         ")"}]}]}]},
     {
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         SubscriptBox["z", "4"]}], " ", 
        RowBox[{"(", 
         RowBox[{"\[Epsilon]", "-", 
          SubscriptBox["\[Theta]", "3"]}], ")"}], " ", 
        SubscriptBox["\[Theta]", "3"], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", "\[Epsilon]", "+", 
          SubscriptBox["\[Theta]", "4"]}], ")"}]}], "+", 
       RowBox[{
        SubscriptBox["z", "3"], " ", 
        SubscriptBox["\[Theta]", "4"], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["\[Epsilon]", "2"], "-", 
          SubsuperscriptBox["\[Theta]", "4", "2"]}], ")"}]}]}]},
     {
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SubscriptBox["z", "3"], " ", 
          RowBox[{"(", 
           RowBox[{"\[Epsilon]", "-", 
            SubscriptBox["\[Theta]", "2"]}], ")"}], " ", 
          SubscriptBox["\[Theta]", "2"]}], "+", 
         RowBox[{
          SubscriptBox["z", "2"], " ", 
          SubscriptBox["\[Theta]", "3"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "\[Epsilon]"}], "+", 
            SubscriptBox["\[Theta]", "3"]}], ")"}]}]}], ")"}], " ", 
       SubscriptBox["\[Theta]", "4"]}]},
     {
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SubscriptBox["z", "3"], " ", 
          RowBox[{"(", 
           RowBox[{"\[Epsilon]", "-", 
            SubscriptBox["\[Theta]", "1"]}], ")"}], " ", 
          SubscriptBox["\[Theta]", "1"]}], "+", 
         RowBox[{
          SubscriptBox["z", "1"], " ", 
          SubscriptBox["\[Theta]", "3"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "\[Epsilon]"}], "+", 
            SubscriptBox["\[Theta]", "3"]}], ")"}]}]}], ")"}], " ", 
       SubscriptBox["\[Theta]", "4"]}]},
     {
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          SubscriptBox["z", "1"], "+", 
          SubscriptBox["z", "2"], "+", 
          SubscriptBox["z", "4"]}], ")"}], " ", 
        SubscriptBox["\[Theta]", "3"], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["\[Epsilon]", "2"], "-", 
          SubsuperscriptBox["\[Theta]", "3", "2"]}], ")"}]}], "+", 
       RowBox[{
        SubscriptBox["z", "3"], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", "\[Epsilon]", "+", 
          SubscriptBox["\[Theta]", "3"]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "2"}], " ", 
           SubscriptBox["\[Theta]", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             SubscriptBox["\[Theta]", "3"], "+", 
             SubscriptBox["\[Theta]", "4"]}], ")"}]}], "-", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Theta]", "1"], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             SubscriptBox["\[Theta]", "2"], "+", 
             SubscriptBox["\[Theta]", "3"], "+", 
             SubscriptBox["\[Theta]", "4"]}], ")"}]}], "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "+", 
             SubscriptBox["\[Theta]", "3"]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"1", "-", "\[Epsilon]", "+", 
             SubscriptBox["\[Theta]", "3"], "+", 
             RowBox[{"2", " ", 
              SubscriptBox["\[Theta]", "4"]}]}], ")"}]}]}], ")"}]}]}]},
     {
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"\[Epsilon]", "-", 
          SubscriptBox["\[Theta]", "4"]}], ")"}], " ", 
        SubscriptBox["\[Theta]", "4"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           SubscriptBox["\[Theta]", "2"]}], "+", 
          RowBox[{"2", " ", 
           SubscriptBox["z", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"\[Epsilon]", "+", 
             SubscriptBox["\[Theta]", "4"]}], ")"}]}]}], ")"}]}], "-", 
       RowBox[{
        SubscriptBox["z", "4"], " ", 
        SubscriptBox["\[Theta]", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", "\[Epsilon]", "+", 
          RowBox[{"2", " ", 
           SuperscriptBox["\[Epsilon]", "2"]}], "+", 
          SubsuperscriptBox["\[Theta]", "1", "2"], "+", 
          SubsuperscriptBox["\[Theta]", "2", "2"], "+", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Theta]", "3"]}], "-", 
          RowBox[{"\[Epsilon]", " ", 
           SubscriptBox["\[Theta]", "3"]}], "+", 
          SubsuperscriptBox["\[Theta]", "3", "2"], "+", 
          RowBox[{
           SubscriptBox["\[Theta]", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "3"}], " ", "\[Epsilon]"}], "+", 
             RowBox[{"2", " ", 
              SubscriptBox["\[Theta]", "3"]}]}], ")"}]}], "+", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Theta]", "4"]}], "+", 
          RowBox[{"\[Epsilon]", " ", 
           SubscriptBox["\[Theta]", "4"]}], "+", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Theta]", "3"], " ", 
           SubscriptBox["\[Theta]", "4"]}], "+", 
          SubsuperscriptBox["\[Theta]", "4", "2"], "+", 
          RowBox[{
           SubscriptBox["\[Theta]", "1"], " ", 
           RowBox[{"(", 
            RowBox[{"2", "-", "\[Epsilon]", "+", 
             RowBox[{"2", " ", 
              SubscriptBox["\[Theta]", "2"]}], "+", 
             RowBox[{"2", " ", 
              SubscriptBox["\[Theta]", "3"]}], "+", 
             RowBox[{"2", " ", 
              SubscriptBox["\[Theta]", "4"]}]}], ")"}]}]}], ")"}]}]}]},
     {
      RowBox[{
       SubscriptBox["\[Theta]", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SubscriptBox["z", "4"], " ", 
          RowBox[{"(", 
           RowBox[{"\[Epsilon]", "-", 
            SubscriptBox["\[Theta]", "3"]}], ")"}], " ", 
          SubscriptBox["\[Theta]", "3"]}], "+", 
         RowBox[{
          SubscriptBox["z", "3"], " ", 
          SubscriptBox["\[Theta]", "4"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "\[Epsilon]"}], "+", 
            SubscriptBox["\[Theta]", "4"]}], ")"}]}]}], ")"}]}]},
     {
      RowBox[{
       SubscriptBox["\[Theta]", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SubscriptBox["z", "4"], " ", 
          RowBox[{"(", 
           RowBox[{"\[Epsilon]", "-", 
            SubscriptBox["\[Theta]", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            SubscriptBox["\[Theta]", "2"]}], ")"}]}], "+", 
         RowBox[{
          SubscriptBox["z", "2"], " ", 
          SubscriptBox["\[Theta]", "4"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "\[Epsilon]"}], "+", 
            SubscriptBox["\[Theta]", "4"]}], ")"}]}]}], ")"}]}]},
     {
      RowBox[{
       SubscriptBox["\[Theta]", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SubscriptBox["z", "4"], " ", 
          RowBox[{"(", 
           RowBox[{"\[Epsilon]", "-", 
            SubscriptBox["\[Theta]", "1"]}], ")"}], " ", 
          SubscriptBox["\[Theta]", "1"]}], "+", 
         RowBox[{
          SubscriptBox["z", "1"], " ", 
          SubscriptBox["\[Theta]", "4"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "\[Epsilon]"}], "+", 
            SubscriptBox["\[Theta]", "4"]}], ")"}]}]}], ")"}]}]},
     {
      RowBox[{
       RowBox[{
        SubscriptBox["z", "1"], " ", 
        RowBox[{"(", 
         RowBox[{"\[Epsilon]", "-", 
          SubscriptBox["\[Theta]", "2"]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"\[Epsilon]", "-", 
          SubscriptBox["\[Theta]", "3"]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"\[Epsilon]", "-", 
          SubscriptBox["\[Theta]", "4"]}], ")"}]}], "+", 
       RowBox[{
        SubscriptBox["z", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "\[Epsilon]", "-", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Theta]", "1"]}], "-", 
          SubscriptBox["\[Theta]", "2"]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"\[Epsilon]", "-", 
          SubscriptBox["\[Theta]", "3"]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"\[Epsilon]", "-", 
          SubscriptBox["\[Theta]", "4"]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"\[Epsilon]", "-", 
          SubscriptBox["\[Theta]", "2"]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SubscriptBox["z", "3"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "\[Epsilon]", "-", 
             RowBox[{"2", " ", 
              SubscriptBox["\[Theta]", "1"]}], "-", 
             RowBox[{"2", " ", 
              SubscriptBox["\[Theta]", "2"]}], "-", 
             SubscriptBox["\[Theta]", "3"]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"\[Epsilon]", "-", 
             SubscriptBox["\[Theta]", "4"]}], ")"}]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"\[Epsilon]", "-", 
             SubscriptBox["\[Theta]", "3"]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "\[Epsilon]"}], "+", 
             RowBox[{
              SubscriptBox["z", "4"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", "\[Epsilon]", "-", 
                RowBox[{"2", " ", 
                 SubscriptBox["\[Theta]", "1"]}], "-", 
                RowBox[{"2", " ", 
                 SubscriptBox["\[Theta]", "2"]}], "-", 
                RowBox[{"2", " ", 
                 SubscriptBox["\[Theta]", "3"]}], "-", 
                SubscriptBox["\[Theta]", "4"]}], ")"}]}], "+", 
             SubscriptBox["\[Theta]", "4"]}], ")"}]}]}], ")"}]}]}]},
     {
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"\[Epsilon]", "-", 
          SubscriptBox["\[Theta]", "3"]}], ")"}], " ", 
        SubscriptBox["\[Theta]", "3"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             SubscriptBox["z", "4"]}], ")"}], " ", 
           SubscriptBox["\[Theta]", "2"]}], "+", 
          RowBox[{"2", " ", 
           SubscriptBox["z", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"\[Epsilon]", "+", 
             SubscriptBox["\[Theta]", "3"]}], ")"}]}]}], ")"}]}], "-", 
       RowBox[{
        SubscriptBox["z", "3"], " ", 
        SubscriptBox["\[Theta]", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", "\[Epsilon]", "+", 
          RowBox[{"2", " ", 
           SuperscriptBox["\[Epsilon]", "2"]}], "+", 
          SubsuperscriptBox["\[Theta]", "1", "2"], "+", 
          SubsuperscriptBox["\[Theta]", "2", "2"], "+", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Theta]", "3"]}], "+", 
          RowBox[{"\[Epsilon]", " ", 
           SubscriptBox["\[Theta]", "3"]}], "+", 
          SubsuperscriptBox["\[Theta]", "3", "2"], "+", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Theta]", "4"]}], "+", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Theta]", "3"], " ", 
           SubscriptBox["\[Theta]", "4"]}], "+", 
          RowBox[{
           SubscriptBox["\[Theta]", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "3"}], " ", "\[Epsilon]"}], "+", 
             RowBox[{"2", " ", 
              SubscriptBox["\[Theta]", "4"]}]}], ")"}]}], "+", 
          RowBox[{
           SubscriptBox["\[Theta]", "1"], " ", 
           RowBox[{"(", 
            RowBox[{"2", "-", "\[Epsilon]", "+", 
             RowBox[{"2", " ", 
              SubscriptBox["\[Theta]", "2"]}], "+", 
             RowBox[{"2", " ", 
              SubscriptBox["\[Theta]", "3"]}], "+", 
             RowBox[{"2", " ", 
              SubscriptBox["\[Theta]", "4"]}]}], ")"}]}]}], ")"}]}]}]},
     {
      RowBox[{
       SubscriptBox["\[Theta]", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SubscriptBox["z", "3"], " ", 
          RowBox[{"(", 
           RowBox[{"\[Epsilon]", "-", 
            SubscriptBox["\[Theta]", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            SubscriptBox["\[Theta]", "2"]}], ")"}]}], "+", 
         RowBox[{
          SubscriptBox["z", "2"], " ", 
          SubscriptBox["\[Theta]", "3"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "\[Epsilon]"}], "+", 
            SubscriptBox["\[Theta]", "3"]}], ")"}]}]}], ")"}]}]},
     {
      RowBox[{
       SubscriptBox["\[Theta]", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SubscriptBox["z", "3"], " ", 
          RowBox[{"(", 
           RowBox[{"\[Epsilon]", "-", 
            SubscriptBox["\[Theta]", "1"]}], ")"}], " ", 
          SubscriptBox["\[Theta]", "1"]}], "+", 
         RowBox[{
          SubscriptBox["z", "1"], " ", 
          SubscriptBox["\[Theta]", "3"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "\[Epsilon]"}], "+", 
            SubscriptBox["\[Theta]", "3"]}], ")"}]}]}], ")"}]}]},
     {
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          SubscriptBox["z", "3"], "+", 
          SubscriptBox["z", "4"]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"\[Epsilon]", "-", 
          SubscriptBox["\[Theta]", "2"]}], ")"}], " ", 
        SubscriptBox["\[Theta]", "2"]}], "+", 
       RowBox[{
        SubscriptBox["z", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "\[Epsilon]", "-", 
          SubsuperscriptBox["\[Theta]", "1", "2"], "-", 
          SubsuperscriptBox["\[Theta]", "2", "2"], "-", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Theta]", "3"]}], "+", 
          RowBox[{
           SubscriptBox["\[Theta]", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "2"}], "+", "\[Epsilon]", "-", 
             RowBox[{"2", " ", 
              SubscriptBox["\[Theta]", "3"]}], "-", 
             RowBox[{"2", " ", 
              SubscriptBox["\[Theta]", "4"]}]}], ")"}]}], "+", 
          RowBox[{
           SubscriptBox["\[Theta]", "1"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "2"}], "+", "\[Epsilon]", "-", 
             RowBox[{"2", " ", 
              SubscriptBox["\[Theta]", "2"]}], "-", 
             RowBox[{"2", " ", 
              SubscriptBox["\[Theta]", "3"]}], "-", 
             RowBox[{"2", " ", 
              SubscriptBox["\[Theta]", "4"]}]}], ")"}]}], "-", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Theta]", "4"]}], "-", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Theta]", "3"], " ", 
           SubscriptBox["\[Theta]", "4"]}]}], ")"}]}]}]},
     {
      RowBox[{
       RowBox[{
        SubscriptBox["z", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"\[Epsilon]", "-", 
          SubscriptBox["\[Theta]", "1"]}], ")"}], " ", 
        SubscriptBox["\[Theta]", "1"]}], "+", 
       RowBox[{
        SubscriptBox["z", "1"], " ", 
        SubscriptBox["\[Theta]", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "\[Epsilon]"}], "+", 
          SubscriptBox["\[Theta]", "2"]}], ")"}]}]}]},
     {
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         SubscriptBox["z", "4"]}], " ", 
        RowBox[{"(", 
         RowBox[{"\[Epsilon]", "-", 
          SubscriptBox["\[Theta]", "2"]}], ")"}], " ", 
        SubscriptBox["\[Theta]", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"\[Epsilon]", "-", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Theta]", "1"]}], "-", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Theta]", "2"]}], "-", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Theta]", "3"]}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          SubscriptBox["z", "3"]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"\[Epsilon]", "-", 
          SubscriptBox["\[Theta]", "2"]}], ")"}], " ", 
        SubscriptBox["\[Theta]", "2"], " ", 
        SubscriptBox["\[Theta]", "4"]}], "-", 
       RowBox[{
        SubscriptBox["z", "2"], " ", 
        SubscriptBox["\[Theta]", "4"], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", "\[Epsilon]", "-", 
          SuperscriptBox["\[Epsilon]", "2"], "+", 
          SubsuperscriptBox["\[Theta]", "1", "2"], "+", 
          SubsuperscriptBox["\[Theta]", "2", "2"], "+", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Theta]", "3"]}], "+", 
          RowBox[{"2", " ", "\[Epsilon]", " ", 
           SubscriptBox["\[Theta]", "3"]}], "+", 
          RowBox[{
           SubscriptBox["\[Theta]", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"2", "+", "\[Epsilon]", "+", 
             RowBox[{"2", " ", 
              SubscriptBox["\[Theta]", "3"]}]}], ")"}]}], "+", 
          RowBox[{
           SubscriptBox["\[Theta]", "1"], " ", 
           RowBox[{"(", 
            RowBox[{"2", "+", "\[Epsilon]", "+", 
             RowBox[{"2", " ", 
              SubscriptBox["\[Theta]", "2"]}], "+", 
             RowBox[{"2", " ", 
              SubscriptBox["\[Theta]", "3"]}]}], ")"}]}], "+", 
          SubsuperscriptBox["\[Theta]", "4", "2"]}], ")"}]}]}]},
     {
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         SubscriptBox["z", "4"]}], " ", 
        RowBox[{"(", 
         RowBox[{"\[Epsilon]", "-", 
          SubscriptBox["\[Theta]", "2"]}], ")"}], " ", 
        SubscriptBox["\[Theta]", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", "\[Epsilon]", "+", 
          SubscriptBox["\[Theta]", "4"]}], ")"}]}], "+", 
       RowBox[{
        SubscriptBox["z", "2"], " ", 
        SubscriptBox["\[Theta]", "4"], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["\[Epsilon]", "2"], "-", 
          SubsuperscriptBox["\[Theta]", "4", "2"]}], ")"}]}]}]},
     {
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SubscriptBox["z", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"\[Epsilon]", "-", 
            SubscriptBox["\[Theta]", "1"]}], ")"}], " ", 
          SubscriptBox["\[Theta]", "1"]}], "+", 
         RowBox[{
          SubscriptBox["z", "1"], " ", 
          SubscriptBox["\[Theta]", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "\[Epsilon]"}], "+", 
            SubscriptBox["\[Theta]", "2"]}], ")"}]}]}], ")"}], " ", 
       SubscriptBox["\[Theta]", "4"]}]},
     {
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          SubscriptBox["z", "4"]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"\[Epsilon]", "-", 
          SubscriptBox["\[Theta]", "2"]}], ")"}], " ", 
        SubscriptBox["\[Theta]", "2"], " ", 
        SubscriptBox["\[Theta]", "3"]}], "-", 
       RowBox[{
        SubscriptBox["z", "3"], " ", 
        RowBox[{"(", 
         RowBox[{"\[Epsilon]", "-", 
          SubscriptBox["\[Theta]", "2"]}], ")"}], " ", 
        SubscriptBox["\[Theta]", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"\[Epsilon]", "-", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Theta]", "1"]}], "-", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Theta]", "2"]}], "-", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Theta]", "4"]}]}], ")"}]}], "-", 
       RowBox[{
        SubscriptBox["z", "2"], " ", 
        SubscriptBox["\[Theta]", "3"], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", "\[Epsilon]", "-", 
          SuperscriptBox["\[Epsilon]", "2"], "+", 
          SubsuperscriptBox["\[Theta]", "1", "2"], "+", 
          SubsuperscriptBox["\[Theta]", "2", "2"], "+", 
          SubsuperscriptBox["\[Theta]", "3", "2"], "+", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Theta]", "4"]}], "+", 
          RowBox[{"2", " ", "\[Epsilon]", " ", 
           SubscriptBox["\[Theta]", "4"]}], "+", 
          RowBox[{
           SubscriptBox["\[Theta]", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"2", "+", "\[Epsilon]", "+", 
             RowBox[{"2", " ", 
              SubscriptBox["\[Theta]", "4"]}]}], ")"}]}], "+", 
          RowBox[{
           SubscriptBox["\[Theta]", "1"], " ", 
           RowBox[{"(", 
            RowBox[{"2", "+", "\[Epsilon]", "+", 
             RowBox[{"2", " ", 
              SubscriptBox["\[Theta]", "2"]}], "+", 
             RowBox[{"2", " ", 
              SubscriptBox["\[Theta]", "4"]}]}], ")"}]}]}], ")"}]}]}]},
     {
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         SubscriptBox["z", "3"]}], " ", 
        RowBox[{"(", 
         RowBox[{"\[Epsilon]", "-", 
          SubscriptBox["\[Theta]", "2"]}], ")"}], " ", 
        SubscriptBox["\[Theta]", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", "\[Epsilon]", "+", 
          SubscriptBox["\[Theta]", "3"]}], ")"}]}], "+", 
       RowBox[{
        SubscriptBox["z", "2"], " ", 
        SubscriptBox["\[Theta]", "3"], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["\[Epsilon]", "2"], "-", 
          SubsuperscriptBox["\[Theta]", "3", "2"]}], ")"}]}]}]},
     {
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SubscriptBox["z", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"\[Epsilon]", "-", 
            SubscriptBox["\[Theta]", "1"]}], ")"}], " ", 
          SubscriptBox["\[Theta]", "1"]}], "+", 
         RowBox[{
          SubscriptBox["z", "1"], " ", 
          SubscriptBox["\[Theta]", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "\[Epsilon]"}], "+", 
            SubscriptBox["\[Theta]", "2"]}], ")"}]}]}], ")"}], " ", 
       SubscriptBox["\[Theta]", "3"]}]},
     {
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          SubscriptBox["z", "1"], "+", 
          SubscriptBox["z", "3"], "+", 
          SubscriptBox["z", "4"]}], ")"}], " ", 
        SubscriptBox["\[Theta]", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["\[Epsilon]", "2"], "-", 
          SubsuperscriptBox["\[Theta]", "2", "2"]}], ")"}]}], "+", 
       RowBox[{
        SubscriptBox["z", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", "\[Epsilon]", "+", 
          SubscriptBox["\[Theta]", "2"]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "\[Epsilon]", "-", 
          SubsuperscriptBox["\[Theta]", "2", "2"], "-", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Theta]", "3"]}], "+", 
          RowBox[{
           SubscriptBox["\[Theta]", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "2"}], "+", "\[Epsilon]", "-", 
             RowBox[{"2", " ", 
              SubscriptBox["\[Theta]", "3"]}], "-", 
             RowBox[{"2", " ", 
              SubscriptBox["\[Theta]", "4"]}]}], ")"}]}], "-", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Theta]", "4"]}], "-", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Theta]", "3"], " ", 
           SubscriptBox["\[Theta]", "4"]}], "-", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Theta]", "1"], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             SubscriptBox["\[Theta]", "2"], "+", 
             SubscriptBox["\[Theta]", "3"], "+", 
             SubscriptBox["\[Theta]", "4"]}], ")"}]}]}], ")"}]}]}]},
     {
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"\[Epsilon]", "-", 
          SubscriptBox["\[Theta]", "4"]}], ")"}], " ", 
        SubscriptBox["\[Theta]", "4"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           SubscriptBox["\[Theta]", "1"]}], "+", 
          RowBox[{"2", " ", 
           SubscriptBox["z", "1"], " ", 
           RowBox[{"(", 
            RowBox[{"\[Epsilon]", "+", 
             SubscriptBox["\[Theta]", "4"]}], ")"}]}]}], ")"}]}], "-", 
       RowBox[{
        SubscriptBox["z", "4"], " ", 
        SubscriptBox["\[Theta]", "1"], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", "\[Epsilon]", "+", 
          RowBox[{"2", " ", 
           SuperscriptBox["\[Epsilon]", "2"]}], "+", 
          SubsuperscriptBox["\[Theta]", "1", "2"], "+", 
          SubsuperscriptBox["\[Theta]", "2", "2"], "+", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Theta]", "3"]}], "-", 
          RowBox[{"\[Epsilon]", " ", 
           SubscriptBox["\[Theta]", "3"]}], "+", 
          SubsuperscriptBox["\[Theta]", "3", "2"], "+", 
          RowBox[{
           SubscriptBox["\[Theta]", "1"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "3"}], " ", "\[Epsilon]"}], "+", 
             RowBox[{"2", " ", 
              SubscriptBox["\[Theta]", "2"]}], "+", 
             RowBox[{"2", " ", 
              SubscriptBox["\[Theta]", "3"]}]}], ")"}]}], "+", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Theta]", "4"]}], "+", 
          RowBox[{"\[Epsilon]", " ", 
           SubscriptBox["\[Theta]", "4"]}], "+", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Theta]", "3"], " ", 
           SubscriptBox["\[Theta]", "4"]}], "+", 
          SubsuperscriptBox["\[Theta]", "4", "2"], "+", 
          RowBox[{
           SubscriptBox["\[Theta]", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"2", "-", "\[Epsilon]", "+", 
             RowBox[{"2", " ", 
              SubscriptBox["\[Theta]", "3"]}], "+", 
             RowBox[{"2", " ", 
              SubscriptBox["\[Theta]", "4"]}]}], ")"}]}]}], ")"}]}]}]},
     {
      RowBox[{
       SubscriptBox["\[Theta]", "1"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SubscriptBox["z", "4"], " ", 
          RowBox[{"(", 
           RowBox[{"\[Epsilon]", "-", 
            SubscriptBox["\[Theta]", "3"]}], ")"}], " ", 
          SubscriptBox["\[Theta]", "3"]}], "+", 
         RowBox[{
          SubscriptBox["z", "3"], " ", 
          SubscriptBox["\[Theta]", "4"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "\[Epsilon]"}], "+", 
            SubscriptBox["\[Theta]", "4"]}], ")"}]}]}], ")"}]}]},
     {
      RowBox[{
       SubscriptBox["\[Theta]", "1"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SubscriptBox["z", "4"], " ", 
          RowBox[{"(", 
           RowBox[{"\[Epsilon]", "-", 
            SubscriptBox["\[Theta]", "2"]}], ")"}], " ", 
          SubscriptBox["\[Theta]", "2"]}], "+", 
         RowBox[{
          SubscriptBox["z", "2"], " ", 
          SubscriptBox["\[Theta]", "4"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "\[Epsilon]"}], "+", 
            SubscriptBox["\[Theta]", "4"]}], ")"}]}]}], ")"}]}]},
     {
      RowBox[{
       SubscriptBox["\[Theta]", "1"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SubscriptBox["z", "4"], " ", 
          RowBox[{"(", 
           RowBox[{"\[Epsilon]", "-", 
            SubscriptBox["\[Theta]", "1"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            SubscriptBox["\[Theta]", "1"]}], ")"}]}], "+", 
         RowBox[{
          SubscriptBox["z", "1"], " ", 
          SubscriptBox["\[Theta]", "4"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "\[Epsilon]"}], "+", 
            SubscriptBox["\[Theta]", "4"]}], ")"}]}]}], ")"}]}]},
     {
      RowBox[{
       RowBox[{
        SubscriptBox["z", "1"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "\[Epsilon]", "-", 
          SubscriptBox["\[Theta]", "1"], "-", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Theta]", "2"]}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"\[Epsilon]", "-", 
          SubscriptBox["\[Theta]", "3"]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"\[Epsilon]", "-", 
          SubscriptBox["\[Theta]", "4"]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"\[Epsilon]", "-", 
          SubscriptBox["\[Theta]", "1"]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SubscriptBox["z", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"\[Epsilon]", "-", 
             SubscriptBox["\[Theta]", "3"]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"\[Epsilon]", "-", 
             SubscriptBox["\[Theta]", "4"]}], ")"}]}], "+", 
          RowBox[{
           SubscriptBox["z", "3"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "\[Epsilon]", "-", 
             RowBox[{"2", " ", 
              SubscriptBox["\[Theta]", "1"]}], "-", 
             RowBox[{"2", " ", 
              SubscriptBox["\[Theta]", "2"]}], "-", 
             SubscriptBox["\[Theta]", "3"]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"\[Epsilon]", "-", 
             SubscriptBox["\[Theta]", "4"]}], ")"}]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"\[Epsilon]", "-", 
             SubscriptBox["\[Theta]", "3"]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "\[Epsilon]"}], "+", 
             RowBox[{
              SubscriptBox["z", "4"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", "\[Epsilon]", "-", 
                RowBox[{"2", " ", 
                 SubscriptBox["\[Theta]", "1"]}], "-", 
                RowBox[{"2", " ", 
                 SubscriptBox["\[Theta]", "2"]}], "-", 
                RowBox[{"2", " ", 
                 SubscriptBox["\[Theta]", "3"]}], "-", 
                SubscriptBox["\[Theta]", "4"]}], ")"}]}], "+", 
             SubscriptBox["\[Theta]", "4"]}], ")"}]}]}], ")"}]}]}]},
     {
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"\[Epsilon]", "-", 
          SubscriptBox["\[Theta]", "3"]}], ")"}], " ", 
        SubscriptBox["\[Theta]", "3"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             SubscriptBox["z", "4"]}], ")"}], " ", 
           SubscriptBox["\[Theta]", "1"]}], "+", 
          RowBox[{"2", " ", 
           SubscriptBox["z", "1"], " ", 
           RowBox[{"(", 
            RowBox[{"\[Epsilon]", "+", 
             SubscriptBox["\[Theta]", "3"]}], ")"}]}]}], ")"}]}], "-", 
       RowBox[{
        SubscriptBox["z", "3"], " ", 
        SubscriptBox["\[Theta]", "1"], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", "\[Epsilon]", "+", 
          RowBox[{"2", " ", 
           SuperscriptBox["\[Epsilon]", "2"]}], "+", 
          SubsuperscriptBox["\[Theta]", "1", "2"], "+", 
          SubsuperscriptBox["\[Theta]", "2", "2"], "+", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Theta]", "3"]}], "+", 
          RowBox[{"\[Epsilon]", " ", 
           SubscriptBox["\[Theta]", "3"]}], "+", 
          SubsuperscriptBox["\[Theta]", "3", "2"], "+", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Theta]", "4"]}], "+", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Theta]", "3"], " ", 
           SubscriptBox["\[Theta]", "4"]}], "+", 
          RowBox[{
           SubscriptBox["\[Theta]", "1"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "3"}], " ", "\[Epsilon]"}], "+", 
             RowBox[{"2", " ", 
              SubscriptBox["\[Theta]", "2"]}], "+", 
             RowBox[{"2", " ", 
              SubscriptBox["\[Theta]", "4"]}]}], ")"}]}], "+", 
          RowBox[{
           SubscriptBox["\[Theta]", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"2", "-", "\[Epsilon]", "+", 
             RowBox[{"2", " ", 
              SubscriptBox["\[Theta]", "3"]}], "+", 
             RowBox[{"2", " ", 
              SubscriptBox["\[Theta]", "4"]}]}], ")"}]}]}], ")"}]}]}]},
     {
      RowBox[{
       SubscriptBox["\[Theta]", "1"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SubscriptBox["z", "3"], " ", 
          RowBox[{"(", 
           RowBox[{"\[Epsilon]", "-", 
            SubscriptBox["\[Theta]", "2"]}], ")"}], " ", 
          SubscriptBox["\[Theta]", "2"]}], "+", 
         RowBox[{
          SubscriptBox["z", "2"], " ", 
          SubscriptBox["\[Theta]", "3"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "\[Epsilon]"}], "+", 
            SubscriptBox["\[Theta]", "3"]}], ")"}]}]}], ")"}]}]},
     {
      RowBox[{
       SubscriptBox["\[Theta]", "1"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SubscriptBox["z", "3"], " ", 
          RowBox[{"(", 
           RowBox[{"\[Epsilon]", "-", 
            SubscriptBox["\[Theta]", "1"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            SubscriptBox["\[Theta]", "1"]}], ")"}]}], "+", 
         RowBox[{
          SubscriptBox["z", "1"], " ", 
          SubscriptBox["\[Theta]", "3"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "\[Epsilon]"}], "+", 
            SubscriptBox["\[Theta]", "3"]}], ")"}]}]}], ")"}]}]},
     {
      RowBox[{
       RowBox[{
        SubscriptBox["z", "1"], " ", 
        RowBox[{"(", 
         RowBox[{"\[Epsilon]", "-", 
          SubscriptBox["\[Theta]", "2"]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "\[Epsilon]", "-", 
          SubscriptBox["\[Theta]", "1"], "-", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Theta]", "3"]}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"\[Epsilon]", "-", 
          SubscriptBox["\[Theta]", "4"]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"\[Epsilon]", "-", 
          SubscriptBox["\[Theta]", "1"]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SubscriptBox["z", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "\[Epsilon]", "-", 
             RowBox[{"2", " ", 
              SubscriptBox["\[Theta]", "1"]}], "-", 
             SubscriptBox["\[Theta]", "2"], "-", 
             RowBox[{"2", " ", 
              SubscriptBox["\[Theta]", "3"]}]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"\[Epsilon]", "-", 
             SubscriptBox["\[Theta]", "4"]}], ")"}]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"\[Epsilon]", "-", 
             SubscriptBox["\[Theta]", "2"]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "\[Epsilon]"}], "+", 
             RowBox[{
              SubscriptBox["z", "3"], " ", 
              RowBox[{"(", 
               RowBox[{"\[Epsilon]", "-", 
                SubscriptBox["\[Theta]", "4"]}], ")"}]}], "+", 
             RowBox[{
              SubscriptBox["z", "4"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", "\[Epsilon]", "-", 
                RowBox[{"2", " ", 
                 SubscriptBox["\[Theta]", "1"]}], "-", 
                RowBox[{"2", " ", 
                 SubscriptBox["\[Theta]", "2"]}], "-", 
                RowBox[{"2", " ", 
                 SubscriptBox["\[Theta]", "3"]}], "-", 
                SubscriptBox["\[Theta]", "4"]}], ")"}]}], "+", 
             SubscriptBox["\[Theta]", "4"]}], ")"}]}]}], ")"}]}]}]},
     {
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"\[Epsilon]", "-", 
          SubscriptBox["\[Theta]", "1"]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"\[Epsilon]", "-", 
             SubscriptBox["\[Theta]", "2"]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                SubscriptBox["z", "4"]}], ")"}], " ", 
              RowBox[{"(", 
               RowBox[{"\[Epsilon]", "-", 
                SubscriptBox["\[Theta]", "3"]}], ")"}]}], "+", 
             RowBox[{
              SubscriptBox["z", "3"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", "\[Epsilon]", "-", 
                RowBox[{"2", " ", 
                 SubscriptBox["\[Theta]", "1"]}], "-", 
                RowBox[{"2", " ", 
                 SubscriptBox["\[Theta]", "2"]}], "-", 
                SubscriptBox["\[Theta]", "3"], "-", 
                RowBox[{"2", " ", 
                 SubscriptBox["\[Theta]", "4"]}]}], ")"}]}]}], ")"}]}], "+", 
          RowBox[{
           SubscriptBox["z", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"\[Epsilon]", "-", 
             SubscriptBox["\[Theta]", "3"]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "\[Epsilon]", "-", 
             RowBox[{"2", " ", 
              SubscriptBox["\[Theta]", "1"]}], "-", 
             SubscriptBox["\[Theta]", "2"], "-", 
             RowBox[{"2", " ", 
              SubscriptBox["\[Theta]", "4"]}]}], ")"}]}]}], ")"}]}], "+", 
       RowBox[{
        SubscriptBox["z", "1"], " ", 
        RowBox[{"(", 
         RowBox[{"\[Epsilon]", "-", 
          SubscriptBox["\[Theta]", "2"]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"\[Epsilon]", "-", 
          SubscriptBox["\[Theta]", "3"]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "\[Epsilon]", "-", 
          SubscriptBox["\[Theta]", "1"], "-", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Theta]", "4"]}]}], ")"}]}]}]},
     {
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"\[Epsilon]", "-", 
          SubscriptBox["\[Theta]", "2"]}], ")"}], " ", 
        SubscriptBox["\[Theta]", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             SubscriptBox["z", "3"], "+", 
             SubscriptBox["z", "4"]}], ")"}], " ", 
           SubscriptBox["\[Theta]", "1"]}], "+", 
          RowBox[{"2", " ", 
           SubscriptBox["z", "1"], " ", 
           RowBox[{"(", 
            RowBox[{"\[Epsilon]", "+", 
             SubscriptBox["\[Theta]", "2"]}], ")"}]}]}], ")"}]}], "-", 
       RowBox[{
        SubscriptBox["z", "2"], " ", 
        SubscriptBox["\[Theta]", "1"], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", "\[Epsilon]", "+", 
          RowBox[{"2", " ", 
           SuperscriptBox["\[Epsilon]", "2"]}], "+", 
          SubsuperscriptBox["\[Theta]", "1", "2"], "+", 
          SubsuperscriptBox["\[Theta]", "2", "2"], "+", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Theta]", "3"]}], "+", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Theta]", "4"]}], "+", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Theta]", "3"], " ", 
           SubscriptBox["\[Theta]", "4"]}], "+", 
          RowBox[{
           SubscriptBox["\[Theta]", "1"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "3"}], " ", "\[Epsilon]"}], "+", 
             RowBox[{"2", " ", 
              SubscriptBox["\[Theta]", "3"]}], "+", 
             RowBox[{"2", " ", 
              SubscriptBox["\[Theta]", "4"]}]}], ")"}]}], "+", 
          RowBox[{
           SubscriptBox["\[Theta]", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"2", "+", "\[Epsilon]", "+", 
             RowBox[{"2", " ", 
              SubscriptBox["\[Theta]", "3"]}], "+", 
             RowBox[{"2", " ", 
              SubscriptBox["\[Theta]", "4"]}]}], ")"}]}]}], ")"}]}]}]},
     {
      RowBox[{
       SubscriptBox["\[Theta]", "1"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SubscriptBox["z", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"\[Epsilon]", "-", 
            SubscriptBox["\[Theta]", "1"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            SubscriptBox["\[Theta]", "1"]}], ")"}]}], "+", 
         RowBox[{
          SubscriptBox["z", "1"], " ", 
          SubscriptBox["\[Theta]", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "\[Epsilon]"}], "+", 
            SubscriptBox["\[Theta]", "2"]}], ")"}]}]}], ")"}]}]},
     {
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          SubscriptBox["z", "2"], "+", 
          SubscriptBox["z", "3"], "+", 
          SubscriptBox["z", "4"]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"\[Epsilon]", "-", 
          SubscriptBox["\[Theta]", "1"]}], ")"}], " ", 
        SubscriptBox["\[Theta]", "1"]}], "+", 
       RowBox[{
        SubscriptBox["z", "1"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "\[Epsilon]", "-", 
          SubsuperscriptBox["\[Theta]", "1", "2"], "-", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Theta]", "3"]}], "+", 
          RowBox[{
           SubscriptBox["\[Theta]", "1"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "2"}], "+", "\[Epsilon]", "-", 
             RowBox[{"2", " ", 
              SubscriptBox["\[Theta]", "2"]}], "-", 
             RowBox[{"2", " ", 
              SubscriptBox["\[Theta]", "3"]}], "-", 
             RowBox[{"2", " ", 
              SubscriptBox["\[Theta]", "4"]}]}], ")"}]}], "-", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Theta]", "4"]}], "-", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Theta]", "3"], " ", 
           SubscriptBox["\[Theta]", "4"]}], "-", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Theta]", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             SubscriptBox["\[Theta]", "3"], "+", 
             SubscriptBox["\[Theta]", "4"]}], ")"}]}]}], ")"}]}]}]},
     {
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         SubscriptBox["z", "4"]}], " ", 
        RowBox[{"(", 
         RowBox[{"\[Epsilon]", "-", 
          SubscriptBox["\[Theta]", "1"]}], ")"}], " ", 
        SubscriptBox["\[Theta]", "1"], " ", 
        RowBox[{"(", 
         RowBox[{"\[Epsilon]", "-", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Theta]", "1"]}], "-", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Theta]", "2"]}], "-", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Theta]", "3"]}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          SubscriptBox["z", "2"], "+", 
          SubscriptBox["z", "3"]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"\[Epsilon]", "-", 
          SubscriptBox["\[Theta]", "1"]}], ")"}], " ", 
        SubscriptBox["\[Theta]", "1"], " ", 
        SubscriptBox["\[Theta]", "4"]}], "-", 
       RowBox[{
        SubscriptBox["z", "1"], " ", 
        SubscriptBox["\[Theta]", "4"], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", "\[Epsilon]", "-", 
          SuperscriptBox["\[Epsilon]", "2"], "+", 
          SubsuperscriptBox["\[Theta]", "1", "2"], "+", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Theta]", "3"]}], "+", 
          RowBox[{"2", " ", "\[Epsilon]", " ", 
           SubscriptBox["\[Theta]", "3"]}], "+", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Theta]", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", "\[Epsilon]", "+", 
             SubscriptBox["\[Theta]", "3"]}], ")"}]}], "+", 
          RowBox[{
           SubscriptBox["\[Theta]", "1"], " ", 
           RowBox[{"(", 
            RowBox[{"2", "+", "\[Epsilon]", "+", 
             RowBox[{"2", " ", 
              SubscriptBox["\[Theta]", "2"]}], "+", 
             RowBox[{"2", " ", 
              SubscriptBox["\[Theta]", "3"]}]}], ")"}]}], "+", 
          SubsuperscriptBox["\[Theta]", "4", "2"]}], ")"}]}]}]},
     {
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         SubscriptBox["z", "4"]}], " ", 
        RowBox[{"(", 
         RowBox[{"\[Epsilon]", "-", 
          SubscriptBox["\[Theta]", "1"]}], ")"}], " ", 
        SubscriptBox["\[Theta]", "1"], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", "\[Epsilon]", "+", 
          SubscriptBox["\[Theta]", "4"]}], ")"}]}], "+", 
       RowBox[{
        SubscriptBox["z", "1"], " ", 
        SubscriptBox["\[Theta]", "4"], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["\[Epsilon]", "2"], "-", 
          SubsuperscriptBox["\[Theta]", "4", "2"]}], ")"}]}]}]},
     {
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          SubscriptBox["z", "2"], "+", 
          SubscriptBox["z", "4"]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"\[Epsilon]", "-", 
          SubscriptBox["\[Theta]", "1"]}], ")"}], " ", 
        SubscriptBox["\[Theta]", "1"], " ", 
        SubscriptBox["\[Theta]", "3"]}], "-", 
       RowBox[{
        SubscriptBox["z", "3"], " ", 
        RowBox[{"(", 
         RowBox[{"\[Epsilon]", "-", 
          SubscriptBox["\[Theta]", "1"]}], ")"}], " ", 
        SubscriptBox["\[Theta]", "1"], " ", 
        RowBox[{"(", 
         RowBox[{"\[Epsilon]", "-", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Theta]", "1"]}], "-", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Theta]", "2"]}], "-", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Theta]", "4"]}]}], ")"}]}], "-", 
       RowBox[{
        SubscriptBox["z", "1"], " ", 
        SubscriptBox["\[Theta]", "3"], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", "\[Epsilon]", "-", 
          SuperscriptBox["\[Epsilon]", "2"], "+", 
          SubsuperscriptBox["\[Theta]", "1", "2"], "+", 
          SubsuperscriptBox["\[Theta]", "3", "2"], "+", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Theta]", "4"]}], "+", 
          RowBox[{"2", " ", "\[Epsilon]", " ", 
           SubscriptBox["\[Theta]", "4"]}], "+", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Theta]", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", "\[Epsilon]", "+", 
             SubscriptBox["\[Theta]", "4"]}], ")"}]}], "+", 
          RowBox[{
           SubscriptBox["\[Theta]", "1"], " ", 
           RowBox[{"(", 
            RowBox[{"2", "+", "\[Epsilon]", "+", 
             RowBox[{"2", " ", 
              SubscriptBox["\[Theta]", "2"]}], "+", 
             RowBox[{"2", " ", 
              SubscriptBox["\[Theta]", "4"]}]}], ")"}]}]}], ")"}]}]}]},
     {
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         SubscriptBox["z", "3"]}], " ", 
        RowBox[{"(", 
         RowBox[{"\[Epsilon]", "-", 
          SubscriptBox["\[Theta]", "1"]}], ")"}], " ", 
        SubscriptBox["\[Theta]", "1"], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", "\[Epsilon]", "+", 
          SubscriptBox["\[Theta]", "3"]}], ")"}]}], "+", 
       RowBox[{
        SubscriptBox["z", "1"], " ", 
        SubscriptBox["\[Theta]", "3"], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["\[Epsilon]", "2"], "-", 
          SubsuperscriptBox["\[Theta]", "3", "2"]}], ")"}]}]}]},
     {
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          SubscriptBox["z", "3"], "+", 
          SubscriptBox["z", "4"]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"\[Epsilon]", "-", 
          SubscriptBox["\[Theta]", "1"]}], ")"}], " ", 
        SubscriptBox["\[Theta]", "1"], " ", 
        SubscriptBox["\[Theta]", "2"]}], "-", 
       RowBox[{
        SubscriptBox["z", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"\[Epsilon]", "-", 
          SubscriptBox["\[Theta]", "1"]}], ")"}], " ", 
        SubscriptBox["\[Theta]", "1"], " ", 
        RowBox[{"(", 
         RowBox[{"\[Epsilon]", "-", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Theta]", "1"]}], "-", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Theta]", "3"]}], "-", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Theta]", "4"]}]}], ")"}]}], "-", 
       RowBox[{
        SubscriptBox["z", "1"], " ", 
        SubscriptBox["\[Theta]", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", "\[Epsilon]", "-", 
          SuperscriptBox["\[Epsilon]", "2"], "+", 
          SubsuperscriptBox["\[Theta]", "1", "2"], "+", 
          SubsuperscriptBox["\[Theta]", "2", "2"], "+", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Theta]", "3"]}], "+", 
          RowBox[{"2", " ", "\[Epsilon]", " ", 
           SubscriptBox["\[Theta]", "3"]}], "+", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Theta]", "4"]}], "+", 
          RowBox[{"2", " ", "\[Epsilon]", " ", 
           SubscriptBox["\[Theta]", "4"]}], "+", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Theta]", "3"], " ", 
           SubscriptBox["\[Theta]", "4"]}], "+", 
          RowBox[{
           SubscriptBox["\[Theta]", "1"], " ", 
           RowBox[{"(", 
            RowBox[{"2", "+", "\[Epsilon]", "+", 
             RowBox[{"2", " ", 
              SubscriptBox["\[Theta]", "3"]}], "+", 
             RowBox[{"2", " ", 
              SubscriptBox["\[Theta]", "4"]}]}], ")"}]}]}], ")"}]}]}]},
     {
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         SubscriptBox["z", "2"]}], " ", 
        RowBox[{"(", 
         RowBox[{"\[Epsilon]", "-", 
          SubscriptBox["\[Theta]", "1"]}], ")"}], " ", 
        SubscriptBox["\[Theta]", "1"], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", "\[Epsilon]", "+", 
          SubscriptBox["\[Theta]", "2"]}], ")"}]}], "+", 
       RowBox[{
        SubscriptBox["z", "1"], " ", 
        SubscriptBox["\[Theta]", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["\[Epsilon]", "2"], "-", 
          SubsuperscriptBox["\[Theta]", "2", "2"]}], ")"}]}]}]},
     {
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          SubscriptBox["z", "2"], "+", 
          SubscriptBox["z", "3"], "+", 
          SubscriptBox["z", "4"]}], ")"}], " ", 
        SubscriptBox["\[Theta]", "1"], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["\[Epsilon]", "2"], "-", 
          SubsuperscriptBox["\[Theta]", "1", "2"]}], ")"}]}], "+", 
       RowBox[{
        SubscriptBox["z", "1"], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", "\[Epsilon]", "+", 
          SubscriptBox["\[Theta]", "1"]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "\[Epsilon]", "-", 
          SubsuperscriptBox["\[Theta]", "1", "2"], "-", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Theta]", "3"]}], "+", 
          RowBox[{
           SubscriptBox["\[Theta]", "1"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "2"}], "+", "\[Epsilon]", "-", 
             RowBox[{"2", " ", 
              SubscriptBox["\[Theta]", "2"]}], "-", 
             RowBox[{"2", " ", 
              SubscriptBox["\[Theta]", "3"]}], "-", 
             RowBox[{"2", " ", 
              SubscriptBox["\[Theta]", "4"]}]}], ")"}]}], "-", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Theta]", "4"]}], "-", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Theta]", "3"], " ", 
           SubscriptBox["\[Theta]", "4"]}], "-", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Theta]", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             SubscriptBox["\[Theta]", "3"], "+", 
             SubscriptBox["\[Theta]", "4"]}], ")"}]}]}], ")"}]}]}]}
    },
    GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.5599999999999999]}, 
        Offset[0.27999999999999997`]}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}}],
   Column],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{{3.837677951745667*^9, 3.837678043666243*^9}, 
   3.837678200534234*^9, 3.837678284606859*^9},
 CellLabel->
  "Out[88]//TableForm=",ExpressionUUID->"80a46518-7123-4b15-98e2-\
bedbc8fe32f2"],

Cell[BoxData["54"], "Output",
 CellChangeTimes->{{3.837677951745667*^9, 3.837678043666243*^9}, 
   3.837678200534234*^9, 3.83767828462438*^9},
 CellLabel->"Out[89]=",ExpressionUUID->"090fe595-1f81-438f-8790-74a57180ed6a"]
}, Open  ]],

Cell[BoxData["\[IndentingNewLine]"], "Input",
 CellChangeTimes->{
  3.8376778420228643`*^9},ExpressionUUID->"99ad6b6b-bc4c-4084-9671-\
ba43239b1edc"],

Cell[TextData[{
 "We can also choose other bounds on the order of the operators and the \
degree of the polynomial in front of the derivatives. For example, we can \
take still l=3 but now ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["deg", "z"], TraditionalForm]],
  FormatType->TraditionalForm,ExpressionUUID->
  "5ff9743b-f488-4e32-b8d0-4c1ae118c32a"],
 "\[LessEqual]2 and ",
 Cell[BoxData[
  FormBox[
   RowBox[{" ", 
    RowBox[{
     SubscriptBox["ord", "\[Theta]"], "<=", "2"}]}], TraditionalForm]],
  FormatType->TraditionalForm,ExpressionUUID->
  "993f1eef-a49a-4ffc-b97d-0f03014db914"],
 ". Then we find:"
}], "Text",
 CellChangeTimes->{{3.837228677132165*^9, 3.837228718083098*^9}, {
   3.837228754218828*^9, 3.8372287545225058`*^9}, {3.8376780640935698`*^9, 
   3.837678187540554*^9}, {3.837678222731221*^9, 3.83767825181223*^9}, 
   3.837678328098852*^9},ExpressionUUID->"67b930ee-dfec-4369-b7a1-\
a3c231042242"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"OperatorsGenericMass", "[", 
   RowBox[{"3", ",", "2", ",", "2"}], "]"}], "//", 
  "Simplify"}], "\[IndentingNewLine]", 
 RowBox[{"%", "//", "Length"}]}], "Input",
 CellChangeTimes->{{3.837228669651752*^9, 3.837228670753717*^9}, {
  3.837228723934767*^9, 3.83722874984416*^9}, {3.837229130945356*^9, 
  3.837229134387401*^9}, {3.8372292342447557`*^9, 3.837229234876568*^9}, {
  3.837678191176303*^9, 3.837678192929996*^9}, {3.837678295981092*^9, 
  3.837678322227118*^9}},
 CellLabel->"In[96]:=",ExpressionUUID->"a46c0b69-47f0-41e2-b881-ef9eb1e55734"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["\[Theta]", "4"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "\[Epsilon]"}], "+", 
       SubscriptBox["\[Theta]", "4"]}], ")"}]}], "+", 
    RowBox[{
     SubsuperscriptBox["z", "4", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "\[Epsilon]", "-", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Theta]", "3"]}], "-", 
          SubscriptBox["\[Theta]", "4"]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          SubscriptBox["\[Theta]", "4"]}], ")"}]}], "-", 
       RowBox[{"2", " ", 
        SubscriptBox["\[Theta]", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          SubscriptBox["\[Theta]", "3"], "+", 
          SubscriptBox["\[Theta]", "4"]}], ")"}]}], "-", 
       RowBox[{"2", " ", 
        SubscriptBox["\[Theta]", "1"], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          SubscriptBox["\[Theta]", "2"], "+", 
          SubscriptBox["\[Theta]", "3"], "+", 
          SubscriptBox["\[Theta]", "4"]}], ")"}]}]}], ")"}]}], "+", 
    RowBox[{
     SubscriptBox["z", "4"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "\[Epsilon]", "-", 
       SubscriptBox["z", "3"], "+", 
       RowBox[{"\[Epsilon]", " ", 
        SubscriptBox["z", "3"]}], "-", 
       RowBox[{"2", " ", 
        SubscriptBox["\[Theta]", "1"]}], "-", 
       RowBox[{"2", " ", 
        SubscriptBox["z", "3"], " ", 
        SubscriptBox["\[Theta]", "1"]}], "+", 
       RowBox[{"2", " ", "\[Epsilon]", " ", 
        SubscriptBox["z", "3"], " ", 
        SubscriptBox["\[Theta]", "1"]}], "-", 
       RowBox[{"2", " ", 
        SubscriptBox["z", "3"], " ", 
        SubsuperscriptBox["\[Theta]", "1", "2"]}], "-", 
       RowBox[{"2", " ", 
        SubscriptBox["\[Theta]", "2"]}], "-", 
       RowBox[{"2", " ", 
        SubscriptBox["z", "3"], " ", 
        SubscriptBox["\[Theta]", "2"]}], "+", 
       RowBox[{"2", " ", "\[Epsilon]", " ", 
        SubscriptBox["z", "3"], " ", 
        SubscriptBox["\[Theta]", "2"]}], "-", 
       RowBox[{"2", " ", 
        SubscriptBox["\[Theta]", "1"], " ", 
        SubscriptBox["\[Theta]", "2"]}], "-", 
       RowBox[{"2", " ", 
        SubscriptBox["z", "3"], " ", 
        SubscriptBox["\[Theta]", "1"], " ", 
        SubscriptBox["\[Theta]", "2"]}], "-", 
       RowBox[{"2", " ", 
        SubscriptBox["z", "3"], " ", 
        SubsuperscriptBox["\[Theta]", "2", "2"]}], "-", 
       RowBox[{"2", " ", 
        SubscriptBox["\[Theta]", "3"]}], "-", 
       RowBox[{"2", " ", 
        SubscriptBox["z", "3"], " ", 
        SubscriptBox["\[Theta]", "3"]}], "+", 
       RowBox[{"\[Epsilon]", " ", 
        SubscriptBox["z", "3"], " ", 
        SubscriptBox["\[Theta]", "3"]}], "-", 
       RowBox[{"2", " ", 
        SubscriptBox["\[Theta]", "1"], " ", 
        SubscriptBox["\[Theta]", "3"]}], "-", 
       RowBox[{"2", " ", 
        SubscriptBox["z", "3"], " ", 
        SubscriptBox["\[Theta]", "1"], " ", 
        SubscriptBox["\[Theta]", "3"]}], "-", 
       RowBox[{"2", " ", 
        SubscriptBox["\[Theta]", "2"], " ", 
        SubscriptBox["\[Theta]", "3"]}], "-", 
       RowBox[{"2", " ", 
        SubscriptBox["z", "3"], " ", 
        SubscriptBox["\[Theta]", "2"], " ", 
        SubscriptBox["\[Theta]", "3"]}], "-", 
       RowBox[{
        SubscriptBox["z", "3"], " ", 
        SubsuperscriptBox["\[Theta]", "3", "2"]}], "-", 
       RowBox[{"2", " ", 
        SubscriptBox["\[Theta]", "4"]}], "-", 
       RowBox[{"2", " ", 
        SubscriptBox["z", "3"], " ", 
        SubscriptBox["\[Theta]", "4"]}], "+", 
       RowBox[{"2", " ", "\[Epsilon]", " ", 
        SubscriptBox["z", "3"], " ", 
        SubscriptBox["\[Theta]", "4"]}], "-", 
       RowBox[{"2", " ", 
        SubscriptBox["\[Theta]", "1"], " ", 
        SubscriptBox["\[Theta]", "4"]}], "-", 
       RowBox[{"2", " ", 
        SubscriptBox["z", "3"], " ", 
        SubscriptBox["\[Theta]", "1"], " ", 
        SubscriptBox["\[Theta]", "4"]}], "-", 
       RowBox[{"2", " ", 
        SubscriptBox["\[Theta]", "2"], " ", 
        SubscriptBox["\[Theta]", "4"]}], "-", 
       RowBox[{"2", " ", 
        SubscriptBox["z", "3"], " ", 
        SubscriptBox["\[Theta]", "2"], " ", 
        SubscriptBox["\[Theta]", "4"]}], "-", 
       RowBox[{"2", " ", 
        SubscriptBox["\[Theta]", "3"], " ", 
        SubscriptBox["\[Theta]", "4"]}], "-", 
       RowBox[{"2", " ", 
        SubscriptBox["z", "3"], " ", 
        SubscriptBox["\[Theta]", "3"], " ", 
        SubscriptBox["\[Theta]", "4"]}], "-", 
       RowBox[{"2", " ", 
        SubscriptBox["z", "3"], " ", 
        SubsuperscriptBox["\[Theta]", "4", "2"]}], "+", 
       RowBox[{
        SubscriptBox["z", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "\[Epsilon]", "-", 
          RowBox[{"2", " ", 
           SubsuperscriptBox["\[Theta]", "1", "2"]}], "-", 
          SubsuperscriptBox["\[Theta]", "2", "2"], "-", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Theta]", "3"]}], "+", 
          RowBox[{
           SubscriptBox["\[Theta]", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "2"}], "+", "\[Epsilon]", "-", 
             RowBox[{"2", " ", 
              SubscriptBox["\[Theta]", "3"]}], "-", 
             RowBox[{"2", " ", 
              SubscriptBox["\[Theta]", "4"]}]}], ")"}]}], "+", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Theta]", "1"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "\[Epsilon]", "-", 
             SubscriptBox["\[Theta]", "2"], "-", 
             SubscriptBox["\[Theta]", "3"], "-", 
             SubscriptBox["\[Theta]", "4"]}], ")"}]}], "-", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Theta]", "4"]}], "+", 
          RowBox[{"2", " ", "\[Epsilon]", " ", 
           SubscriptBox["\[Theta]", "4"]}], "-", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Theta]", "3"], " ", 
           SubscriptBox["\[Theta]", "4"]}], "-", 
          RowBox[{"2", " ", 
           SubsuperscriptBox["\[Theta]", "4", "2"]}]}], ")"}]}], "+", 
       RowBox[{
        SubscriptBox["z", "1"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "\[Epsilon]", "-", 
          SubsuperscriptBox["\[Theta]", "1", "2"], "-", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Theta]", "3"]}], "+", 
          RowBox[{
           SubscriptBox["\[Theta]", "1"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "2"}], "+", "\[Epsilon]", "-", 
             RowBox[{"2", " ", 
              SubscriptBox["\[Theta]", "2"]}], "-", 
             RowBox[{"2", " ", 
              SubscriptBox["\[Theta]", "3"]}], "-", 
             RowBox[{"2", " ", 
              SubscriptBox["\[Theta]", "4"]}]}], ")"}]}], "-", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Theta]", "4"]}], "+", 
          RowBox[{"2", " ", "\[Epsilon]", " ", 
           SubscriptBox["\[Theta]", "4"]}], "-", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Theta]", "3"], " ", 
           SubscriptBox["\[Theta]", "4"]}], "-", 
          RowBox[{"2", " ", 
           SubsuperscriptBox["\[Theta]", "4", "2"]}], "-", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Theta]", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             SubscriptBox["\[Theta]", "3"], "+", 
             SubscriptBox["\[Theta]", "4"]}], ")"}]}]}], ")"}]}]}], ")"}]}]}],
    ",", 
   RowBox[{
    SubscriptBox["z", "4"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         SubscriptBox["z", "1"], "+", 
         SubscriptBox["z", "2"], "+", 
         SubscriptBox["z", "3"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"\[Epsilon]", "-", 
         SubscriptBox["\[Theta]", "4"]}], ")"}], " ", 
       SubscriptBox["\[Theta]", "4"]}], "+", 
      RowBox[{
       SubscriptBox["z", "4"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "\[Epsilon]", "-", 
            RowBox[{"2", " ", 
             SubscriptBox["\[Theta]", "3"]}], "-", 
            SubscriptBox["\[Theta]", "4"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            SubscriptBox["\[Theta]", "4"]}], ")"}]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["\[Theta]", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            SubscriptBox["\[Theta]", "3"], "+", 
            SubscriptBox["\[Theta]", "4"]}], ")"}]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["\[Theta]", "1"], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            SubscriptBox["\[Theta]", "2"], "+", 
            SubscriptBox["\[Theta]", "3"], "+", 
            SubscriptBox["\[Theta]", "4"]}], ")"}]}]}], ")"}]}]}], ")"}]}], 
   ",", 
   RowBox[{
    SubscriptBox["z", "3"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[Theta]", "4"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "\[Epsilon]"}], "+", 
         SubscriptBox["\[Theta]", "4"]}], ")"}]}], "+", 
      RowBox[{
       SubscriptBox["z", "4"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "\[Epsilon]", "-", 
         SubscriptBox["\[Theta]", "1"], "-", 
         SubscriptBox["\[Theta]", "2"], "-", 
         SubscriptBox["\[Theta]", "3"], "-", 
         SubscriptBox["\[Theta]", "4"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         SubscriptBox["\[Theta]", "1"], "+", 
         SubscriptBox["\[Theta]", "2"], "+", 
         SubscriptBox["\[Theta]", "3"], "+", 
         SubscriptBox["\[Theta]", "4"]}], ")"}]}]}], ")"}]}], ",", 
   RowBox[{
    SubscriptBox["z", "3"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SubscriptBox["z", "4"], " ", 
       RowBox[{"(", 
        RowBox[{"\[Epsilon]", "-", 
         SubscriptBox["\[Theta]", "3"]}], ")"}], " ", 
       SubscriptBox["\[Theta]", "3"]}], "+", 
      RowBox[{
       SubscriptBox["z", "3"], " ", 
       SubscriptBox["\[Theta]", "4"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "\[Epsilon]"}], "+", 
         SubscriptBox["\[Theta]", "4"]}], ")"}]}]}], ")"}]}], ",", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "3"], " ", 
     SubscriptBox["z", "4"], " ", 
     RowBox[{"(", 
      RowBox[{"\[Epsilon]", "-", 
       SubscriptBox["\[Theta]", "2"]}], ")"}], " ", 
     SubscriptBox["\[Theta]", "2"]}], "+", 
    RowBox[{
     SubscriptBox["z", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SubscriptBox["\[Theta]", "4"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "\[Epsilon]"}], "+", 
          SubscriptBox["\[Theta]", "4"]}], ")"}]}], "+", 
       RowBox[{
        SubscriptBox["z", "4"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "\[Epsilon]", "-", 
          SubscriptBox["\[Theta]", "1"], "-", 
          SubscriptBox["\[Theta]", "2"], "-", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Theta]", "3"]}], "-", 
          SubscriptBox["\[Theta]", "4"]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          SubscriptBox["\[Theta]", "1"], "+", 
          SubscriptBox["\[Theta]", "2"], "+", 
          SubscriptBox["\[Theta]", "4"]}], ")"}]}]}], ")"}]}]}], ",", 
   RowBox[{
    SubscriptBox["z", "3"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SubscriptBox["z", "4"], " ", 
       RowBox[{"(", 
        RowBox[{"\[Epsilon]", "-", 
         SubscriptBox["\[Theta]", "2"]}], ")"}], " ", 
       SubscriptBox["\[Theta]", "2"]}], "+", 
      RowBox[{
       SubscriptBox["z", "2"], " ", 
       SubscriptBox["\[Theta]", "4"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "\[Epsilon]"}], "+", 
         SubscriptBox["\[Theta]", "4"]}], ")"}]}]}], ")"}]}], ",", 
   RowBox[{
    SubscriptBox["z", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SubscriptBox["z", "4"], " ", 
       RowBox[{"(", 
        RowBox[{"\[Epsilon]", "-", 
         SubscriptBox["\[Theta]", "2"]}], ")"}], " ", 
       SubscriptBox["\[Theta]", "2"]}], "+", 
      RowBox[{
       SubscriptBox["z", "2"], " ", 
       SubscriptBox["\[Theta]", "4"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "\[Epsilon]"}], "+", 
         SubscriptBox["\[Theta]", "4"]}], ")"}]}]}], ")"}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["z", "2"], "+", 
       SubscriptBox["z", "3"]}], ")"}], " ", 
     SubscriptBox["z", "4"], " ", 
     RowBox[{"(", 
      RowBox[{"\[Epsilon]", "-", 
       SubscriptBox["\[Theta]", "1"]}], ")"}], " ", 
     SubscriptBox["\[Theta]", "1"]}], "+", 
    RowBox[{
     SubscriptBox["z", "1"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SubscriptBox["\[Theta]", "4"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "\[Epsilon]"}], "+", 
          SubscriptBox["\[Theta]", "4"]}], ")"}]}], "+", 
       RowBox[{
        SubscriptBox["z", "4"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           SubsuperscriptBox["\[Theta]", "1", "2"]}], "+", 
          RowBox[{
           SubscriptBox["\[Theta]", "1"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "2"}], "+", "\[Epsilon]", "-", 
             RowBox[{"2", " ", 
              SubscriptBox["\[Theta]", "2"]}], "-", 
             RowBox[{"2", " ", 
              SubscriptBox["\[Theta]", "3"]}], "-", 
             RowBox[{"2", " ", 
              SubscriptBox["\[Theta]", "4"]}]}], ")"}]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "\[Epsilon]", "-", 
             RowBox[{"2", " ", 
              SubscriptBox["\[Theta]", "3"]}], "-", 
             SubscriptBox["\[Theta]", "4"]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             SubscriptBox["\[Theta]", "4"]}], ")"}]}], "-", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Theta]", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             SubscriptBox["\[Theta]", "3"], "+", 
             SubscriptBox["\[Theta]", "4"]}], ")"}]}]}], ")"}]}]}], ")"}]}]}],
    ",", 
   RowBox[{
    SubscriptBox["z", "3"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SubscriptBox["z", "4"], " ", 
       RowBox[{"(", 
        RowBox[{"\[Epsilon]", "-", 
         SubscriptBox["\[Theta]", "1"]}], ")"}], " ", 
       SubscriptBox["\[Theta]", "1"]}], "+", 
      RowBox[{
       SubscriptBox["z", "1"], " ", 
       SubscriptBox["\[Theta]", "4"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "\[Epsilon]"}], "+", 
         SubscriptBox["\[Theta]", "4"]}], ")"}]}]}], ")"}]}], ",", 
   RowBox[{
    SubscriptBox["z", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SubscriptBox["z", "4"], " ", 
       RowBox[{"(", 
        RowBox[{"\[Epsilon]", "-", 
         SubscriptBox["\[Theta]", "1"]}], ")"}], " ", 
       SubscriptBox["\[Theta]", "1"]}], "+", 
      RowBox[{
       SubscriptBox["z", "1"], " ", 
       SubscriptBox["\[Theta]", "4"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "\[Epsilon]"}], "+", 
         SubscriptBox["\[Theta]", "4"]}], ")"}]}]}], ")"}]}], ",", 
   RowBox[{
    SubscriptBox["z", "1"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SubscriptBox["z", "4"], " ", 
       RowBox[{"(", 
        RowBox[{"\[Epsilon]", "-", 
         SubscriptBox["\[Theta]", "1"]}], ")"}], " ", 
       SubscriptBox["\[Theta]", "1"]}], "+", 
      RowBox[{
       SubscriptBox["z", "1"], " ", 
       SubscriptBox["\[Theta]", "4"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "\[Epsilon]"}], "+", 
         SubscriptBox["\[Theta]", "4"]}], ")"}]}]}], ")"}]}], ",", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[Theta]", "3"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "\[Epsilon]"}], "+", 
       SubscriptBox["\[Theta]", "3"]}], ")"}]}], "+", 
    RowBox[{
     SubsuperscriptBox["z", "3", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", 
        SubscriptBox["\[Theta]", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          SubscriptBox["\[Theta]", "3"], "+", 
          SubscriptBox["\[Theta]", "4"]}], ")"}]}], "-", 
       RowBox[{"2", " ", 
        SubscriptBox["\[Theta]", "1"], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          SubscriptBox["\[Theta]", "2"], "+", 
          SubscriptBox["\[Theta]", "3"], "+", 
          SubscriptBox["\[Theta]", "4"]}], ")"}]}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "+", 
          SubscriptBox["\[Theta]", "3"]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"1", "-", "\[Epsilon]", "+", 
          SubscriptBox["\[Theta]", "3"], "+", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Theta]", "4"]}]}], ")"}]}]}], ")"}]}], "+", 
    RowBox[{
     SubscriptBox["z", "3"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "\[Epsilon]", "-", 
       SubscriptBox["z", "4"], "+", 
       RowBox[{"\[Epsilon]", " ", 
        SubscriptBox["z", "4"]}], "-", 
       RowBox[{"2", " ", 
        SubscriptBox["\[Theta]", "1"]}], "-", 
       RowBox[{"2", " ", 
        SubscriptBox["z", "4"], " ", 
        SubscriptBox["\[Theta]", "1"]}], "+", 
       RowBox[{"2", " ", "\[Epsilon]", " ", 
        SubscriptBox["z", "4"], " ", 
        SubscriptBox["\[Theta]", "1"]}], "-", 
       RowBox[{"2", " ", 
        SubscriptBox["z", "4"], " ", 
        SubsuperscriptBox["\[Theta]", "1", "2"]}], "-", 
       RowBox[{"2", " ", 
        SubscriptBox["\[Theta]", "2"]}], "-", 
       RowBox[{"2", " ", 
        SubscriptBox["z", "4"], " ", 
        SubscriptBox["\[Theta]", "2"]}], "+", 
       RowBox[{"2", " ", "\[Epsilon]", " ", 
        SubscriptBox["z", "4"], " ", 
        SubscriptBox["\[Theta]", "2"]}], "-", 
       RowBox[{"2", " ", 
        SubscriptBox["\[Theta]", "1"], " ", 
        SubscriptBox["\[Theta]", "2"]}], "-", 
       RowBox[{"2", " ", 
        SubscriptBox["z", "4"], " ", 
        SubscriptBox["\[Theta]", "1"], " ", 
        SubscriptBox["\[Theta]", "2"]}], "-", 
       RowBox[{"2", " ", 
        SubscriptBox["z", "4"], " ", 
        SubsuperscriptBox["\[Theta]", "2", "2"]}], "-", 
       RowBox[{"2", " ", 
        SubscriptBox["\[Theta]", "3"]}], "-", 
       RowBox[{"2", " ", 
        SubscriptBox["z", "4"], " ", 
        SubscriptBox["\[Theta]", "3"]}], "+", 
       RowBox[{"2", " ", "\[Epsilon]", " ", 
        SubscriptBox["z", "4"], " ", 
        SubscriptBox["\[Theta]", "3"]}], "-", 
       RowBox[{"2", " ", 
        SubscriptBox["\[Theta]", "1"], " ", 
        SubscriptBox["\[Theta]", "3"]}], "-", 
       RowBox[{"2", " ", 
        SubscriptBox["z", "4"], " ", 
        SubscriptBox["\[Theta]", "1"], " ", 
        SubscriptBox["\[Theta]", "3"]}], "-", 
       RowBox[{"2", " ", 
        SubscriptBox["\[Theta]", "2"], " ", 
        SubscriptBox["\[Theta]", "3"]}], "-", 
       RowBox[{"2", " ", 
        SubscriptBox["z", "4"], " ", 
        SubscriptBox["\[Theta]", "2"], " ", 
        SubscriptBox["\[Theta]", "3"]}], "-", 
       RowBox[{"2", " ", 
        SubscriptBox["z", "4"], " ", 
        SubsuperscriptBox["\[Theta]", "3", "2"]}], "-", 
       RowBox[{"2", " ", 
        SubscriptBox["\[Theta]", "4"]}], "-", 
       RowBox[{"2", " ", 
        SubscriptBox["z", "4"], " ", 
        SubscriptBox["\[Theta]", "4"]}], "+", 
       RowBox[{"\[Epsilon]", " ", 
        SubscriptBox["z", "4"], " ", 
        SubscriptBox["\[Theta]", "4"]}], "-", 
       RowBox[{"2", " ", 
        SubscriptBox["\[Theta]", "1"], " ", 
        SubscriptBox["\[Theta]", "4"]}], "-", 
       RowBox[{"2", " ", 
        SubscriptBox["z", "4"], " ", 
        SubscriptBox["\[Theta]", "1"], " ", 
        SubscriptBox["\[Theta]", "4"]}], "-", 
       RowBox[{"2", " ", 
        SubscriptBox["\[Theta]", "2"], " ", 
        SubscriptBox["\[Theta]", "4"]}], "-", 
       RowBox[{"2", " ", 
        SubscriptBox["z", "4"], " ", 
        SubscriptBox["\[Theta]", "2"], " ", 
        SubscriptBox["\[Theta]", "4"]}], "-", 
       RowBox[{"2", " ", 
        SubscriptBox["\[Theta]", "3"], " ", 
        SubscriptBox["\[Theta]", "4"]}], "-", 
       RowBox[{"2", " ", 
        SubscriptBox["z", "4"], " ", 
        SubscriptBox["\[Theta]", "3"], " ", 
        SubscriptBox["\[Theta]", "4"]}], "-", 
       RowBox[{
        SubscriptBox["z", "4"], " ", 
        SubsuperscriptBox["\[Theta]", "4", "2"]}], "+", 
       RowBox[{
        SubscriptBox["z", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "\[Epsilon]", "-", 
          RowBox[{"2", " ", 
           SubsuperscriptBox["\[Theta]", "1", "2"]}], "-", 
          SubsuperscriptBox["\[Theta]", "2", "2"], "-", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Theta]", "3"]}], "+", 
          RowBox[{"2", " ", "\[Epsilon]", " ", 
           SubscriptBox["\[Theta]", "3"]}], "-", 
          RowBox[{"2", " ", 
           SubsuperscriptBox["\[Theta]", "3", "2"]}], "+", 
          RowBox[{
           SubscriptBox["\[Theta]", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "2"}], "+", "\[Epsilon]", "-", 
             RowBox[{"2", " ", 
              SubscriptBox["\[Theta]", "3"]}], "-", 
             RowBox[{"2", " ", 
              SubscriptBox["\[Theta]", "4"]}]}], ")"}]}], "+", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Theta]", "1"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "\[Epsilon]", "-", 
             SubscriptBox["\[Theta]", "2"], "-", 
             SubscriptBox["\[Theta]", "3"], "-", 
             SubscriptBox["\[Theta]", "4"]}], ")"}]}], "-", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Theta]", "4"]}], "-", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Theta]", "3"], " ", 
           SubscriptBox["\[Theta]", "4"]}]}], ")"}]}], "+", 
       RowBox[{
        SubscriptBox["z", "1"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "\[Epsilon]", "-", 
          SubsuperscriptBox["\[Theta]", "1", "2"], "-", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Theta]", "3"]}], "+", 
          RowBox[{"2", " ", "\[Epsilon]", " ", 
           SubscriptBox["\[Theta]", "3"]}], "-", 
          RowBox[{"2", " ", 
           SubsuperscriptBox["\[Theta]", "3", "2"]}], "+", 
          RowBox[{
           SubscriptBox["\[Theta]", "1"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "2"}], "+", "\[Epsilon]", "-", 
             RowBox[{"2", " ", 
              SubscriptBox["\[Theta]", "2"]}], "-", 
             RowBox[{"2", " ", 
              SubscriptBox["\[Theta]", "3"]}], "-", 
             RowBox[{"2", " ", 
              SubscriptBox["\[Theta]", "4"]}]}], ")"}]}], "-", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Theta]", "4"]}], "-", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Theta]", "3"], " ", 
           SubscriptBox["\[Theta]", "4"]}], "-", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Theta]", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             SubscriptBox["\[Theta]", "3"], "+", 
             SubscriptBox["\[Theta]", "4"]}], ")"}]}]}], ")"}]}]}], ")"}]}]}],
    ",", 
   RowBox[{
    SubscriptBox["z", "4"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[Theta]", "3"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "\[Epsilon]"}], "+", 
         SubscriptBox["\[Theta]", "3"]}], ")"}]}], "+", 
      RowBox[{
       SubscriptBox["z", "3"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "\[Epsilon]", "-", 
         SubscriptBox["\[Theta]", "1"], "-", 
         SubscriptBox["\[Theta]", "2"], "-", 
         SubscriptBox["\[Theta]", "3"], "-", 
         SubscriptBox["\[Theta]", "4"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         SubscriptBox["\[Theta]", "1"], "+", 
         SubscriptBox["\[Theta]", "2"], "+", 
         SubscriptBox["\[Theta]", "3"], "+", 
         SubscriptBox["\[Theta]", "4"]}], ")"}]}]}], ")"}]}], ",", 
   RowBox[{
    SubscriptBox["z", "4"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SubscriptBox["z", "4"], " ", 
       SubscriptBox["\[Theta]", "3"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "\[Epsilon]"}], "+", 
         SubscriptBox["\[Theta]", "3"]}], ")"}]}], "+", 
      RowBox[{
       SubscriptBox["z", "3"], " ", 
       RowBox[{"(", 
        RowBox[{"\[Epsilon]", "-", 
         SubscriptBox["\[Theta]", "4"]}], ")"}], " ", 
       SubscriptBox["\[Theta]", "4"]}]}], ")"}]}], ",", 
   RowBox[{
    SubscriptBox["z", "3"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         SubscriptBox["z", "1"], "+", 
         SubscriptBox["z", "2"], "+", 
         SubscriptBox["z", "4"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"\[Epsilon]", "-", 
         SubscriptBox["\[Theta]", "3"]}], ")"}], " ", 
       SubscriptBox["\[Theta]", "3"]}], "+", 
      RowBox[{
       SubscriptBox["z", "3"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], " ", 
          SubscriptBox["\[Theta]", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            SubscriptBox["\[Theta]", "3"], "+", 
            SubscriptBox["\[Theta]", "4"]}], ")"}]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["\[Theta]", "1"], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            SubscriptBox["\[Theta]", "2"], "+", 
            SubscriptBox["\[Theta]", "3"], "+", 
            SubscriptBox["\[Theta]", "4"]}], ")"}]}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "+", 
            SubscriptBox["\[Theta]", "3"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"1", "-", "\[Epsilon]", "+", 
            SubscriptBox["\[Theta]", "3"], "+", 
            RowBox[{"2", " ", 
             SubscriptBox["\[Theta]", "4"]}]}], ")"}]}]}], ")"}]}]}], ")"}]}],
    ",", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "3"], " ", 
     SubscriptBox["z", "4"], " ", 
     RowBox[{"(", 
      RowBox[{"\[Epsilon]", "-", 
       SubscriptBox["\[Theta]", "2"]}], ")"}], " ", 
     SubscriptBox["\[Theta]", "2"]}], "+", 
    RowBox[{
     SubscriptBox["z", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SubscriptBox["\[Theta]", "3"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "\[Epsilon]"}], "+", 
          SubscriptBox["\[Theta]", "3"]}], ")"}]}], "-", 
       RowBox[{
        SubscriptBox["z", "3"], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          SubscriptBox["\[Theta]", "1"], "+", 
          SubscriptBox["\[Theta]", "2"], "+", 
          SubscriptBox["\[Theta]", "3"]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"1", "-", "\[Epsilon]", "+", 
          SubscriptBox["\[Theta]", "1"], "+", 
          SubscriptBox["\[Theta]", "2"], "+", 
          SubscriptBox["\[Theta]", "3"], "+", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Theta]", "4"]}]}], ")"}]}]}], ")"}]}]}], ",", 
   RowBox[{
    SubscriptBox["z", "4"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SubscriptBox["z", "3"], " ", 
       RowBox[{"(", 
        RowBox[{"\[Epsilon]", "-", 
         SubscriptBox["\[Theta]", "2"]}], ")"}], " ", 
       SubscriptBox["\[Theta]", "2"]}], "+", 
      RowBox[{
       SubscriptBox["z", "2"], " ", 
       SubscriptBox["\[Theta]", "3"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "\[Epsilon]"}], "+", 
         SubscriptBox["\[Theta]", "3"]}], ")"}]}]}], ")"}]}], ",", 
   RowBox[{
    SubscriptBox["z", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SubscriptBox["z", "3"], " ", 
       RowBox[{"(", 
        RowBox[{"\[Epsilon]", "-", 
         SubscriptBox["\[Theta]", "2"]}], ")"}], " ", 
       SubscriptBox["\[Theta]", "2"]}], "+", 
      RowBox[{
       SubscriptBox["z", "2"], " ", 
       SubscriptBox["\[Theta]", "3"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "\[Epsilon]"}], "+", 
         SubscriptBox["\[Theta]", "3"]}], ")"}]}]}], ")"}]}], ",", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "3"], " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["z", "2"], "+", 
       SubscriptBox["z", "4"]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"\[Epsilon]", "-", 
       SubscriptBox["\[Theta]", "1"]}], ")"}], " ", 
     SubscriptBox["\[Theta]", "1"]}], "+", 
    RowBox[{
     SubscriptBox["z", "1"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SubscriptBox["\[Theta]", "3"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "\[Epsilon]"}], "+", 
          SubscriptBox["\[Theta]", "3"]}], ")"}]}], "+", 
       RowBox[{
        SubscriptBox["z", "3"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           SubsuperscriptBox["\[Theta]", "1", "2"]}], "+", 
          RowBox[{
           SubscriptBox["\[Theta]", "1"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "2"}], "+", "\[Epsilon]", "-", 
             RowBox[{"2", " ", 
              SubscriptBox["\[Theta]", "2"]}], "-", 
             RowBox[{"2", " ", 
              SubscriptBox["\[Theta]", "3"]}], "-", 
             RowBox[{"2", " ", 
              SubscriptBox["\[Theta]", "4"]}]}], ")"}]}], "-", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Theta]", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             SubscriptBox["\[Theta]", "3"], "+", 
             SubscriptBox["\[Theta]", "4"]}], ")"}]}], "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "+", 
             SubscriptBox["\[Theta]", "3"]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"1", "-", "\[Epsilon]", "+", 
             SubscriptBox["\[Theta]", "3"], "+", 
             RowBox[{"2", " ", 
              SubscriptBox["\[Theta]", "4"]}]}], ")"}]}]}], ")"}]}]}], 
      ")"}]}]}], ",", 
   RowBox[{
    SubscriptBox["z", "4"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SubscriptBox["z", "3"], " ", 
       RowBox[{"(", 
        RowBox[{"\[Epsilon]", "-", 
         SubscriptBox["\[Theta]", "1"]}], ")"}], " ", 
       SubscriptBox["\[Theta]", "1"]}], "+", 
      RowBox[{
       SubscriptBox["z", "1"], " ", 
       SubscriptBox["\[Theta]", "3"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "\[Epsilon]"}], "+", 
         SubscriptBox["\[Theta]", "3"]}], ")"}]}]}], ")"}]}], ",", 
   RowBox[{
    SubscriptBox["z", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SubscriptBox["z", "3"], " ", 
       RowBox[{"(", 
        RowBox[{"\[Epsilon]", "-", 
         SubscriptBox["\[Theta]", "1"]}], ")"}], " ", 
       SubscriptBox["\[Theta]", "1"]}], "+", 
      RowBox[{
       SubscriptBox["z", "1"], " ", 
       SubscriptBox["\[Theta]", "3"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "\[Epsilon]"}], "+", 
         SubscriptBox["\[Theta]", "3"]}], ")"}]}]}], ")"}]}], ",", 
   RowBox[{
    SubscriptBox["z", "1"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SubscriptBox["z", "3"], " ", 
       RowBox[{"(", 
        RowBox[{"\[Epsilon]", "-", 
         SubscriptBox["\[Theta]", "1"]}], ")"}], " ", 
       SubscriptBox["\[Theta]", "1"]}], "+", 
      RowBox[{
       SubscriptBox["z", "1"], " ", 
       SubscriptBox["\[Theta]", "3"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "\[Epsilon]"}], "+", 
         SubscriptBox["\[Theta]", "3"]}], ")"}]}]}], ")"}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{"2", " ", 
        SubscriptBox["z", "3"], " ", 
        SubscriptBox["z", "4"]}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"\[Epsilon]", "-", 
       SubscriptBox["\[Theta]", "2"]}], ")"}], " ", 
     SubscriptBox["\[Theta]", "2"]}], "+", 
    RowBox[{
     SubsuperscriptBox["z", "2", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "\[Epsilon]", "-", 
       SubsuperscriptBox["\[Theta]", "2", "2"], "-", 
       RowBox[{"2", " ", 
        SubscriptBox["\[Theta]", "3"]}], "+", 
       RowBox[{
        SubscriptBox["\[Theta]", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "2"}], "+", "\[Epsilon]", "-", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Theta]", "3"]}], "-", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Theta]", "4"]}]}], ")"}]}], "-", 
       RowBox[{"2", " ", 
        SubscriptBox["\[Theta]", "4"]}], "-", 
       RowBox[{"2", " ", 
        SubscriptBox["\[Theta]", "3"], " ", 
        SubscriptBox["\[Theta]", "4"]}], "-", 
       RowBox[{"2", " ", 
        SubscriptBox["\[Theta]", "1"], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          SubscriptBox["\[Theta]", "2"], "+", 
          SubscriptBox["\[Theta]", "3"], "+", 
          SubscriptBox["\[Theta]", "4"]}], ")"}]}]}], ")"}]}], "+", 
    RowBox[{
     SubscriptBox["z", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "\[Epsilon]", "-", 
       SubscriptBox["z", "4"], "+", 
       RowBox[{"\[Epsilon]", " ", 
        SubscriptBox["z", "4"]}], "-", 
       RowBox[{"2", " ", 
        SubscriptBox["\[Theta]", "1"]}], "-", 
       RowBox[{"2", " ", 
        SubscriptBox["z", "4"], " ", 
        SubscriptBox["\[Theta]", "1"]}], "+", 
       RowBox[{"2", " ", "\[Epsilon]", " ", 
        SubscriptBox["z", "4"], " ", 
        SubscriptBox["\[Theta]", "1"]}], "-", 
       RowBox[{"2", " ", 
        SubscriptBox["z", "4"], " ", 
        SubsuperscriptBox["\[Theta]", "1", "2"]}], "-", 
       RowBox[{"2", " ", 
        SubscriptBox["\[Theta]", "2"]}], "-", 
       RowBox[{"2", " ", 
        SubscriptBox["z", "4"], " ", 
        SubscriptBox["\[Theta]", "2"]}], "+", 
       RowBox[{"2", " ", "\[Epsilon]", " ", 
        SubscriptBox["z", "4"], " ", 
        SubscriptBox["\[Theta]", "2"]}], "-", 
       RowBox[{"2", " ", 
        SubscriptBox["\[Theta]", "1"], " ", 
        SubscriptBox["\[Theta]", "2"]}], "-", 
       RowBox[{"2", " ", 
        SubscriptBox["z", "4"], " ", 
        SubscriptBox["\[Theta]", "1"], " ", 
        SubscriptBox["\[Theta]", "2"]}], "-", 
       RowBox[{"2", " ", 
        SubscriptBox["z", "4"], " ", 
        SubsuperscriptBox["\[Theta]", "2", "2"]}], "-", 
       RowBox[{"2", " ", 
        SubscriptBox["\[Theta]", "3"]}], "-", 
       RowBox[{"2", " ", 
        SubscriptBox["z", "4"], " ", 
        SubscriptBox["\[Theta]", "3"]}], "-", 
       RowBox[{"2", " ", 
        SubscriptBox["\[Theta]", "1"], " ", 
        SubscriptBox["\[Theta]", "3"]}], "-", 
       RowBox[{"2", " ", 
        SubscriptBox["z", "4"], " ", 
        SubscriptBox["\[Theta]", "1"], " ", 
        SubscriptBox["\[Theta]", "3"]}], "-", 
       RowBox[{"2", " ", 
        SubscriptBox["\[Theta]", "2"], " ", 
        SubscriptBox["\[Theta]", "3"]}], "-", 
       RowBox[{"2", " ", 
        SubscriptBox["z", "4"], " ", 
        SubscriptBox["\[Theta]", "2"], " ", 
        SubscriptBox["\[Theta]", "3"]}], "-", 
       RowBox[{"2", " ", 
        SubscriptBox["\[Theta]", "4"]}], "-", 
       RowBox[{"2", " ", 
        SubscriptBox["z", "4"], " ", 
        SubscriptBox["\[Theta]", "4"]}], "+", 
       RowBox[{"\[Epsilon]", " ", 
        SubscriptBox["z", "4"], " ", 
        SubscriptBox["\[Theta]", "4"]}], "-", 
       RowBox[{"2", " ", 
        SubscriptBox["\[Theta]", "1"], " ", 
        SubscriptBox["\[Theta]", "4"]}], "-", 
       RowBox[{"2", " ", 
        SubscriptBox["z", "4"], " ", 
        SubscriptBox["\[Theta]", "1"], " ", 
        SubscriptBox["\[Theta]", "4"]}], "-", 
       RowBox[{"2", " ", 
        SubscriptBox["\[Theta]", "2"], " ", 
        SubscriptBox["\[Theta]", "4"]}], "-", 
       RowBox[{"2", " ", 
        SubscriptBox["z", "4"], " ", 
        SubscriptBox["\[Theta]", "2"], " ", 
        SubscriptBox["\[Theta]", "4"]}], "-", 
       RowBox[{"2", " ", 
        SubscriptBox["\[Theta]", "3"], " ", 
        SubscriptBox["\[Theta]", "4"]}], "-", 
       RowBox[{"2", " ", 
        SubscriptBox["z", "4"], " ", 
        SubscriptBox["\[Theta]", "3"], " ", 
        SubscriptBox["\[Theta]", "4"]}], "-", 
       RowBox[{
        SubscriptBox["z", "4"], " ", 
        SubsuperscriptBox["\[Theta]", "4", "2"]}], "+", 
       RowBox[{
        SubscriptBox["z", "1"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "\[Epsilon]", "-", 
          SubsuperscriptBox["\[Theta]", "1", "2"], "-", 
          RowBox[{"2", " ", 
           SubsuperscriptBox["\[Theta]", "2", "2"]}], "-", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Theta]", "3"]}], "+", 
          RowBox[{
           SubscriptBox["\[Theta]", "1"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "2"}], "+", "\[Epsilon]", "-", 
             RowBox[{"2", " ", 
              SubscriptBox["\[Theta]", "2"]}], "-", 
             RowBox[{"2", " ", 
              SubscriptBox["\[Theta]", "3"]}], "-", 
             RowBox[{"2", " ", 
              SubscriptBox["\[Theta]", "4"]}]}], ")"}]}], "+", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Theta]", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "\[Epsilon]", "-", 
             SubscriptBox["\[Theta]", "3"], "-", 
             SubscriptBox["\[Theta]", "4"]}], ")"}]}], "-", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Theta]", "4"]}], "-", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Theta]", "3"], " ", 
           SubscriptBox["\[Theta]", "4"]}]}], ")"}]}], "+", 
       RowBox[{
        SubscriptBox["z", "3"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "2"}], " ", 
           SubsuperscriptBox["\[Theta]", "1", "2"]}], "-", 
          RowBox[{"2", " ", 
           SubsuperscriptBox["\[Theta]", "2", "2"]}], "+", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Theta]", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "\[Epsilon]", "-", 
             SubscriptBox["\[Theta]", "3"], "-", 
             SubscriptBox["\[Theta]", "4"]}], ")"}]}], "+", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Theta]", "1"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "\[Epsilon]", "-", 
             SubscriptBox["\[Theta]", "2"], "-", 
             SubscriptBox["\[Theta]", "3"], "-", 
             SubscriptBox["\[Theta]", "4"]}], ")"}]}], "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "+", 
             SubscriptBox["\[Theta]", "3"]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"1", "-", "\[Epsilon]", "+", 
             SubscriptBox["\[Theta]", "3"], "+", 
             RowBox[{"2", " ", 
              SubscriptBox["\[Theta]", "4"]}]}], ")"}]}]}], ")"}]}]}], 
      ")"}]}]}], ",", 
   RowBox[{
    SubscriptBox["z", "4"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         SubscriptBox["z", "3"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"\[Epsilon]", "-", 
         SubscriptBox["\[Theta]", "2"]}], ")"}], " ", 
       SubscriptBox["\[Theta]", "2"]}], "+", 
      RowBox[{
       SubscriptBox["z", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "\[Epsilon]", "-", 
         SubscriptBox["\[Theta]", "1"], "-", 
         SubscriptBox["\[Theta]", "2"], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["\[Theta]", "3"]}], "-", 
         SubscriptBox["\[Theta]", "4"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         SubscriptBox["\[Theta]", "1"], "+", 
         SubscriptBox["\[Theta]", "2"], "+", 
         SubscriptBox["\[Theta]", "4"]}], ")"}]}]}], ")"}]}], ",", 
   RowBox[{
    SubscriptBox["z", "4"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SubscriptBox["z", "4"], " ", 
       SubscriptBox["\[Theta]", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "\[Epsilon]"}], "+", 
         SubscriptBox["\[Theta]", "2"]}], ")"}]}], "+", 
      RowBox[{
       SubscriptBox["z", "2"], " ", 
       RowBox[{"(", 
        RowBox[{"\[Epsilon]", "-", 
         SubscriptBox["\[Theta]", "4"]}], ")"}], " ", 
       SubscriptBox["\[Theta]", "4"]}]}], ")"}]}], ",", 
   RowBox[{
    SubscriptBox["z", "3"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         SubscriptBox["z", "4"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"\[Epsilon]", "-", 
         SubscriptBox["\[Theta]", "2"]}], ")"}], " ", 
       SubscriptBox["\[Theta]", "2"]}], "-", 
      RowBox[{
       SubscriptBox["z", "2"], " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         SubscriptBox["\[Theta]", "1"], "+", 
         SubscriptBox["\[Theta]", "2"], "+", 
         SubscriptBox["\[Theta]", "3"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", "\[Epsilon]", "+", 
         SubscriptBox["\[Theta]", "1"], "+", 
         SubscriptBox["\[Theta]", "2"], "+", 
         SubscriptBox["\[Theta]", "3"], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["\[Theta]", "4"]}]}], ")"}]}]}], ")"}]}], ",", 
   RowBox[{
    SubscriptBox["z", "3"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SubscriptBox["z", "3"], " ", 
       SubscriptBox["\[Theta]", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "\[Epsilon]"}], "+", 
         SubscriptBox["\[Theta]", "2"]}], ")"}]}], "+", 
      RowBox[{
       SubscriptBox["z", "2"], " ", 
       RowBox[{"(", 
        RowBox[{"\[Epsilon]", "-", 
         SubscriptBox["\[Theta]", "3"]}], ")"}], " ", 
       SubscriptBox["\[Theta]", "3"]}]}], ")"}]}], ",", 
   RowBox[{
    SubscriptBox["z", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         SubscriptBox["z", "1"], "+", 
         SubscriptBox["z", "3"], "+", 
         SubscriptBox["z", "4"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"\[Epsilon]", "-", 
         SubscriptBox["\[Theta]", "2"]}], ")"}], " ", 
       SubscriptBox["\[Theta]", "2"]}], "+", 
      RowBox[{
       SubscriptBox["z", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "\[Epsilon]", "-", 
         SubsuperscriptBox["\[Theta]", "2", "2"], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["\[Theta]", "3"]}], "+", 
         RowBox[{
          SubscriptBox["\[Theta]", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "2"}], "+", "\[Epsilon]", "-", 
            RowBox[{"2", " ", 
             SubscriptBox["\[Theta]", "3"]}], "-", 
            RowBox[{"2", " ", 
             SubscriptBox["\[Theta]", "4"]}]}], ")"}]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["\[Theta]", "4"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["\[Theta]", "3"], " ", 
          SubscriptBox["\[Theta]", "4"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["\[Theta]", "1"], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            SubscriptBox["\[Theta]", "2"], "+", 
            SubscriptBox["\[Theta]", "3"], "+", 
            SubscriptBox["\[Theta]", "4"]}], ")"}]}]}], ")"}]}]}], ")"}]}], 
   ",", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["z", "3"], "+", 
       SubscriptBox["z", "4"]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"\[Epsilon]", "-", 
       SubscriptBox["\[Theta]", "1"]}], ")"}], " ", 
     SubscriptBox["\[Theta]", "1"]}], "+", 
    RowBox[{
     SubscriptBox["z", "1"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SubscriptBox["\[Theta]", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "\[Epsilon]"}], "+", 
          SubscriptBox["\[Theta]", "2"]}], ")"}]}], "+", 
       RowBox[{
        SubscriptBox["z", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "\[Epsilon]", "-", 
          SubsuperscriptBox["\[Theta]", "1", "2"], "-", 
          SubsuperscriptBox["\[Theta]", "2", "2"], "-", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Theta]", "3"]}], "+", 
          RowBox[{
           SubscriptBox["\[Theta]", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "2"}], "+", "\[Epsilon]", "-", 
             RowBox[{"2", " ", 
              SubscriptBox["\[Theta]", "3"]}], "-", 
             RowBox[{"2", " ", 
              SubscriptBox["\[Theta]", "4"]}]}], ")"}]}], "+", 
          RowBox[{
           SubscriptBox["\[Theta]", "1"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "2"}], "+", "\[Epsilon]", "-", 
             RowBox[{"2", " ", 
              SubscriptBox["\[Theta]", "2"]}], "-", 
             RowBox[{"2", " ", 
              SubscriptBox["\[Theta]", "3"]}], "-", 
             RowBox[{"2", " ", 
              SubscriptBox["\[Theta]", "4"]}]}], ")"}]}], "-", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Theta]", "4"]}], "-", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Theta]", "3"], " ", 
           SubscriptBox["\[Theta]", "4"]}]}], ")"}]}]}], ")"}]}]}], ",", 
   RowBox[{
    SubscriptBox["z", "4"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SubscriptBox["z", "2"], " ", 
       RowBox[{"(", 
        RowBox[{"\[Epsilon]", "-", 
         SubscriptBox["\[Theta]", "1"]}], ")"}], " ", 
       SubscriptBox["\[Theta]", "1"]}], "+", 
      RowBox[{
       SubscriptBox["z", "1"], " ", 
       SubscriptBox["\[Theta]", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "\[Epsilon]"}], "+", 
         SubscriptBox["\[Theta]", "2"]}], ")"}]}]}], ")"}]}], ",", 
   RowBox[{
    SubscriptBox["z", "3"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SubscriptBox["z", "2"], " ", 
       RowBox[{"(", 
        RowBox[{"\[Epsilon]", "-", 
         SubscriptBox["\[Theta]", "1"]}], ")"}], " ", 
       SubscriptBox["\[Theta]", "1"]}], "+", 
      RowBox[{
       SubscriptBox["z", "1"], " ", 
       SubscriptBox["\[Theta]", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "\[Epsilon]"}], "+", 
         SubscriptBox["\[Theta]", "2"]}], ")"}]}]}], ")"}]}], ",", 
   RowBox[{
    SubscriptBox["z", "1"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SubscriptBox["z", "2"], " ", 
       RowBox[{"(", 
        RowBox[{"\[Epsilon]", "-", 
         SubscriptBox["\[Theta]", "1"]}], ")"}], " ", 
       SubscriptBox["\[Theta]", "1"]}], "+", 
      RowBox[{
       SubscriptBox["z", "1"], " ", 
       SubscriptBox["\[Theta]", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "\[Epsilon]"}], "+", 
         SubscriptBox["\[Theta]", "2"]}], ")"}]}]}], ")"}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{"2", " ", 
        SubscriptBox["z", "3"], " ", 
        SubscriptBox["z", "4"]}], "+", 
       RowBox[{"2", " ", 
        SubscriptBox["z", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["z", "3"], "+", 
          SubscriptBox["z", "4"]}], ")"}]}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"\[Epsilon]", "-", 
       SubscriptBox["\[Theta]", "1"]}], ")"}], " ", 
     SubscriptBox["\[Theta]", "1"]}], "+", 
    RowBox[{
     SubsuperscriptBox["z", "1", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "\[Epsilon]", "-", 
       SubsuperscriptBox["\[Theta]", "1", "2"], "-", 
       RowBox[{"2", " ", 
        SubscriptBox["\[Theta]", "3"]}], "+", 
       RowBox[{
        SubscriptBox["\[Theta]", "1"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "2"}], "+", "\[Epsilon]", "-", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Theta]", "2"]}], "-", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Theta]", "3"]}], "-", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Theta]", "4"]}]}], ")"}]}], "-", 
       RowBox[{"2", " ", 
        SubscriptBox["\[Theta]", "4"]}], "-", 
       RowBox[{"2", " ", 
        SubscriptBox["\[Theta]", "3"], " ", 
        SubscriptBox["\[Theta]", "4"]}], "-", 
       RowBox[{"2", " ", 
        SubscriptBox["\[Theta]", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          SubscriptBox["\[Theta]", "3"], "+", 
          SubscriptBox["\[Theta]", "4"]}], ")"}]}]}], ")"}]}], "+", 
    RowBox[{
     SubscriptBox["z", "1"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "\[Epsilon]", "-", 
       SubscriptBox["z", "4"], "+", 
       RowBox[{"\[Epsilon]", " ", 
        SubscriptBox["z", "4"]}], "-", 
       RowBox[{"2", " ", 
        SubscriptBox["\[Theta]", "1"]}], "-", 
       RowBox[{"2", " ", 
        SubscriptBox["z", "4"], " ", 
        SubscriptBox["\[Theta]", "1"]}], "+", 
       RowBox[{"2", " ", "\[Epsilon]", " ", 
        SubscriptBox["z", "4"], " ", 
        SubscriptBox["\[Theta]", "1"]}], "-", 
       RowBox[{"2", " ", 
        SubscriptBox["z", "4"], " ", 
        SubsuperscriptBox["\[Theta]", "1", "2"]}], "-", 
       RowBox[{"2", " ", 
        SubscriptBox["\[Theta]", "2"]}], "-", 
       RowBox[{"2", " ", 
        SubscriptBox["z", "4"], " ", 
        SubscriptBox["\[Theta]", "2"]}], "-", 
       RowBox[{"2", " ", 
        SubscriptBox["\[Theta]", "1"], " ", 
        SubscriptBox["\[Theta]", "2"]}], "-", 
       RowBox[{"2", " ", 
        SubscriptBox["z", "4"], " ", 
        SubscriptBox["\[Theta]", "1"], " ", 
        SubscriptBox["\[Theta]", "2"]}], "-", 
       RowBox[{"2", " ", 
        SubscriptBox["\[Theta]", "3"]}], "-", 
       RowBox[{"2", " ", 
        SubscriptBox["z", "4"], " ", 
        SubscriptBox["\[Theta]", "3"]}], "-", 
       RowBox[{"2", " ", 
        SubscriptBox["\[Theta]", "1"], " ", 
        SubscriptBox["\[Theta]", "3"]}], "-", 
       RowBox[{"2", " ", 
        SubscriptBox["z", "4"], " ", 
        SubscriptBox["\[Theta]", "1"], " ", 
        SubscriptBox["\[Theta]", "3"]}], "-", 
       RowBox[{"2", " ", 
        SubscriptBox["\[Theta]", "2"], " ", 
        SubscriptBox["\[Theta]", "3"]}], "-", 
       RowBox[{"2", " ", 
        SubscriptBox["z", "4"], " ", 
        SubscriptBox["\[Theta]", "2"], " ", 
        SubscriptBox["\[Theta]", "3"]}], "-", 
       RowBox[{"2", " ", 
        SubscriptBox["\[Theta]", "4"]}], "-", 
       RowBox[{"2", " ", 
        SubscriptBox["z", "4"], " ", 
        SubscriptBox["\[Theta]", "4"]}], "+", 
       RowBox[{"\[Epsilon]", " ", 
        SubscriptBox["z", "4"], " ", 
        SubscriptBox["\[Theta]", "4"]}], "-", 
       RowBox[{"2", " ", 
        SubscriptBox["\[Theta]", "1"], " ", 
        SubscriptBox["\[Theta]", "4"]}], "-", 
       RowBox[{"2", " ", 
        SubscriptBox["z", "4"], " ", 
        SubscriptBox["\[Theta]", "1"], " ", 
        SubscriptBox["\[Theta]", "4"]}], "-", 
       RowBox[{"2", " ", 
        SubscriptBox["\[Theta]", "2"], " ", 
        SubscriptBox["\[Theta]", "4"]}], "-", 
       RowBox[{"2", " ", 
        SubscriptBox["z", "4"], " ", 
        SubscriptBox["\[Theta]", "2"], " ", 
        SubscriptBox["\[Theta]", "4"]}], "-", 
       RowBox[{"2", " ", 
        SubscriptBox["\[Theta]", "3"], " ", 
        SubscriptBox["\[Theta]", "4"]}], "-", 
       RowBox[{"2", " ", 
        SubscriptBox["z", "4"], " ", 
        SubscriptBox["\[Theta]", "3"], " ", 
        SubscriptBox["\[Theta]", "4"]}], "-", 
       RowBox[{
        SubscriptBox["z", "4"], " ", 
        SubsuperscriptBox["\[Theta]", "4", "2"]}], "+", 
       RowBox[{
        SubscriptBox["z", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "\[Epsilon]", "-", 
          RowBox[{"2", " ", 
           SubsuperscriptBox["\[Theta]", "1", "2"]}], "-", 
          SubsuperscriptBox["\[Theta]", "2", "2"], "-", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Theta]", "3"]}], "+", 
          RowBox[{
           SubscriptBox["\[Theta]", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "2"}], "+", "\[Epsilon]", "-", 
             RowBox[{"2", " ", 
              SubscriptBox["\[Theta]", "3"]}], "-", 
             RowBox[{"2", " ", 
              SubscriptBox["\[Theta]", "4"]}]}], ")"}]}], "+", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Theta]", "1"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "\[Epsilon]", "-", 
             SubscriptBox["\[Theta]", "2"], "-", 
             SubscriptBox["\[Theta]", "3"], "-", 
             SubscriptBox["\[Theta]", "4"]}], ")"}]}], "-", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Theta]", "4"]}], "-", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Theta]", "3"], " ", 
           SubscriptBox["\[Theta]", "4"]}]}], ")"}]}], "+", 
       RowBox[{
        SubscriptBox["z", "3"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "2"}], " ", 
           SubsuperscriptBox["\[Theta]", "1", "2"]}], "+", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Theta]", "1"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "\[Epsilon]", "-", 
             SubscriptBox["\[Theta]", "2"], "-", 
             SubscriptBox["\[Theta]", "3"], "-", 
             SubscriptBox["\[Theta]", "4"]}], ")"}]}], "-", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Theta]", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             SubscriptBox["\[Theta]", "3"], "+", 
             SubscriptBox["\[Theta]", "4"]}], ")"}]}], "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "+", 
             SubscriptBox["\[Theta]", "3"]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"1", "-", "\[Epsilon]", "+", 
             SubscriptBox["\[Theta]", "3"], "+", 
             RowBox[{"2", " ", 
              SubscriptBox["\[Theta]", "4"]}]}], ")"}]}]}], ")"}]}]}], 
      ")"}]}]}], ",", 
   RowBox[{
    SubscriptBox["z", "4"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         SubscriptBox["z", "2"], "+", 
         SubscriptBox["z", "3"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"\[Epsilon]", "-", 
         SubscriptBox["\[Theta]", "1"]}], ")"}], " ", 
       SubscriptBox["\[Theta]", "1"]}], "+", 
      RowBox[{
       SubscriptBox["z", "1"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SubsuperscriptBox["\[Theta]", "1", "2"]}], "+", 
         RowBox[{
          SubscriptBox["\[Theta]", "1"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "2"}], "+", "\[Epsilon]", "-", 
            RowBox[{"2", " ", 
             SubscriptBox["\[Theta]", "2"]}], "-", 
            RowBox[{"2", " ", 
             SubscriptBox["\[Theta]", "3"]}], "-", 
            RowBox[{"2", " ", 
             SubscriptBox["\[Theta]", "4"]}]}], ")"}]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "\[Epsilon]", "-", 
            RowBox[{"2", " ", 
             SubscriptBox["\[Theta]", "3"]}], "-", 
            SubscriptBox["\[Theta]", "4"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            SubscriptBox["\[Theta]", "4"]}], ")"}]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["\[Theta]", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            SubscriptBox["\[Theta]", "3"], "+", 
            SubscriptBox["\[Theta]", "4"]}], ")"}]}]}], ")"}]}]}], ")"}]}], 
   ",", 
   RowBox[{
    SubscriptBox["z", "4"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SubscriptBox["z", "4"], " ", 
       SubscriptBox["\[Theta]", "1"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "\[Epsilon]"}], "+", 
         SubscriptBox["\[Theta]", "1"]}], ")"}]}], "+", 
      RowBox[{
       SubscriptBox["z", "1"], " ", 
       RowBox[{"(", 
        RowBox[{"\[Epsilon]", "-", 
         SubscriptBox["\[Theta]", "4"]}], ")"}], " ", 
       SubscriptBox["\[Theta]", "4"]}]}], ")"}]}], ",", 
   RowBox[{
    SubscriptBox["z", "3"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         SubscriptBox["z", "2"], "+", 
         SubscriptBox["z", "4"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"\[Epsilon]", "-", 
         SubscriptBox["\[Theta]", "1"]}], ")"}], " ", 
       SubscriptBox["\[Theta]", "1"]}], "+", 
      RowBox[{
       SubscriptBox["z", "1"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SubsuperscriptBox["\[Theta]", "1", "2"]}], "+", 
         RowBox[{
          SubscriptBox["\[Theta]", "1"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "2"}], "+", "\[Epsilon]", "-", 
            RowBox[{"2", " ", 
             SubscriptBox["\[Theta]", "2"]}], "-", 
            RowBox[{"2", " ", 
             SubscriptBox["\[Theta]", "3"]}], "-", 
            RowBox[{"2", " ", 
             SubscriptBox["\[Theta]", "4"]}]}], ")"}]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["\[Theta]", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            SubscriptBox["\[Theta]", "3"], "+", 
            SubscriptBox["\[Theta]", "4"]}], ")"}]}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "+", 
            SubscriptBox["\[Theta]", "3"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"1", "-", "\[Epsilon]", "+", 
            SubscriptBox["\[Theta]", "3"], "+", 
            RowBox[{"2", " ", 
             SubscriptBox["\[Theta]", "4"]}]}], ")"}]}]}], ")"}]}]}], ")"}]}],
    ",", 
   RowBox[{
    SubscriptBox["z", "3"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SubscriptBox["z", "3"], " ", 
       SubscriptBox["\[Theta]", "1"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "\[Epsilon]"}], "+", 
         SubscriptBox["\[Theta]", "1"]}], ")"}]}], "+", 
      RowBox[{
       SubscriptBox["z", "1"], " ", 
       RowBox[{"(", 
        RowBox[{"\[Epsilon]", "-", 
         SubscriptBox["\[Theta]", "3"]}], ")"}], " ", 
       SubscriptBox["\[Theta]", "3"]}]}], ")"}]}], ",", 
   RowBox[{
    SubscriptBox["z", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         SubscriptBox["z", "3"], "+", 
         SubscriptBox["z", "4"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"\[Epsilon]", "-", 
         SubscriptBox["\[Theta]", "1"]}], ")"}], " ", 
       SubscriptBox["\[Theta]", "1"]}], "+", 
      RowBox[{
       SubscriptBox["z", "1"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "\[Epsilon]", "-", 
         SubsuperscriptBox["\[Theta]", "1", "2"], "-", 
         SubsuperscriptBox["\[Theta]", "2", "2"], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["\[Theta]", "3"]}], "+", 
         RowBox[{
          SubscriptBox["\[Theta]", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "2"}], "+", "\[Epsilon]", "-", 
            RowBox[{"2", " ", 
             SubscriptBox["\[Theta]", "3"]}], "-", 
            RowBox[{"2", " ", 
             SubscriptBox["\[Theta]", "4"]}]}], ")"}]}], "+", 
         RowBox[{
          SubscriptBox["\[Theta]", "1"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "2"}], "+", "\[Epsilon]", "-", 
            RowBox[{"2", " ", 
             SubscriptBox["\[Theta]", "2"]}], "-", 
            RowBox[{"2", " ", 
             SubscriptBox["\[Theta]", "3"]}], "-", 
            RowBox[{"2", " ", 
             SubscriptBox["\[Theta]", "4"]}]}], ")"}]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["\[Theta]", "4"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["\[Theta]", "3"], " ", 
          SubscriptBox["\[Theta]", "4"]}]}], ")"}]}]}], ")"}]}], ",", 
   RowBox[{
    SubscriptBox["z", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SubscriptBox["z", "2"], " ", 
       SubscriptBox["\[Theta]", "1"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "\[Epsilon]"}], "+", 
         SubscriptBox["\[Theta]", "1"]}], ")"}]}], "+", 
      RowBox[{
       SubscriptBox["z", "1"], " ", 
       RowBox[{"(", 
        RowBox[{"\[Epsilon]", "-", 
         SubscriptBox["\[Theta]", "2"]}], ")"}], " ", 
       SubscriptBox["\[Theta]", "2"]}]}], ")"}]}], ",", 
   RowBox[{
    SubscriptBox["z", "1"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         SubscriptBox["z", "2"], "+", 
         SubscriptBox["z", "3"], "+", 
         SubscriptBox["z", "4"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"\[Epsilon]", "-", 
         SubscriptBox["\[Theta]", "1"]}], ")"}], " ", 
       SubscriptBox["\[Theta]", "1"]}], "+", 
      RowBox[{
       SubscriptBox["z", "1"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "\[Epsilon]", "-", 
         SubsuperscriptBox["\[Theta]", "1", "2"], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["\[Theta]", "3"]}], "+", 
         RowBox[{
          SubscriptBox["\[Theta]", "1"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "2"}], "+", "\[Epsilon]", "-", 
            RowBox[{"2", " ", 
             SubscriptBox["\[Theta]", "2"]}], "-", 
            RowBox[{"2", " ", 
             SubscriptBox["\[Theta]", "3"]}], "-", 
            RowBox[{"2", " ", 
             SubscriptBox["\[Theta]", "4"]}]}], ")"}]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["\[Theta]", "4"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["\[Theta]", "3"], " ", 
          SubscriptBox["\[Theta]", "4"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["\[Theta]", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            SubscriptBox["\[Theta]", "3"], "+", 
            SubscriptBox["\[Theta]", "4"]}], ")"}]}]}], ")"}]}]}], ")"}]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.837228671500844*^9, {3.837228725040854*^9, 3.837228750021544*^9}, 
   3.837229135165716*^9, 3.837229235391947*^9, {3.837678205195949*^9, 
   3.837678210583755*^9}, {3.837678304613274*^9, 3.8376783239873447`*^9}},
 CellLabel->"Out[96]=",ExpressionUUID->"a1f6e0eb-9620-4cfd-9ec1-403be7aa6038"],

Cell[BoxData["40"], "Output",
 CellChangeTimes->{
  3.837228671500844*^9, {3.837228725040854*^9, 3.837228750021544*^9}, 
   3.837229135165716*^9, 3.837229235391947*^9, {3.837678205195949*^9, 
   3.837678210583755*^9}, {3.837678304613274*^9, 3.837678324007204*^9}},
 CellLabel->"Out[97]=",ExpressionUUID->"eb6a26f0-29ae-4fc0-8107-e68d34e8293a"]
}, Open  ]]
}, Closed]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Operators in the equal-mass case", "Chapter",
 CellChangeTimes->{{3.837232536990637*^9, 
  3.837232541913076*^9}},ExpressionUUID->"908fc8c3-142b-45f0-8296-\
663dedf3abf6"],

Cell["Evaluate all functions in \[OpenCurlyDoubleQuote]Necessary Functions\
\[CloseCurlyDoubleQuote]!", "Text",
 CellChangeTimes->{{3.837237009937067*^9, 3.8372370453525963`*^9}, {
  3.8376772621106853`*^9, 
  3.837677264450604*^9}},ExpressionUUID->"e398e435-cf77-4914-9002-\
c59c1a3f82f4"],

Cell["\<\
The Function \[OpenCurlyDoubleQuote]OperatorEqualMass[l]\
\[CloseCurlyDoubleQuote] computes the Picard-Fuchs operator for the l-loop \
banana integral in D=2-2\[Epsilon].\
\>", "Text",
 CellChangeTimes->{{3.837677536084594*^9, 3.837677579621003*^9}, {
  3.8376783434102*^9, 
  3.837678357648093*^9}},ExpressionUUID->"12ffdf89-e6c8-4082-9067-\
7dfe72774de5"],

Cell[CellGroupData[{

Cell["Necessary Functions", "Section",
 CellChangeTimes->{{3.837228303658607*^9, 
  3.837228306516485*^9}},ExpressionUUID->"e8b627e9-78ec-4835-a064-\
30120cdbff98"],

Cell[BoxData[{
 RowBox[{"Clear", "[", 
  RowBox[{
  "\[CapitalTheta]D", ",", "\[CapitalTheta]Dm", ",", "PF", ",", "ThetaPF", 
   ",", "ThetaInverseVar", ",", "InverseVar"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Clear", "[", 
  RowBox[{
  "L", ",", "LX", ",", "X2Regel", ",", "OpTest", ",", "EpsRein", ",", 
   "FinalOperatorMUM", ",", "OperatorEqualMass"}], "]"}]}], "Input",
 CellChangeTimes->{{3.824805395048574*^9, 3.824805398787952*^9}, 
   3.824805527816263*^9, {3.824805588816475*^9, 3.824805601277424*^9}, {
   3.837228442049926*^9, 3.837228473998996*^9}, {3.8372285134068747`*^9, 
   3.8372285404446287`*^9}, {3.837228580391715*^9, 3.837228580539954*^9}, {
   3.837236665851653*^9, 3.837236710436343*^9}, {3.837677230161378*^9, 
   3.837677230325914*^9}, {3.837677376626052*^9, 3.837677376818308*^9}},
 CellLabel->"In[34]:=",ExpressionUUID->"0f31d05b-fa19-4b6d-a6dd-ee0ef169091b"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"\[CapitalTheta]D", "[", "t_", "]"}], ":=", 
   RowBox[{
    RowBox[{"t", " ", 
     RowBox[{"D", "[", 
      RowBox[{"#", ",", "t"}], "]"}]}], "&"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[CapitalTheta]Dm", "[", 
    RowBox[{"t_", ",", "m_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", "hi", "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"hi", "=", "#"}], ";", "\[IndentingNewLine]", 
       RowBox[{"Do", "[", 
        RowBox[{
         RowBox[{"hi", "=", 
          RowBox[{
           RowBox[{"\[CapitalTheta]D", "[", "t", "]"}], "[", "hi", "]"}]}], 
         ",", 
         RowBox[{"{", 
          RowBox[{"k", ",", "0", ",", 
           RowBox[{"m", "-", "1"}]}], "}"}]}], "]"}], ";", 
       "\[IndentingNewLine]", "hi"}]}], "]"}], "&"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"PF", "[", "t_", "]"}], ":=", 
   RowBox[{
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", "hi", "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"hi", "=", 
        RowBox[{"CoefficientList", "[", 
         RowBox[{"#2", ",", "\[Theta]"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"Expand", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
          "hi", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
          "#1"}], "+", 
         RowBox[{"Sum", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"hi", "\[LeftDoubleBracket]", 
             RowBox[{"$n", "+", "1"}], "\[RightDoubleBracket]"}], "*", 
            RowBox[{"Sum", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"StirlingS2", "[", 
                RowBox[{"$n", ",", "$k"}], "]"}], 
               SuperscriptBox["t", "$k"], 
               RowBox[{"D", "[", 
                RowBox[{"#1", ",", 
                 RowBox[{"{", 
                  RowBox[{"t", ",", "$k"}], "}"}]}], "]"}]}], ",", 
              RowBox[{"{", 
               RowBox[{"$k", ",", "1", ",", "$n"}], "}"}]}], "]"}]}], ",", 
           RowBox[{"{", 
            RowBox[{"$n", ",", "1", ",", 
             RowBox[{
              RowBox[{"Length", "[", "hi", "]"}], "-", "1"}]}], "}"}]}], 
          "]"}]}], "]"}]}]}], "]"}], "&"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ThetaPF", "[", 
    RowBox[{"f_", ",", "t_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"hi", ",", "maxdiff", ",", "khilf"}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"hi", "=", "#"}], ";", "\[IndentingNewLine]", 
       RowBox[{"maxdiff", "=", 
        RowBox[{"Max", "[", 
         RowBox[{"Cases", "[", 
          RowBox[{
           RowBox[{"hi", "*", "khilf"}], ",", 
           RowBox[{
            RowBox[{
             RowBox[{
              SuperscriptBox["f", 
               TagBox[
                RowBox[{"(", "order_", ")"}],
                Derivative],
               MultilineFunction->None], "[", "t", "]"}], "\[RuleDelayed]", 
             "order"}], "/.", 
            RowBox[{"khilf", "\[Rule]", "1"}]}], ",", "Infinity"}], "]"}], 
         "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"maxdiff", "=", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"maxdiff", "\[Equal]", 
           RowBox[{"-", "\[Infinity]"}]}], ",", "0", ",", "maxdiff"}], 
         "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"ReplaceAll", "[", 
         RowBox[{"hi", ",", 
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"D", "[", 
              RowBox[{
               RowBox[{"f", "[", "t", "]"}], ",", 
               RowBox[{"{", 
                RowBox[{"t", ",", "n"}], "}"}]}], "]"}], "\[Rule]", 
             RowBox[{
              FractionBox["1", 
               SuperscriptBox["t", "n"]], 
              RowBox[{"Product", "[", 
               RowBox[{
                RowBox[{"\[Theta]", "-", "k"}], ",", 
                RowBox[{"{", 
                 RowBox[{"k", ",", "0", ",", 
                  RowBox[{"n", "-", "1"}]}], "}"}]}], "]"}]}]}], ",", 
            RowBox[{"{", 
             RowBox[{"n", ",", "0", ",", "maxdiff"}], "}"}]}], "]"}]}], "]"}],
         "//", "Expand"}]}]}], "]"}], "&"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ThetaInverseVar", "[", "t_", "]"}], ":=", 
   RowBox[{
    RowBox[{
     RowBox[{"#", "/.", 
      RowBox[{"t", "\[Rule]", 
       RowBox[{"1", "/", "t"}]}]}], "/.", 
     RowBox[{"\[Theta]", "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"-", "1"}], ")"}], "\[Theta]"}]}]}], "&"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"InverseVar", "[", 
    RowBox[{"f_", ",", "t_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"hi", ",", "khilf", ",", "hii"}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"hi", "=", 
        RowBox[{
         RowBox[{"#", "+", 
          RowBox[{"khilf", " ", 
           RowBox[{"f", "[", "t", "]"}]}]}], "//", "Expand"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"hii", "=", 
        RowBox[{
         RowBox[{
          RowBox[{"Cases", "[", 
           RowBox[{"hi", ",", " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["f", 
               TagBox[
                RowBox[{"(", "order_", ")"}],
                Derivative],
               MultilineFunction->None], "[", "t", "]"}], "\[RuleDelayed]", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{
                SuperscriptBox["f", 
                 TagBox[
                  RowBox[{"(", "order", ")"}],
                  Derivative],
                 MultilineFunction->None], "[", "t", "]"}], ",", "order"}], 
              "}"}]}], ",", "Infinity"}], "]"}], "/.", 
          RowBox[{"khilf", "\[Rule]", "0"}]}], "//", "DeleteDuplicates"}]}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"hii", "=", 
        RowBox[{"Join", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"f", "[", "t", "]"}], ",", "0"}], "}"}], "}"}], ",", 
          "hii"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"hi", "=", 
        RowBox[{
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Coefficient", "[", 
              RowBox[{"hi", ",", 
               RowBox[{"hii", "\[LeftDoubleBracket]", 
                RowBox[{"k", ",", "1"}], "\[RightDoubleBracket]"}], ",", 
               "1"}], "]"}], ",", 
             RowBox[{"hii", "\[LeftDoubleBracket]", 
              RowBox[{"k", ",", "1"}], "\[RightDoubleBracket]"}], ",", 
             RowBox[{"hii", "\[LeftDoubleBracket]", 
              RowBox[{"k", ",", "2"}], "\[RightDoubleBracket]"}]}], "}"}], 
           ",", 
           RowBox[{"{", 
            RowBox[{"k", ",", "1", ",", 
             RowBox[{"Length", "[", "hii", "]"}]}], "}"}]}], "]"}], "/.", 
         RowBox[{"khilf", "\[Rule]", "0"}]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"hii", "=", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{"hi", "\[LeftDoubleBracket]", 
              RowBox[{"n", ",", "1"}], "\[RightDoubleBracket]"}], "/.", 
             RowBox[{"t", "\[Rule]", 
              RowBox[{"1", "/", "t"}]}]}], ",", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"-", "1"}], ")"}], 
               RowBox[{"hi", "\[LeftDoubleBracket]", 
                RowBox[{"n", ",", "3"}], "\[RightDoubleBracket]"}]], 
              SuperscriptBox["t", 
               RowBox[{"hi", "\[LeftDoubleBracket]", 
                RowBox[{"n", ",", "3"}], "\[RightDoubleBracket]"}]], 
              RowBox[{"Sum", "[", 
               RowBox[{
                RowBox[{
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"hi", "\[LeftDoubleBracket]", 
                    RowBox[{"n", ",", "3"}], "\[RightDoubleBracket]"}], "-", 
                    "k"}], ")"}], "!"}], " ", 
                 RowBox[{"Binomial", "[", 
                  RowBox[{
                   RowBox[{"hi", "\[LeftDoubleBracket]", 
                    RowBox[{"n", ",", "3"}], "\[RightDoubleBracket]"}], ",", 
                   "k"}], "]"}], " ", 
                 RowBox[{"Binomial", "[", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"hi", "\[LeftDoubleBracket]", 
                    RowBox[{"n", ",", "3"}], "\[RightDoubleBracket]"}], "-", 
                    "1"}], ",", 
                   RowBox[{"k", "-", "1"}]}], "]"}], 
                 SuperscriptBox["t", "k"], 
                 RowBox[{"D", "[", 
                  RowBox[{
                   RowBox[{"f", "[", "t", "]"}], ",", 
                   RowBox[{"{", 
                    RowBox[{"t", ",", "k"}], "}"}]}], "]"}]}], ",", 
                RowBox[{"{", 
                 RowBox[{"k", ",", 
                  RowBox[{"hi", "\[LeftDoubleBracket]", 
                   RowBox[{"n", ",", "3"}], "\[RightDoubleBracket]"}]}], 
                 "}"}]}], "]"}]}], "//", "Expand"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "2", ",", 
            RowBox[{"Length", "[", "hi", "]"}]}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"hi", "=", 
        RowBox[{"Join", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{"hi", "\[LeftDoubleBracket]", 
               RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}], "/.", 
              RowBox[{"t", "\[Rule]", 
               RowBox[{"1", "/", "t"}]}]}], ",", 
             RowBox[{"f", "[", "t", "]"}]}], "}"}], "}"}], ",", "hii"}], 
         "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"Sum", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"hi", "\[LeftDoubleBracket]", 
           RowBox[{"k", ",", "1"}], "\[RightDoubleBracket]"}], 
          RowBox[{"hi", "\[LeftDoubleBracket]", 
           RowBox[{"k", ",", "2"}], "\[RightDoubleBracket]"}]}], ",", 
         RowBox[{"{", 
          RowBox[{"k", ",", "1", ",", 
           RowBox[{"Length", "[", "hi", "]"}]}], "}"}]}], "]"}]}]}], "]"}], 
    "&"}]}], ";"}]}], "Input",
 CellChangeTimes->{
  3.822711122962096*^9, {3.822711153360466*^9, 3.822711159818063*^9}, {
   3.822711648309795*^9, 3.8227117278163033`*^9}, 3.822711919016674*^9, {
   3.8227119530040283`*^9, 3.822711979262253*^9}, {3.822712040129524*^9, 
   3.822712055179718*^9}, {3.822712094938733*^9, 3.8227120986288023`*^9}, {
   3.822712136924954*^9, 3.822712186640397*^9}, {3.822712234072877*^9, 
   3.8227122699720488`*^9}, {3.8227123352502127`*^9, 3.822712338531443*^9}, {
   3.822712698427964*^9, 3.822712702245545*^9}, {3.822712839296855*^9, 
   3.822712927962576*^9}, {3.822712966371402*^9, 3.822712998277327*^9}, {
   3.8235764811024227`*^9, 3.823576492207881*^9}, {3.823576670711665*^9, 
   3.823576673976061*^9}, 3.837228465587461*^9, 3.837236660640479*^9, {
   3.837236698329527*^9, 3.837236698731965*^9}},
 CellLabel->"In[36]:=",ExpressionUUID->"32e46965-4084-45ed-8f57-0e39ac001712"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"L", "[", 
    RowBox[{"z_", ",", "$\[Epsilon]_", ",", "n_"}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "Lhi", "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Lhi", "[", "0", "]"}], ":=", "1"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Lhi", "[", "1", "]"}], ":=", "\[Theta]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Lhi", "[", "$k_", "]"}], ":=", 
       RowBox[{
        RowBox[{"Lhi", "[", "$k", "]"}], "=", 
        RowBox[{"Expand", "[", 
         RowBox[{
          RowBox[{"\[Theta]", " ", 
           RowBox[{"Lhi", "[", 
            RowBox[{"$k", "-", "1"}], "]"}]}], "+", 
          RowBox[{"z", " ", 
           RowBox[{"D", "[", 
            RowBox[{
             RowBox[{"Lhi", "[", 
              RowBox[{"$k", "-", "1"}], "]"}], ",", "z"}], "]"}]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", 
              SuperscriptBox["z", "2"]}], "-", 
             SuperscriptBox["$\[Epsilon]", "2"]}], ")"}], 
           RowBox[{"(", 
            RowBox[{"$k", "-", "1"}], ")"}], 
           RowBox[{"(", 
            RowBox[{"n", "-", 
             RowBox[{"(", 
              RowBox[{"$k", "-", "1"}], ")"}], "+", "1"}], ")"}], 
           RowBox[{"Lhi", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"$k", "-", "1"}], ")"}], "-", "1"}], "]"}]}]}], 
         "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Lhi", "[", 
        RowBox[{"n", "+", "1"}], "]"}], "//", 
       RowBox[{
        RowBox[{"Collect", "[", 
         RowBox[{"#", ",", "\[Theta]", ",", "Factor"}], "]"}], "&"}]}]}]}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"LX", "[", 
    RowBox[{"x_", ",", "\[Epsilon]_", ",", "l_"}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"hi", ",", "max\[Theta]", ",", "maxx"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"hi", "=", 
       RowBox[{"L", "[", 
        RowBox[{"x", ",", "\[Epsilon]", ",", "l"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"max\[Theta]", "=", 
       RowBox[{"l", "+", "2"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"maxx", "=", 
       RowBox[{"l", "+", "2"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Sum", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Coefficient", "[", 
           RowBox[{
            RowBox[{"Coefficient", "[", 
             RowBox[{"hi", ",", "x", ",", "$n"}], "]"}], ",", "\[Theta]", ",",
             "$m"}], "]"}], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"-", "1"}], ")"}], "$m"], 
          SuperscriptBox["x", "$n"], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"$n", "+", "2", "+", 
             RowBox[{"\[Epsilon]", " ", 
              RowBox[{"(", 
               RowBox[{"l", "-", "1"}], ")"}]}], "+", "\[Theta]"}], ")"}], 
           "$m"]}], ",", 
         RowBox[{"{", 
          RowBox[{"$m", ",", "0", ",", "max\[Theta]"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"$n", ",", "0", ",", "maxx"}], "}"}]}], "]"}], "//", 
       RowBox[{
        RowBox[{"Collect", "[", 
         RowBox[{"#", ",", "\[Theta]", ",", "Factor"}], "]"}], "&"}]}]}]}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"X2Regel", "[", 
    RowBox[{"t_", ",", "n_"}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "hi", "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"hi", "=", 
       RowBox[{"f", "[", "t", "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"Do", "[", 
       RowBox[{
        RowBox[{"hi", "=", 
         RowBox[{
          RowBox[{"PF", "[", "t", "]"}], "[", 
          RowBox[{"hi", ",", 
           RowBox[{
            FractionBox["1", "t"], 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"4", 
               SuperscriptBox["\[Theta]", "2"]}], "-", 
              SuperscriptBox["\[Epsilon]", "2"]}], ")"}]}]}], "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"$k", ",", "1", ",", "n"}], "}"}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"ThetaPF", "[", 
        RowBox[{"f", ",", "t"}], "]"}], "[", "hi", "]"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"OpTest", "[", 
    RowBox[{"t_", ",", "\[Epsilon]_", ",", "l_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{"OpTest", "[", 
     RowBox[{"t", ",", "\[Epsilon]", ",", "l"}], "]"}], "=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"hi", ",", "hii", ",", "result"}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"hi", "=", 
        RowBox[{"LX", "[", 
         RowBox[{"x", ",", "\[Epsilon]", ",", 
          RowBox[{"l", "+", "1"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"result", "=", "0"}], ";", "\[IndentingNewLine]", 
       RowBox[{"Do", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"hii", "=", 
           RowBox[{
            RowBox[{"Coefficient", "[", 
             RowBox[{"hi", ",", "\[Theta]", ",", "$n"}], "]"}], "//", 
            RowBox[{
             RowBox[{"CoefficientList", "[", 
              RowBox[{"#", ",", "x"}], "]"}], "&"}]}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"hii", "=", 
           RowBox[{
            RowBox[{"ThetaPF", "[", 
             RowBox[{"f", ",", "t"}], "]"}], "[", 
            RowBox[{
             RowBox[{"PF", "[", "t", "]"}], "[", 
             RowBox[{
              RowBox[{
               RowBox[{"PF", "[", "t", "]"}], "[", 
               RowBox[{
                RowBox[{"f", "[", "t", "]"}], ",", 
                RowBox[{"Sum", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"hii", "\[LeftDoubleBracket]", 
                    RowBox[{"$k", "+", "1"}], "\[RightDoubleBracket]"}], 
                   RowBox[{"X2Regel", "[", 
                    RowBox[{"t", ",", 
                    RowBox[{"$k", "/", "2"}]}], "]"}]}], ",", 
                  RowBox[{"{", 
                   RowBox[{"$k", ",", "0", ",", 
                    RowBox[{
                    RowBox[{"Length", "[", "hii", "]"}], "-", "1"}]}], 
                   "}"}]}], "]"}]}], "]"}], ",", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"2", "\[Theta]"}], ")"}], "$n"]}], "]"}], "]"}]}], 
          ";", "\[IndentingNewLine]", 
          RowBox[{"result", "=", 
           RowBox[{"result", "+", "hii"}]}]}], ",", 
         RowBox[{"{", 
          RowBox[{"$n", ",", "0", ",", 
           RowBox[{"l", "+", "2"}]}], "}"}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"result", "//", 
        RowBox[{
         RowBox[{"Collect", "[", 
          RowBox[{
           RowBox[{"#", "*", 
            SuperscriptBox["t", "l"]}], ",", "\[Theta]", ",", "Factor"}], 
          "]"}], "&"}]}]}]}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"EpsRein", "[", 
    RowBox[{"t_", ",", "\[Epsilon]_", ",", "l_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{"EpsRein", "[", 
     RowBox[{"t", ",", "\[Epsilon]", ",", "l"}], "]"}], "=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", "hi", "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"hi", "=", 
        RowBox[{
         RowBox[{"OpTest", "[", 
          RowBox[{"t", ",", "\[Epsilon]", ",", "l"}], "]"}], "/.", 
         RowBox[{"\[Theta]", "\[Rule]", 
          RowBox[{"\[Theta]", "-", 
           FractionBox["\[Epsilon]", "2"]}]}]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"hi", "//", "FunctionExpand"}], "//", 
        RowBox[{
         RowBox[{"Collect", "[", 
          RowBox[{"#", ",", "\[Theta]", ",", "Factor"}], "]"}], "&"}]}]}]}], 
     "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"FinalOperatorMUM", "[", 
    RowBox[{"t_", ",", "\[Epsilon]_", ",", "l_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{"FinalOperatorMUM", "[", 
     RowBox[{"t", ",", "\[Epsilon]", ",", "l"}], "]"}], "=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "hi", ",", "ansatz", ",", "maxeps", ",", "maxt", ",", "max\[Theta]", 
        ",", "list"}], "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"hi", "=", 
        RowBox[{"EpsRein", "[", 
         RowBox[{"t", ",", "\[Epsilon]", ",", "l"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"maxeps", "=", 
        RowBox[{"Exponent", "[", 
         RowBox[{"hi", ",", "\[Epsilon]", ",", "Max"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"maxt", "=", 
        RowBox[{"Exponent", "[", 
         RowBox[{"hi", ",", "t", ",", "Max"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"max\[Theta]", "=", 
        RowBox[{"Exponent", "[", 
         RowBox[{"hi", ",", "\[Theta]", ",", "Max"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"ansatz", "=", 
        RowBox[{"Sum", "[", 
         RowBox[{
          RowBox[{
           SubscriptBox["q", 
            RowBox[{"m", ",", "n", ",", "k"}]], 
           SuperscriptBox["\[Epsilon]", "m"], 
           SuperscriptBox["t", "n"], 
           RowBox[{"D", "[", 
            RowBox[{
             RowBox[{"f", "[", "t", "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"t", ",", "k"}], "}"}]}], "]"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"m", ",", "0", ",", "maxeps"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "0", ",", 
            RowBox[{"maxt", "+", "1"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"k", ",", "0", ",", 
            RowBox[{"max\[Theta]", "-", "2"}]}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"list", "=", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"PF", "[", "t", "]"}], "[", 
            RowBox[{"ansatz", ",", 
             RowBox[{"\[Theta]", 
              RowBox[{"(", 
               RowBox[{"\[Theta]", "-", "\[Epsilon]"}], ")"}]}]}], "]"}], 
           SuperscriptBox["t", 
            RowBox[{"l", "-", "1"}]]}], "-", " ", 
          RowBox[{
           RowBox[{"PF", "[", "t", "]"}], "[", 
           RowBox[{
            RowBox[{"f", "[", "t", "]"}], ",", "hi"}], "]"}]}], "//", 
         RowBox[{
          RowBox[{"CoefficientList", "[", 
           RowBox[{"#", ",", 
            RowBox[{"Flatten", "[", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"t", ",", "\[Epsilon]"}], "}"}], ",", 
               RowBox[{"Table", "[", 
                RowBox[{
                 RowBox[{"D", "[", 
                  RowBox[{
                   RowBox[{"f", "[", "t", "]"}], ",", 
                   RowBox[{"{", 
                    RowBox[{"t", ",", "r"}], "}"}]}], "]"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"r", ",", "0", ",", "max\[Theta]"}], "}"}]}], 
                "]"}]}], "}"}], "]"}]}], "]"}], "&"}]}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"list", "=", 
        RowBox[{"Solve", "[", 
         RowBox[{
          RowBox[{"list", "\[Equal]", "0"}], ",", 
          RowBox[{"Flatten", "[", 
           RowBox[{"Table", "[", 
            RowBox[{
             SubscriptBox["q", 
              RowBox[{"m", ",", "n", ",", "k"}]], ",", 
             RowBox[{"{", 
              RowBox[{"m", ",", "0", ",", "maxeps"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"n", ",", "0", ",", 
               RowBox[{"maxt", "+", "1"}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"k", ",", "0", ",", 
               RowBox[{"max\[Theta]", "-", "2"}]}], "}"}]}], "]"}], "]"}]}], 
         "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"hi", "=", 
        RowBox[{
         RowBox[{"ReplaceAll", "[", 
          RowBox[{"ansatz", ",", "list"}], "]"}], "//", 
         RowBox[{
          RowBox[{"Collect", "[", 
           RowBox[{"#", ",", "\[Theta]", ",", "Factor"}], "]"}], "&"}]}]}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"hi", "=", 
        RowBox[{
         RowBox[{"ThetaInverseVar", "[", "t", "]"}], "[", 
         RowBox[{
          RowBox[{"ThetaPF", "[", 
           RowBox[{"f", ",", "t"}], "]"}], "[", "hi", "]"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"hi", "=", 
        RowBox[{
         RowBox[{"Numerator", "[", 
          RowBox[{"Together", "[", "hi", "]"}], "]"}], "\[LeftDoubleBracket]",
          "1", "\[RightDoubleBracket]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"hi", "=", 
        RowBox[{
         RowBox[{"hi", "/", 
          RowBox[{"(", 
           RowBox[{"hi", "/.", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"\[Theta]", "\[Rule]", "0"}], ",", 
              RowBox[{"t", "\[Rule]", "0"}], ",", 
              RowBox[{"\[Epsilon]", "\[Rule]", "0"}]}], "}"}]}], ")"}]}], "//", 
         RowBox[{
          RowBox[{"Collect", "[", 
           RowBox[{"#", ",", "\[Theta]", ",", "Factor"}], "]"}], 
          "&"}]}]}]}]}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"OperatorEqualMass", "[", "l_", "]"}], ":=", 
   RowBox[{"FinalOperatorMUM", "[", 
    RowBox[{"z", ",", "\[Epsilon]", ",", "l"}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.837677298638225*^9, 3.837677313515876*^9}, {
   3.837677359935071*^9, 3.837677364220083*^9}, {3.8376774293365726`*^9, 
   3.837677430107296*^9}, 3.837677489295945*^9},
 CellLabel->"In[42]:=",ExpressionUUID->"3ef52cb3-be84-4a03-9ea8-0b04685c2437"]
}, Closed]],

Cell[CellGroupData[{

Cell["Equal-Mass Operators", "Section",
 CellChangeTimes->{{3.837236824770177*^9, 
  3.8372368297318697`*^9}},ExpressionUUID->"88525f0a-1f82-47e3-8418-\
de4a551e1c55"],

Cell["Compute all equal-mass operators up to l=7:", "Text",
 CellChangeTimes->{{3.837236856124256*^9, 3.837236879052041*^9}, {
  3.837236932524439*^9, 
  3.837236932794434*^9}},ExpressionUUID->"2da521f2-bd42-4850-a4e4-\
5ec20bb93dc5"],

Cell[BoxData[
 RowBox[{"Do", "[", 
  RowBox[{
   RowBox[{"OperatorEqualMass", "[", "k", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"k", ",", "1", ",", "7"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.8187488072654247`*^9, 3.818748813926918*^9}, {
   3.8187488838244762`*^9, 3.8187488873103*^9}, {3.8209032432969017`*^9, 
   3.820903250193495*^9}, 3.837236845246765*^9, 3.837236883271633*^9, {
   3.8376774535428553`*^9, 3.837677457299068*^9}},
 CellLabel->"In[49]:=",ExpressionUUID->"7fb7c23a-434c-40d2-849c-fd47211db1d8"],

Cell[BoxData["\[IndentingNewLine]"], "Input",
 CellChangeTimes->{
  3.8372369197602043`*^9},ExpressionUUID->"6bcb99c3-064e-4af7-ba5e-\
5433569325f1"],

Cell["Table of all equal-mass operators up to l=7:", "Text",
 CellChangeTimes->{{3.837236920985992*^9, 
  3.837236938847073*^9}},ExpressionUUID->"1e412bc4-9d92-496d-8549-\
712a0510ff6f"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"OperatorEqualMass", "[", "k", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"k", ",", "1", ",", "7"}], "}"}]}], "]"}], "//", 
  "TableForm"}]], "Input",
 CellChangeTimes->{{3.817348677492998*^9, 3.81734874213745*^9}, 
   3.8173487792088213`*^9, {3.8187487235786753`*^9, 3.8187487420270348`*^9}, {
   3.818748857701894*^9, 3.8187488693667192`*^9}, {3.820903212325583*^9, 
   3.820903235511345*^9}, 3.8372369175858173`*^9, 3.83767747022665*^9},
 CellLabel->"In[50]:=",ExpressionUUID->"eff9cf9a-96ee-4535-a7f0-df61bdb570b6"],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {
      RowBox[{"1", "-", 
       RowBox[{"2", " ", "z"}], "+", "\[Epsilon]", "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"4", " ", "z"}]}], ")"}], " ", "\[Theta]"}]}]},
     {
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"2", " ", "\[Epsilon]"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"1", "-", 
          RowBox[{"3", " ", "z"}], "+", "\[Epsilon]", "+", 
          RowBox[{"z", " ", "\[Epsilon]"}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "2"}], "+", 
          RowBox[{"10", " ", "z"}], "-", 
          RowBox[{"3", " ", "\[Epsilon]"}], "+", 
          RowBox[{"10", " ", "z", " ", "\[Epsilon]"}], "+", 
          RowBox[{"9", " ", 
           SuperscriptBox["z", "2"], " ", "\[Epsilon]"}]}], ")"}], " ", 
        "\[Theta]"}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "z"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"9", " ", "z"}]}], ")"}], " ", 
        SuperscriptBox["\[Theta]", "2"]}]}]},
     {
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"2", " ", "\[Epsilon]"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"3", " ", "\[Epsilon]"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"1", "-", 
          RowBox[{"4", " ", "z"}], "+", "\[Epsilon]", "+", 
          RowBox[{"2", " ", "z", " ", "\[Epsilon]"}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "3"}], "+", 
          RowBox[{"18", " ", "z"}], "-", 
          RowBox[{"12", " ", "\[Epsilon]"}], "+", 
          RowBox[{"60", " ", "z", " ", "\[Epsilon]"}], "-", 
          RowBox[{"11", " ", 
           SuperscriptBox["\[Epsilon]", "2"]}], "+", 
          RowBox[{"28", " ", "z", " ", 
           SuperscriptBox["\[Epsilon]", "2"]}], "+", 
          RowBox[{"64", " ", 
           SuperscriptBox["z", "2"], " ", 
           SuperscriptBox["\[Epsilon]", "2"]}]}], ")"}], " ", "\[Theta]"}], 
       "-", 
       RowBox[{"3", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"10", " ", "z"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"2", " ", "\[Epsilon]"}]}], ")"}], " ", 
        SuperscriptBox["\[Theta]", "2"]}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"4", " ", "z"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"16", " ", "z"}]}], ")"}], " ", 
        SuperscriptBox["\[Theta]", "3"]}]}]},
     {
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"2", " ", "\[Epsilon]"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"3", " ", "\[Epsilon]"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"4", " ", "\[Epsilon]"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"1", "-", 
          RowBox[{"5", " ", "z"}], "+", "\[Epsilon]", "+", 
          RowBox[{"3", " ", "z", " ", "\[Epsilon]"}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "4"}], "+", 
          RowBox[{"28", " ", "z"}], "-", 
          RowBox[{"30", " ", "\[Epsilon]"}], "+", 
          RowBox[{"189", " ", "z", " ", "\[Epsilon]"}], "+", 
          RowBox[{"26", " ", 
           SuperscriptBox["z", "2"], " ", "\[Epsilon]"}], "-", 
          RowBox[{"225", " ", 
           SuperscriptBox["z", "3"], " ", "\[Epsilon]"}], "-", 
          RowBox[{"70", " ", 
           SuperscriptBox["\[Epsilon]", "2"]}], "+", 
          RowBox[{"343", " ", "z", " ", 
           SuperscriptBox["\[Epsilon]", "2"]}], "-", 
          RowBox[{"225", " ", 
           SuperscriptBox["z", "3"], " ", 
           SuperscriptBox["\[Epsilon]", "2"]}], "-", 
          RowBox[{"50", " ", 
           SuperscriptBox["\[Epsilon]", "3"]}], "+", 
          RowBox[{"84", " ", "z", " ", 
           SuperscriptBox["\[Epsilon]", "3"]}], "+", 
          RowBox[{"414", " ", 
           SuperscriptBox["z", "2"], " ", 
           SuperscriptBox["\[Epsilon]", "3"]}]}], ")"}], " ", "\[Theta]"}], 
       "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"6", "-", 
          RowBox[{"63", " ", "z"}], "+", 
          RowBox[{"26", " ", 
           SuperscriptBox["z", "2"]}], "-", 
          RowBox[{"225", " ", 
           SuperscriptBox["z", "3"]}], "+", 
          RowBox[{"30", " ", "\[Epsilon]"}], "-", 
          RowBox[{"315", " ", "z", " ", "\[Epsilon]"}], "-", 
          RowBox[{"675", " ", 
           SuperscriptBox["z", "3"], " ", "\[Epsilon]"}], "+", 
          RowBox[{"35", " ", 
           SuperscriptBox["\[Epsilon]", "2"]}], "-", 
          RowBox[{"343", " ", "z", " ", 
           SuperscriptBox["\[Epsilon]", "2"]}], "-", 
          RowBox[{"363", " ", 
           SuperscriptBox["z", "2"], " ", 
           SuperscriptBox["\[Epsilon]", "2"]}], "-", 
          RowBox[{"225", " ", 
           SuperscriptBox["z", "3"], " ", 
           SuperscriptBox["\[Epsilon]", "2"]}]}], ")"}], " ", 
        SuperscriptBox["\[Theta]", "2"]}], "-", 
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{"2", "-", 
          RowBox[{"35", " ", "z"}], "+", 
          RowBox[{"225", " ", 
           SuperscriptBox["z", "3"]}], "+", 
          RowBox[{"5", " ", "\[Epsilon]"}], "-", 
          RowBox[{"105", " ", "z", " ", "\[Epsilon]"}], "+", 
          RowBox[{"259", " ", 
           SuperscriptBox["z", "2"], " ", "\[Epsilon]"}], "+", 
          RowBox[{"225", " ", 
           SuperscriptBox["z", "3"], " ", "\[Epsilon]"}]}], ")"}], " ", 
        SuperscriptBox["\[Theta]", "3"]}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "z"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"9", " ", "z"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"25", " ", "z"}]}], ")"}], " ", 
        SuperscriptBox["\[Theta]", "4"]}]}]},
     {
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"2", " ", "\[Epsilon]"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"3", " ", "\[Epsilon]"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"4", " ", "\[Epsilon]"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"5", " ", "\[Epsilon]"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"1", "-", 
          RowBox[{"6", " ", "z"}], "+", "\[Epsilon]", "+", 
          RowBox[{"4", " ", "z", " ", "\[Epsilon]"}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          RowBox[{"40", " ", "z"}], "-", 
          RowBox[{"60", " ", "\[Epsilon]"}], "+", 
          RowBox[{"448", " ", "z", " ", "\[Epsilon]"}], "+", 
          RowBox[{"1152", " ", 
           SuperscriptBox["z", "3"], " ", "\[Epsilon]"}], "-", 
          RowBox[{"255", " ", 
           SuperscriptBox["\[Epsilon]", "2"]}], "+", 
          RowBox[{"1664", " ", "z", " ", 
           SuperscriptBox["\[Epsilon]", "2"]}], "+", 
          RowBox[{"472", " ", 
           SuperscriptBox["z", "2"], " ", 
           SuperscriptBox["\[Epsilon]", "2"]}], "-", 
          RowBox[{"3456", " ", 
           SuperscriptBox["z", "3"], " ", 
           SuperscriptBox["\[Epsilon]", "2"]}], "-", 
          RowBox[{"450", " ", 
           SuperscriptBox["\[Epsilon]", "3"]}], "+", 
          RowBox[{"2128", " ", "z", " ", 
           SuperscriptBox["\[Epsilon]", "3"]}], "-", 
          RowBox[{"4608", " ", 
           SuperscriptBox["z", "3"], " ", 
           SuperscriptBox["\[Epsilon]", "3"]}], "-", 
          RowBox[{"274", " ", 
           SuperscriptBox["\[Epsilon]", "4"]}], "+", 
          RowBox[{"208", " ", "z", " ", 
           SuperscriptBox["\[Epsilon]", "4"]}], "+", 
          RowBox[{"2816", " ", 
           SuperscriptBox["z", "2"], " ", 
           SuperscriptBox["\[Epsilon]", "4"]}]}], ")"}], " ", "\[Theta]"}], 
       "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"10", "-", 
          RowBox[{"112", " ", "z"}], "+", 
          RowBox[{"1152", " ", 
           SuperscriptBox["z", "3"]}], "+", 
          RowBox[{"90", " ", "\[Epsilon]"}], "-", 
          RowBox[{"1008", " ", "z", " ", "\[Epsilon]"}], "+", 
          RowBox[{"236", " ", 
           SuperscriptBox["z", "2"], " ", "\[Epsilon]"}], "+", 
          RowBox[{"1152", " ", 
           SuperscriptBox["z", "3"], " ", "\[Epsilon]"}], "+", 
          RowBox[{"255", " ", 
           SuperscriptBox["\[Epsilon]", "2"]}], "-", 
          RowBox[{"2772", " ", "z", " ", 
           SuperscriptBox["\[Epsilon]", "2"]}], "-", 
          RowBox[{"10368", " ", 
           SuperscriptBox["z", "3"], " ", 
           SuperscriptBox["\[Epsilon]", "2"]}], "+", 
          RowBox[{"225", " ", 
           SuperscriptBox["\[Epsilon]", "3"]}], "-", 
          RowBox[{"2128", " ", "z", " ", 
           SuperscriptBox["\[Epsilon]", "3"]}], "-", 
          RowBox[{"4864", " ", 
           SuperscriptBox["z", "2"], " ", 
           SuperscriptBox["\[Epsilon]", "3"]}], "-", 
          RowBox[{"4608", " ", 
           SuperscriptBox["z", "3"], " ", 
           SuperscriptBox["\[Epsilon]", "3"]}]}], ")"}], " ", 
        SuperscriptBox["\[Theta]", "2"]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "10"}], "+", 
          RowBox[{"168", " ", "z"}], "-", 
          RowBox[{"236", " ", 
           SuperscriptBox["z", "2"]}], "+", 
          RowBox[{"4608", " ", 
           SuperscriptBox["z", "3"]}], "-", 
          RowBox[{"60", " ", "\[Epsilon]"}], "+", 
          RowBox[{"1120", " ", "z", " ", "\[Epsilon]"}], "-", 
          RowBox[{"85", " ", 
           SuperscriptBox["\[Epsilon]", "2"]}], "+", 
          RowBox[{"1848", " ", "z", " ", 
           SuperscriptBox["\[Epsilon]", "2"]}], "-", 
          RowBox[{"2976", " ", 
           SuperscriptBox["z", "2"], " ", 
           SuperscriptBox["\[Epsilon]", "2"]}], "-", 
          RowBox[{"6912", " ", 
           SuperscriptBox["z", "3"], " ", 
           SuperscriptBox["\[Epsilon]", "2"]}]}], ")"}], " ", 
        SuperscriptBox["\[Theta]", "3"]}], "+", 
       RowBox[{"5", " ", 
        RowBox[{"(", 
         RowBox[{"1", "-", 
          RowBox[{"28", " ", "z"}], "+", 
          RowBox[{"1152", " ", 
           SuperscriptBox["z", "3"]}], "+", 
          RowBox[{"3", " ", "\[Epsilon]"}], "-", 
          RowBox[{"112", " ", "z", " ", "\[Epsilon]"}], "+", 
          RowBox[{"784", " ", 
           SuperscriptBox["z", "2"], " ", "\[Epsilon]"}]}], ")"}], " ", 
        SuperscriptBox["\[Theta]", "4"]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"4", " ", "z"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"16", " ", "z"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"36", " ", "z"}]}], ")"}], " ", 
        SuperscriptBox["\[Theta]", "5"]}]}]},
     {
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"2", " ", "\[Epsilon]"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"3", " ", "\[Epsilon]"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"4", " ", "\[Epsilon]"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"5", " ", "\[Epsilon]"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"6", " ", "\[Epsilon]"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"1", "-", 
          RowBox[{"7", " ", "z"}], "+", "\[Epsilon]", "+", 
          RowBox[{"5", " ", "z", " ", "\[Epsilon]"}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "6"}], "+", 
          RowBox[{"54", " ", "z"}], "-", 
          RowBox[{"105", " ", "\[Epsilon]"}], "+", 
          RowBox[{"900", " ", "z", " ", "\[Epsilon]"}], "+", 
          RowBox[{"51", " ", 
           SuperscriptBox["z", "2"], " ", "\[Epsilon]"}], "-", 
          RowBox[{"5178", " ", 
           SuperscriptBox["z", "3"], " ", "\[Epsilon]"}], "+", 
          RowBox[{"44100", " ", 
           SuperscriptBox["z", "4"], " ", "\[Epsilon]"}], "-", 
          RowBox[{"700", " ", 
           SuperscriptBox["\[Epsilon]", "2"]}], "+", 
          RowBox[{"5514", " ", "z", " ", 
           SuperscriptBox["\[Epsilon]", "2"]}], "+", 
          RowBox[{"27112", " ", 
           SuperscriptBox["z", "3"], " ", 
           SuperscriptBox["\[Epsilon]", "2"]}], "+", 
          RowBox[{"66150", " ", 
           SuperscriptBox["z", "4"], " ", 
           SuperscriptBox["\[Epsilon]", "2"]}], "-", 
          RowBox[{"2205", " ", 
           SuperscriptBox["\[Epsilon]", "3"]}], "+", 
          RowBox[{"14760", " ", "z", " ", 
           SuperscriptBox["\[Epsilon]", "3"]}], "+", 
          RowBox[{"6465", " ", 
           SuperscriptBox["z", "2"], " ", 
           SuperscriptBox["\[Epsilon]", "3"]}], "-", 
          RowBox[{"37410", " ", 
           SuperscriptBox["z", "3"], " ", 
           SuperscriptBox["\[Epsilon]", "3"]}], "+", 
          RowBox[{"22050", " ", 
           SuperscriptBox["z", "4"], " ", 
           SuperscriptBox["\[Epsilon]", "3"]}], "-", 
          RowBox[{"3248", " ", 
           SuperscriptBox["\[Epsilon]", "4"]}], "+", 
          RowBox[{"14628", " ", "z", " ", 
           SuperscriptBox["\[Epsilon]", "4"]}], "-", 
          RowBox[{"69700", " ", 
           SuperscriptBox["z", "3"], " ", 
           SuperscriptBox["\[Epsilon]", "4"]}], "-", 
          RowBox[{"1764", " ", 
           SuperscriptBox["\[Epsilon]", "5"]}], "-", 
          RowBox[{"360", " ", "z", " ", 
           SuperscriptBox["\[Epsilon]", "5"]}], "+", 
          RowBox[{"20700", " ", 
           SuperscriptBox["z", "2"], " ", 
           SuperscriptBox["\[Epsilon]", "5"]}]}], ")"}], " ", "\[Theta]"}], 
       "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"15", "-", 
          RowBox[{"180", " ", "z"}], "+", 
          RowBox[{"51", " ", 
           SuperscriptBox["z", "2"]}], "-", 
          RowBox[{"5178", " ", 
           SuperscriptBox["z", "3"]}], "+", 
          RowBox[{"44100", " ", 
           SuperscriptBox["z", "4"]}], "+", 
          RowBox[{"210", " ", "\[Epsilon]"}], "-", 
          RowBox[{"2520", " ", "z", " ", "\[Epsilon]"}], "+", 
          RowBox[{"3840", " ", 
           SuperscriptBox["z", "3"], " ", "\[Epsilon]"}], "+", 
          RowBox[{"198450", " ", 
           SuperscriptBox["z", "4"], " ", "\[Epsilon]"}], "+", 
          RowBox[{"1050", " ", 
           SuperscriptBox["\[Epsilon]", "2"]}], "-", 
          RowBox[{"12402", " ", "z", " ", 
           SuperscriptBox["\[Epsilon]", "2"]}], "+", 
          RowBox[{"525", " ", 
           SuperscriptBox["z", "2"], " ", 
           SuperscriptBox["\[Epsilon]", "2"]}], "+", 
          RowBox[{"73656", " ", 
           SuperscriptBox["z", "3"], " ", 
           SuperscriptBox["\[Epsilon]", "2"]}], "+", 
          RowBox[{"165375", " ", 
           SuperscriptBox["z", "4"], " ", 
           SuperscriptBox["\[Epsilon]", "2"]}], "+", 
          RowBox[{"2205", " ", 
           SuperscriptBox["\[Epsilon]", "3"]}], "-", 
          RowBox[{"24570", " ", "z", " ", 
           SuperscriptBox["\[Epsilon]", "3"]}], "-", 
          RowBox[{"112230", " ", 
           SuperscriptBox["z", "3"], " ", 
           SuperscriptBox["\[Epsilon]", "3"]}], "+", 
          RowBox[{"33075", " ", 
           SuperscriptBox["z", "4"], " ", 
           SuperscriptBox["\[Epsilon]", "3"]}], "+", 
          RowBox[{"1624", " ", 
           SuperscriptBox["\[Epsilon]", "4"]}], "-", 
          RowBox[{"14628", " ", "z", " ", 
           SuperscriptBox["\[Epsilon]", "4"]}], "-", 
          RowBox[{"54240", " ", 
           SuperscriptBox["z", "2"], " ", 
           SuperscriptBox["\[Epsilon]", "4"]}], "-", 
          RowBox[{"69700", " ", 
           SuperscriptBox["z", "3"], " ", 
           SuperscriptBox["\[Epsilon]", "4"]}]}], ")"}], " ", 
        SuperscriptBox["\[Theta]", "2"]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "20"}], "+", 
          RowBox[{"336", " ", "z"}], "-", 
          RowBox[{"23272", " ", 
           SuperscriptBox["z", "3"]}], "+", 
          RowBox[{"132300", " ", 
           SuperscriptBox["z", "4"]}], "-", 
          RowBox[{"210", " ", "\[Epsilon]"}], "+", 
          RowBox[{"3780", " ", "z", " ", "\[Epsilon]"}], "-", 
          RowBox[{"4752", " ", 
           SuperscriptBox["z", "2"], " ", "\[Epsilon]"}], "+", 
          RowBox[{"67140", " ", 
           SuperscriptBox["z", "3"], " ", "\[Epsilon]"}], "+", 
          RowBox[{"286650", " ", 
           SuperscriptBox["z", "4"], " ", "\[Epsilon]"}], "-", 
          RowBox[{"700", " ", 
           SuperscriptBox["\[Epsilon]", "2"]}], "+", 
          RowBox[{"13776", " ", "z", " ", 
           SuperscriptBox["\[Epsilon]", "2"]}], "+", 
          RowBox[{"93088", " ", 
           SuperscriptBox["z", "3"], " ", 
           SuperscriptBox["\[Epsilon]", "2"]}], "+", 
          RowBox[{"132300", " ", 
           SuperscriptBox["z", "4"], " ", 
           SuperscriptBox["\[Epsilon]", "2"]}], "-", 
          RowBox[{"735", " ", 
           SuperscriptBox["\[Epsilon]", "3"]}], "+", 
          RowBox[{"16380", " ", "z", " ", 
           SuperscriptBox["\[Epsilon]", "3"]}], "-", 
          RowBox[{"10602", " ", 
           SuperscriptBox["z", "2"], " ", 
           SuperscriptBox["\[Epsilon]", "3"]}], "-", 
          RowBox[{"74820", " ", 
           SuperscriptBox["z", "3"], " ", 
           SuperscriptBox["\[Epsilon]", "3"]}], "+", 
          RowBox[{"11025", " ", 
           SuperscriptBox["z", "4"], " ", 
           SuperscriptBox["\[Epsilon]", "3"]}]}], ")"}], " ", 
        SuperscriptBox["\[Theta]", "3"]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"15", "-", 
          RowBox[{"378", " ", "z"}], "+", 
          RowBox[{"1188", " ", 
           SuperscriptBox["z", "2"]}], "-", 
          RowBox[{"43926", " ", 
           SuperscriptBox["z", "3"]}], "+", 
          RowBox[{"143325", " ", 
           SuperscriptBox["z", "4"]}], "+", 
          RowBox[{"105", " ", "\[Epsilon]"}], "-", 
          RowBox[{"3150", " ", "z", " ", "\[Epsilon]"}], "+", 
          RowBox[{"96870", " ", 
           SuperscriptBox["z", "3"], " ", "\[Epsilon]"}], "+", 
          RowBox[{"165375", " ", 
           SuperscriptBox["z", "4"], " ", "\[Epsilon]"}], "+", 
          RowBox[{"175", " ", 
           SuperscriptBox["\[Epsilon]", "2"]}], "-", 
          RowBox[{"6888", " ", "z", " ", 
           SuperscriptBox["\[Epsilon]", "2"]}], "+", 
          RowBox[{"44598", " ", 
           SuperscriptBox["z", "2"], " ", 
           SuperscriptBox["\[Epsilon]", "2"]}], "+", 
          RowBox[{"46544", " ", 
           SuperscriptBox["z", "3"], " ", 
           SuperscriptBox["\[Epsilon]", "2"]}], "+", 
          RowBox[{"33075", " ", 
           SuperscriptBox["z", "4"], " ", 
           SuperscriptBox["\[Epsilon]", "2"]}]}], ")"}], " ", 
        SuperscriptBox["\[Theta]", "4"]}], "+", 
       RowBox[{"3", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "2"}], "+", 
          RowBox[{"84", " ", "z"}], "-", 
          RowBox[{"12916", " ", 
           SuperscriptBox["z", "3"]}], "+", 
          RowBox[{"22050", " ", 
           SuperscriptBox["z", "4"]}], "-", 
          RowBox[{"7", " ", "\[Epsilon]"}], "+", 
          RowBox[{"420", " ", "z", " ", "\[Epsilon]"}], "-", 
          RowBox[{"5922", " ", 
           SuperscriptBox["z", "2"], " ", "\[Epsilon]"}], "+", 
          RowBox[{"12916", " ", 
           SuperscriptBox["z", "3"], " ", "\[Epsilon]"}], "+", 
          RowBox[{"11025", " ", 
           SuperscriptBox["z", "4"], " ", "\[Epsilon]"}]}], ")"}], " ", 
        SuperscriptBox["\[Theta]", "5"]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "z"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"9", " ", "z"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"25", " ", "z"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"49", " ", "z"}]}], ")"}], " ", 
        SuperscriptBox["\[Theta]", "6"]}]}]},
     {
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"2", " ", "\[Epsilon]"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"3", " ", "\[Epsilon]"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"4", " ", "\[Epsilon]"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"5", " ", "\[Epsilon]"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"6", " ", "\[Epsilon]"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"7", " ", "\[Epsilon]"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"1", "-", 
          RowBox[{"8", " ", "z"}], "+", "\[Epsilon]", "+", 
          RowBox[{"6", " ", "z", " ", "\[Epsilon]"}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "7"}], "+", 
          RowBox[{"70", " ", "z"}], "-", 
          RowBox[{"168", " ", "\[Epsilon]"}], "+", 
          RowBox[{"1620", " ", "z", " ", "\[Epsilon]"}], "+", 
          RowBox[{"18432", " ", 
           SuperscriptBox["z", "3"], " ", "\[Epsilon]"}], "-", 
          RowBox[{"589824", " ", 
           SuperscriptBox["z", "4"], " ", "\[Epsilon]"}], "-", 
          RowBox[{"1610", " ", 
           SuperscriptBox["\[Epsilon]", "2"]}], "+", 
          RowBox[{"14650", " ", "z", " ", 
           SuperscriptBox["\[Epsilon]", "2"]}], "+", 
          RowBox[{"1692", " ", 
           SuperscriptBox["z", "2"], " ", 
           SuperscriptBox["\[Epsilon]", "2"]}], "-", 
          RowBox[{"170880", " ", 
           SuperscriptBox["z", "3"], " ", 
           SuperscriptBox["\[Epsilon]", "2"]}], "+", 
          RowBox[{"884736", " ", 
           SuperscriptBox["z", "4"], " ", 
           SuperscriptBox["\[Epsilon]", "2"]}], "-", 
          RowBox[{"7840", " ", 
           SuperscriptBox["\[Epsilon]", "3"]}], "+", 
          RowBox[{"64620", " ", "z", " ", 
           SuperscriptBox["\[Epsilon]", "3"]}], "+", 
          RowBox[{"445440", " ", 
           SuperscriptBox["z", "3"], " ", 
           SuperscriptBox["\[Epsilon]", "3"]}], "+", 
          RowBox[{"2359296", " ", 
           SuperscriptBox["z", "4"], " ", 
           SuperscriptBox["\[Epsilon]", "3"]}], "-", 
          RowBox[{"20307", " ", 
           SuperscriptBox["\[Epsilon]", "4"]}], "+", 
          RowBox[{"138424", " ", "z", " ", 
           SuperscriptBox["\[Epsilon]", "4"]}], "+", 
          RowBox[{"83124", " ", 
           SuperscriptBox["z", "2"], " ", 
           SuperscriptBox["\[Epsilon]", "4"]}], "-", 
          RowBox[{"339840", " ", 
           SuperscriptBox["z", "3"], " ", 
           SuperscriptBox["\[Epsilon]", "4"]}], "+", 
          RowBox[{"884736", " ", 
           SuperscriptBox["z", "4"], " ", 
           SuperscriptBox["\[Epsilon]", "4"]}], "-", 
          RowBox[{"26264", " ", 
           SuperscriptBox["\[Epsilon]", "5"]}], "+", 
          RowBox[{"111240", " ", "z", " ", 
           SuperscriptBox["\[Epsilon]", "5"]}], "-", 
          RowBox[{"974592", " ", 
           SuperscriptBox["z", "3"], " ", 
           SuperscriptBox["\[Epsilon]", "5"]}], "-", 
          RowBox[{"13068", " ", 
           SuperscriptBox["\[Epsilon]", "6"]}], "-", 
          RowBox[{"15696", " ", "z", " ", 
           SuperscriptBox["\[Epsilon]", "6"]}], "+", 
          RowBox[{"164592", " ", 
           SuperscriptBox["z", "2"], " ", 
           SuperscriptBox["\[Epsilon]", "6"]}]}], ")"}], " ", "\[Theta]"}], 
       "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"21", "-", 
          RowBox[{"270", " ", "z"}], "+", 
          RowBox[{"18432", " ", 
           SuperscriptBox["z", "3"]}], "-", 
          RowBox[{"589824", " ", 
           SuperscriptBox["z", "4"]}], "+", 
          RowBox[{"420", " ", "\[Epsilon]"}], "-", 
          RowBox[{"5400", " ", "z", " ", "\[Epsilon]"}], "+", 
          RowBox[{"1128", " ", 
           SuperscriptBox["z", "2"], " ", "\[Epsilon]"}], "-", 
          RowBox[{"70912", " ", 
           SuperscriptBox["z", "3"], " ", "\[Epsilon]"}], "-", 
          RowBox[{"1474560", " ", 
           SuperscriptBox["z", "4"], " ", "\[Epsilon]"}], "+", 
          RowBox[{"3220", " ", 
           SuperscriptBox["\[Epsilon]", "2"]}], "-", 
          RowBox[{"41010", " ", "z", " ", 
           SuperscriptBox["\[Epsilon]", "2"]}], "-", 
          RowBox[{"323968", " ", 
           SuperscriptBox["z", "3"], " ", 
           SuperscriptBox["\[Epsilon]", "2"]}], "+", 
          RowBox[{"4866048", " ", 
           SuperscriptBox["z", "4"], " ", 
           SuperscriptBox["\[Epsilon]", "2"]}], "+", 
          RowBox[{"11760", " ", 
           SuperscriptBox["\[Epsilon]", "3"]}], "-", 
          RowBox[{"145260", " ", "z", " ", 
           SuperscriptBox["\[Epsilon]", "3"]}], "-", 
          RowBox[{"23424", " ", 
           SuperscriptBox["z", "2"], " ", 
           SuperscriptBox["\[Epsilon]", "3"]}], "+", 
          RowBox[{"1537536", " ", 
           SuperscriptBox["z", "3"], " ", 
           SuperscriptBox["\[Epsilon]", "3"]}], "+", 
          RowBox[{"5898240", " ", 
           SuperscriptBox["z", "4"], " ", 
           SuperscriptBox["\[Epsilon]", "3"]}], "+", 
          RowBox[{"20307", " ", 
           SuperscriptBox["\[Epsilon]", "4"]}], "-", 
          RowBox[{"230220", " ", "z", " ", 
           SuperscriptBox["\[Epsilon]", "4"]}], "-", 
          RowBox[{"1019520", " ", 
           SuperscriptBox["z", "3"], " ", 
           SuperscriptBox["\[Epsilon]", "4"]}], "+", 
          RowBox[{"1327104", " ", 
           SuperscriptBox["z", "4"], " ", 
           SuperscriptBox["\[Epsilon]", "4"]}], "+", 
          RowBox[{"13132", " ", 
           SuperscriptBox["\[Epsilon]", "5"]}], "-", 
          RowBox[{"111240", " ", "z", " ", 
           SuperscriptBox["\[Epsilon]", "5"]}], "-", 
          RowBox[{"597024", " ", 
           SuperscriptBox["z", "2"], " ", 
           SuperscriptBox["\[Epsilon]", "5"]}], "-", 
          RowBox[{"974592", " ", 
           SuperscriptBox["z", "3"], " ", 
           SuperscriptBox["\[Epsilon]", "5"]}]}], ")"}], " ", 
        SuperscriptBox["\[Theta]", "2"]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "35"}], "+", 
          RowBox[{"600", " ", "z"}], "-", 
          RowBox[{"564", " ", 
           SuperscriptBox["z", "2"]}], "+", 
          RowBox[{"99968", " ", 
           SuperscriptBox["z", "3"]}], "-", 
          RowBox[{"2359296", " ", 
           SuperscriptBox["z", "4"]}], "-", 
          RowBox[{"560", " ", "\[Epsilon]"}], "+", 
          RowBox[{"10080", " ", "z", " ", "\[Epsilon]"}], "-", 
          RowBox[{"546048", " ", 
           SuperscriptBox["z", "3"], " ", "\[Epsilon]"}], "-", 
          RowBox[{"1179648", " ", 
           SuperscriptBox["z", "4"], " ", "\[Epsilon]"}], "-", 
          RowBox[{"3220", " ", 
           SuperscriptBox["\[Epsilon]", "2"]}], "+", 
          RowBox[{"61500", " ", "z", " ", 
           SuperscriptBox["\[Epsilon]", "2"]}], "-", 
          RowBox[{"67128", " ", 
           SuperscriptBox["z", "2"], " ", 
           SuperscriptBox["\[Epsilon]", "2"]}], "+", 
          RowBox[{"412928", " ", 
           SuperscriptBox["z", "3"], " ", 
           SuperscriptBox["\[Epsilon]", "2"]}], "+", 
          RowBox[{"7520256", " ", 
           SuperscriptBox["z", "4"], " ", 
           SuperscriptBox["\[Epsilon]", "2"]}], "-", 
          RowBox[{"7840", " ", 
           SuperscriptBox["\[Epsilon]", "3"]}], "+", 
          RowBox[{"161280", " ", "z", " ", 
           SuperscriptBox["\[Epsilon]", "3"]}], "+", 
          RowBox[{"2184192", " ", 
           SuperscriptBox["z", "3"], " ", 
           SuperscriptBox["\[Epsilon]", "3"]}], "+", 
          RowBox[{"4718592", " ", 
           SuperscriptBox["z", "4"], " ", 
           SuperscriptBox["\[Epsilon]", "3"]}], "-", 
          RowBox[{"6769", " ", 
           SuperscriptBox["\[Epsilon]", "4"]}], "+", 
          RowBox[{"153480", " ", "z", " ", 
           SuperscriptBox["\[Epsilon]", "4"]}], "+", 
          RowBox[{"63504", " ", 
           SuperscriptBox["z", "2"], " ", 
           SuperscriptBox["\[Epsilon]", "4"]}], "-", 
          RowBox[{"679680", " ", 
           SuperscriptBox["z", "3"], " ", 
           SuperscriptBox["\[Epsilon]", "4"]}], "+", 
          RowBox[{"442368", " ", 
           SuperscriptBox["z", "4"], " ", 
           SuperscriptBox["\[Epsilon]", "4"]}]}], ")"}], " ", 
        SuperscriptBox["\[Theta]", "3"]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"35", "-", 
          RowBox[{"840", " ", "z"}], "+", 
          RowBox[{"223360", " ", 
           SuperscriptBox["z", "3"]}], "-", 
          RowBox[{"3686400", " ", 
           SuperscriptBox["z", "4"]}], "+", 
          RowBox[{"420", " ", "\[Epsilon]"}], "-", 
          RowBox[{"11340", " ", "z", " ", "\[Epsilon]"}], "+", 
          RowBox[{"35040", " ", 
           SuperscriptBox["z", "2"], " ", "\[Epsilon]"}], "-", 
          RowBox[{"1191424", " ", 
           SuperscriptBox["z", "3"], " ", "\[Epsilon]"}], "-", 
          RowBox[{"294912", " ", 
           SuperscriptBox["z", "4"], " ", "\[Epsilon]"}], "+", 
          RowBox[{"1610", " ", 
           SuperscriptBox["\[Epsilon]", "2"]}], "-", 
          RowBox[{"51240", " ", "z", " ", 
           SuperscriptBox["\[Epsilon]", "2"]}], "+", 
          RowBox[{"943360", " ", 
           SuperscriptBox["z", "3"], " ", 
           SuperscriptBox["\[Epsilon]", "2"]}], "+", 
          RowBox[{"4423680", " ", 
           SuperscriptBox["z", "4"], " ", 
           SuperscriptBox["\[Epsilon]", "2"]}], "+", 
          RowBox[{"1960", " ", 
           SuperscriptBox["\[Epsilon]", "3"]}], "-", 
          RowBox[{"80640", " ", "z", " ", 
           SuperscriptBox["\[Epsilon]", "3"]}], "+", 
          RowBox[{"471360", " ", 
           SuperscriptBox["z", "2"], " ", 
           SuperscriptBox["\[Epsilon]", "3"]}], "+", 
          RowBox[{"1092096", " ", 
           SuperscriptBox["z", "3"], " ", 
           SuperscriptBox["\[Epsilon]", "3"]}], "+", 
          RowBox[{"1179648", " ", 
           SuperscriptBox["z", "4"], " ", 
           SuperscriptBox["\[Epsilon]", "3"]}]}], ")"}], " ", 
        SuperscriptBox["\[Theta]", "4"]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "21"}], "+", 
          RowBox[{"756", " ", "z"}], "-", 
          RowBox[{"4380", " ", 
           SuperscriptBox["z", "2"]}], "+", 
          RowBox[{"273024", " ", 
           SuperscriptBox["z", "3"]}], "-", 
          RowBox[{"2801664", " ", 
           SuperscriptBox["z", "4"]}], "-", 
          RowBox[{"168", " ", "\[Epsilon]"}], "+", 
          RowBox[{"7560", " ", "z", " ", "\[Epsilon]"}], "-", 
          RowBox[{"1102080", " ", 
           SuperscriptBox["z", "3"], " ", "\[Epsilon]"}], "-", 
          RowBox[{"322", " ", 
           SuperscriptBox["\[Epsilon]", "2"]}], "+", 
          RowBox[{"20496", " ", "z", " ", 
           SuperscriptBox["\[Epsilon]", "2"]}], "-", 
          RowBox[{"288240", " ", 
           SuperscriptBox["z", "2"], " ", 
           SuperscriptBox["\[Epsilon]", "2"]}], "+", 
          RowBox[{"377344", " ", 
           SuperscriptBox["z", "3"], " ", 
           SuperscriptBox["\[Epsilon]", "2"]}], "+", 
          RowBox[{"884736", " ", 
           SuperscriptBox["z", "4"], " ", 
           SuperscriptBox["\[Epsilon]", "2"]}]}], ")"}], " ", 
        SuperscriptBox["\[Theta]", "5"]}], "-", 
       RowBox[{"7", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"60", " ", "z"}], "-", 
          RowBox[{"26240", " ", 
           SuperscriptBox["z", "3"]}], "+", 
          RowBox[{"147456", " ", 
           SuperscriptBox["z", "4"]}], "-", 
          RowBox[{"4", " ", "\[Epsilon]"}], "+", 
          RowBox[{"360", " ", "z", " ", "\[Epsilon]"}], "-", 
          RowBox[{"8736", " ", 
           SuperscriptBox["z", "2"], " ", "\[Epsilon]"}], "+", 
          RowBox[{"52480", " ", 
           SuperscriptBox["z", "3"], " ", "\[Epsilon]"}]}], ")"}], " ", 
        SuperscriptBox["\[Theta]", "6"]}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"4", " ", "z"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"16", " ", "z"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"36", " ", "z"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"64", " ", "z"}]}], ")"}], " ", 
        SuperscriptBox["\[Theta]", "7"]}]}]}
    },
    GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.5599999999999999]}, 
        Offset[0.27999999999999997`]}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}}],
   Column],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{
  3.818748869975046*^9, {3.820903216220191*^9, 3.8209032374202967`*^9}, {
   3.83723690531632*^9, 3.8372369177687798`*^9}, 3.837677502151039*^9},
 CellLabel->
  "Out[50]//TableForm=",ExpressionUUID->"cf711d11-506b-42ad-85b5-\
657e58c81884"]
}, Open  ]],

Cell[BoxData["\[IndentingNewLine]"], "Input",
 CellChangeTimes->{
  3.837236945771307*^9},ExpressionUUID->"753d9394-2c5e-4dc1-9bc3-\
05fa7bc4aa6a"],

Cell["Four - loop equal-mass operator (\[Epsilon]-extension of AESZ 34): ", \
"Text",
 CellChangeTimes->{{3.837236952777176*^9, 
  3.837236976265306*^9}},ExpressionUUID->"d496224d-6efd-4828-91af-\
ec2f20c25c73"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"OperatorEqualMass", "[", "4", "]"}]], "Input",
 CellChangeTimes->{{3.837236981046916*^9, 3.837236998012433*^9}, {
  3.837677515778681*^9, 3.837677518521564*^9}},
 CellLabel->"In[51]:=",ExpressionUUID->"67a15b27-be86-4693-9141-fa682977b848"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{"1", "+", 
     RowBox[{"2", " ", "\[Epsilon]"}]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", 
     RowBox[{"3", " ", "\[Epsilon]"}]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", 
     RowBox[{"4", " ", "\[Epsilon]"}]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"1", "-", 
     RowBox[{"5", " ", "z"}], "+", "\[Epsilon]", "+", 
     RowBox[{"3", " ", "z", " ", "\[Epsilon]"}]}], ")"}]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "4"}], "+", 
     RowBox[{"28", " ", "z"}], "-", 
     RowBox[{"30", " ", "\[Epsilon]"}], "+", 
     RowBox[{"189", " ", "z", " ", "\[Epsilon]"}], "+", 
     RowBox[{"26", " ", 
      SuperscriptBox["z", "2"], " ", "\[Epsilon]"}], "-", 
     RowBox[{"225", " ", 
      SuperscriptBox["z", "3"], " ", "\[Epsilon]"}], "-", 
     RowBox[{"70", " ", 
      SuperscriptBox["\[Epsilon]", "2"]}], "+", 
     RowBox[{"343", " ", "z", " ", 
      SuperscriptBox["\[Epsilon]", "2"]}], "-", 
     RowBox[{"225", " ", 
      SuperscriptBox["z", "3"], " ", 
      SuperscriptBox["\[Epsilon]", "2"]}], "-", 
     RowBox[{"50", " ", 
      SuperscriptBox["\[Epsilon]", "3"]}], "+", 
     RowBox[{"84", " ", "z", " ", 
      SuperscriptBox["\[Epsilon]", "3"]}], "+", 
     RowBox[{"414", " ", 
      SuperscriptBox["z", "2"], " ", 
      SuperscriptBox["\[Epsilon]", "3"]}]}], ")"}], " ", "\[Theta]"}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"6", "-", 
     RowBox[{"63", " ", "z"}], "+", 
     RowBox[{"26", " ", 
      SuperscriptBox["z", "2"]}], "-", 
     RowBox[{"225", " ", 
      SuperscriptBox["z", "3"]}], "+", 
     RowBox[{"30", " ", "\[Epsilon]"}], "-", 
     RowBox[{"315", " ", "z", " ", "\[Epsilon]"}], "-", 
     RowBox[{"675", " ", 
      SuperscriptBox["z", "3"], " ", "\[Epsilon]"}], "+", 
     RowBox[{"35", " ", 
      SuperscriptBox["\[Epsilon]", "2"]}], "-", 
     RowBox[{"343", " ", "z", " ", 
      SuperscriptBox["\[Epsilon]", "2"]}], "-", 
     RowBox[{"363", " ", 
      SuperscriptBox["z", "2"], " ", 
      SuperscriptBox["\[Epsilon]", "2"]}], "-", 
     RowBox[{"225", " ", 
      SuperscriptBox["z", "3"], " ", 
      SuperscriptBox["\[Epsilon]", "2"]}]}], ")"}], " ", 
   SuperscriptBox["\[Theta]", "2"]}], "-", 
  RowBox[{"2", " ", 
   RowBox[{"(", 
    RowBox[{"2", "-", 
     RowBox[{"35", " ", "z"}], "+", 
     RowBox[{"225", " ", 
      SuperscriptBox["z", "3"]}], "+", 
     RowBox[{"5", " ", "\[Epsilon]"}], "-", 
     RowBox[{"105", " ", "z", " ", "\[Epsilon]"}], "+", 
     RowBox[{"259", " ", 
      SuperscriptBox["z", "2"], " ", "\[Epsilon]"}], "+", 
     RowBox[{"225", " ", 
      SuperscriptBox["z", "3"], " ", "\[Epsilon]"}]}], ")"}], " ", 
   SuperscriptBox["\[Theta]", "3"]}], "-", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", "z"}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", 
     RowBox[{"9", " ", "z"}]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", 
     RowBox[{"25", " ", "z"}]}], ")"}], " ", 
   SuperscriptBox["\[Theta]", "4"]}]}]], "Output",
 CellChangeTimes->{{3.837236981191679*^9, 3.83723699826027*^9}, 
   3.8376775187969007`*^9},
 CellLabel->"Out[51]=",ExpressionUUID->"7a501130-5702-4ce9-b322-e66969db0a66"]
}, Open  ]]
}, Closed]]
}, Closed]]
}, Open  ]]
},
Evaluator->"MyKernel4",
WindowSize->{1402, 1295},
WindowMargins->{{468, Automatic}, {Automatic, 0}},
FrontEndVersion->"12.3 for Mac OS X x86 (64-bit) (June 19, 2021)",
StyleDefinitions->"Default.nb",
ExpressionUUID->"b59e2e00-718f-4b0d-b9c7-6b6862c6a4b0"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 273, 6, 98, "Title",ExpressionUUID->"5e146ba6-3056-485d-95ac-35994a430abf"],
Cell[CellGroupData[{
Cell[878, 32, 177, 3, 69, "Chapter",ExpressionUUID->"b50de7df-2fe0-4670-a278-aec814a58f66"],
Cell[1058, 37, 285, 5, 35, "Text",ExpressionUUID->"aa8d77a8-2c29-4c07-84b8-4ec88bdb64b9"],
Cell[1346, 44, 386, 7, 35, "Text",ExpressionUUID->"60d4d29a-c901-493f-a1fd-25cb9562a518"],
Cell[1735, 53, 1827, 46, 62, "Text",ExpressionUUID->"ffa1b902-9928-4d53-afe1-d81dcdca952d"],
Cell[CellGroupData[{
Cell[3587, 103, 164, 3, 67, "Section",ExpressionUUID->"2f5a02a2-bba2-4ee1-8299-a45de99e01a5"],
Cell[3754, 108, 718, 12, 44, "Input",ExpressionUUID->"3391a588-1ee2-404b-a439-0450a6259916"],
Cell[4475, 122, 7685, 200, 677, "Input",ExpressionUUID->"86e6ce61-0bb3-4721-90cb-29727bfc3106"],
Cell[12163, 324, 13367, 298, 589, "Input",ExpressionUUID->"608cfe77-7767-416e-bf69-4b7cb0e8b46f"]
}, Closed]],
Cell[CellGroupData[{
Cell[25567, 627, 160, 3, 53, "Section",ExpressionUUID->"1a6dc5ff-9852-478b-82e4-252de3737e41"],
Cell[CellGroupData[{
Cell[25752, 634, 154, 3, 45, "Subsubsection",ExpressionUUID->"2ab9371e-4028-48d9-8025-6988568ca47c"],
Cell[25909, 639, 281, 4, 35, "Text",ExpressionUUID->"6b1ec49f-26a8-4c1a-985b-85a920751e4b"],
Cell[CellGroupData[{
Cell[26215, 647, 397, 8, 80, "Input",ExpressionUUID->"dbcb596b-ff90-44b1-9af7-eb7ec45b4ad4"],
Cell[26615, 657, 8848, 259, 192, "Output",ExpressionUUID->"f9a7caf9-ebf7-4ef9-9902-879a81663e32"],
Cell[35466, 918, 199, 3, 34, "Output",ExpressionUUID->"4ca20bf7-c180-4545-bb00-2e3f13b889b6"]
}, Open  ]],
Cell[35680, 924, 149, 3, 52, "Input",ExpressionUUID->"8ed53c50-b50c-482f-aaf1-d0b10d9b9c15"],
Cell[35832, 929, 900, 23, 37, "Text",ExpressionUUID->"d2a7136d-7328-4b28-87e7-1b2d6527955c"],
Cell[CellGroupData[{
Cell[36757, 956, 538, 10, 80, "Input",ExpressionUUID->"2c1cb143-a79a-4ae8-97eb-e20ac00a207b"],
Cell[37298, 968, 51108, 1485, 672, "Output",ExpressionUUID->"40177e4d-6591-4448-ada7-c1b574cef260"],
Cell[88409, 2455, 299, 5, 34, "Output",ExpressionUUID->"579b517a-a2b9-4c8a-b1aa-7ca3fd91dffd"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[88757, 2466, 203, 4, 37, "Subsubsection",ExpressionUUID->"29e0faca-07f6-4875-abd9-0843925dc0a8"],
Cell[88963, 2472, 281, 4, 35, "Text",ExpressionUUID->"be2185a5-9a9c-495d-b708-3db798fe6ba6"],
Cell[CellGroupData[{
Cell[89269, 2480, 422, 8, 80, "Input",ExpressionUUID->"6c6fc30a-9020-428b-b22a-0b310e1f8057"],
Cell[89694, 2490, 363, 9, 28, "Message",ExpressionUUID->"d3bf8100-6618-4709-b7bf-45a47a28ebea"],
Cell[90060, 2501, 64526, 1785, 1118, "Output",ExpressionUUID->"80a46518-7123-4b15-98e2-bedbc8fe32f2"],
Cell[154589, 4288, 221, 3, 34, "Output",ExpressionUUID->"090fe595-1f81-438f-8790-74a57180ed6a"]
}, Open  ]],
Cell[154825, 4294, 149, 3, 52, "Input",ExpressionUUID->"99ad6b6b-bc4c-4084-9671-ba43239b1edc"],
Cell[154977, 4299, 925, 23, 37, "Text",ExpressionUUID->"67b930ee-dfec-4369-b7a1-a3c231042242"],
Cell[CellGroupData[{
Cell[155927, 4326, 587, 11, 80, "Input",ExpressionUUID->"a46c0b69-47f0-41e2-b881-ef9eb1e55734"],
Cell[156517, 4339, 63619, 1788, 903, "Output",ExpressionUUID->"a1f6e0eb-9620-4cfd-9ec1-403be7aa6038"],
Cell[220139, 6129, 343, 5, 34, "Output",ExpressionUUID->"eb6a26f0-29ae-4fc0-8107-e68d34e8293a"]
}, Open  ]]
}, Closed]]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[220555, 6142, 177, 3, 58, "Chapter",ExpressionUUID->"908fc8c3-142b-45f0-8296-663dedf3abf6"],
Cell[220735, 6147, 290, 5, 35, "Text",ExpressionUUID->"e398e435-cf77-4914-9002-c59c1a3f82f4"],
Cell[221028, 6154, 367, 8, 35, "Text",ExpressionUUID->"12ffdf89-e6c8-4082-9067-7dfe72774de5"],
Cell[CellGroupData[{
Cell[221420, 6166, 164, 3, 67, "Section",ExpressionUUID->"e8b627e9-78ec-4835-a064-30120cdbff98"],
Cell[221587, 6171, 895, 16, 80, "Input",ExpressionUUID->"0f31d05b-fa19-4b6d-a6dd-ee0ef169091b"],
Cell[222485, 6189, 11540, 298, 818, "Input",ExpressionUUID->"32e46965-4084-45ed-8f57-0e39ac001712"],
Cell[234028, 6489, 13852, 370, 1220, "Input",ExpressionUUID->"3ef52cb3-be84-4a03-9ea8-0b04685c2437"]
}, Closed]],
Cell[CellGroupData[{
Cell[247917, 6864, 167, 3, 53, "Section",ExpressionUUID->"88525f0a-1f82-47e3-8418-de4a551e1c55"],
Cell[248087, 6869, 234, 4, 35, "Text",ExpressionUUID->"2da521f2-bd42-4850-a4e4-5ec20bb93dc5"],
Cell[248324, 6875, 527, 10, 44, "Input",ExpressionUUID->"7fb7c23a-434c-40d2-849c-fd47211db1d8"],
Cell[248854, 6887, 149, 3, 52, "Input",ExpressionUUID->"6bcb99c3-064e-4af7-ba5e-5433569325f1"],
Cell[249006, 6892, 186, 3, 35, "Text",ExpressionUUID->"1e412bc4-9d92-496d-8549-712a0510ff6f"],
Cell[CellGroupData[{
Cell[249217, 6899, 593, 12, 44, "Input",ExpressionUUID->"eff9cf9a-96ee-4535-a7f0-df61bdb570b6"],
Cell[249813, 6913, 34590, 858, 182, "Output",ExpressionUUID->"cf711d11-506b-42ad-85b5-657e58c81884"]
}, Open  ]],
Cell[284418, 7774, 147, 3, 52, "Input",ExpressionUUID->"753d9394-2c5e-4dc1-9bc3-05fa7bc4aa6a"],
Cell[284568, 7779, 211, 4, 35, "Text",ExpressionUUID->"d496224d-6efd-4828-91af-ec2f20c25c73"],
Cell[CellGroupData[{
Cell[284804, 7787, 264, 4, 30, "Input",ExpressionUUID->"67a15b27-be86-4693-9141-fa682977b848"],
Cell[285071, 7793, 3290, 92, 60, "Output",ExpressionUUID->"7a501130-5702-4ce9-b322-e66969db0a66"]
}, Open  ]]
}, Closed]]
}, Closed]]
}, Open  ]]
}
]
*)

